(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    264593,       8109]*)
(*NotebookOutlinePosition[    319013,       9966]*)
(*  CellTagsIndexPosition[    315801,       9865]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[ValueBox["FileName"]], "Title",
  CounterAssignments->{{"Title", 0}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],

Cell[TextData[{
  "Trial of Translation of ",
  ButtonBox["[Mel1910]",
    ButtonData:>"[Mel1910]",
    ButtonStyle->"Hyperlink"],
  " from the original Language German to English\nWho asks:\t29.10.2003\t\
Edward Jones, Llandudno (Northern Wales)\nHandling:\t  3.11.2003 - 11.12.2003\
\tNorbert S\[UDoubleDot]dland, Aalen (W\[UDoubleDot]rttemberg)\nLast \
Calculation:\t29.11.2003\tNorbert S\[UDoubleDot]dland, Aalen \
(W\[UDoubleDot]rttemberg)"
}], "Subsubtitle",
  TextAlignment->Left],

Cell[TextData[{
  "The interactive ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calculations like"
}], "Text"],

Cell[BoxData[
    \(<< Calculus`Limit`\)], "Input"],

Cell["elucidate the correctness of the results.", "Text"],

Cell[TextData[{
  "[Mel1910] Mellin Hjalmar ",
  StyleBox[
  "Abri\[SZ] einer einheitlichen Theorie der Gamma- und der \
hypergeometrischen Funktionen",
    FontSlant->"Italic"],
  ", Mathematische Annalen ",
  StyleBox["68",
    FontWeight->"Bold"],
  " 305-337, (1910)"
}], "Text",
  ParagraphIndent->-95,
  CellTags->"[Mel1910]"],

Cell[CellGroupData[{

Cell["\<\
Summary of a Uniform Theory of Gamma and Hypergeometric Functions\
\>", "Subtitle",
  TextAlignment->Center],

Cell["\<\
by
Hj. Mellin, Helsingfors (Finland)\
\>", "Subsubtitle",
  TextAlignment->Center],

Cell[TextData[{
  "Although it seems not to be unknown, that there is a hearty ",
  ButtonBox["connection*)",
    ButtonData:>"FootnoteAbstract",
    ButtonStyle->"Hyperlink"],
  " between the gamma function and the hypergeometric functions, to my \
knowledge there is no attention to this fact in the handbooks being published \
so far, monographies and encyclopediae, that deal with the theory of gamma \
functions or parts thereof. Even in the latest elaborations of this kind \
indeed there is no mentioning of the hypergeometric functions. In this \
present elaboration I try to plead a conception which is fundamentally \
different to this and more general, ",
  StyleBox[
  "namely, where I must consider the very integration of all hypergeometric \
differential equations by means of the gamma functions to be the proper main \
task of a modern theory of that function itself. ",
    FontSlant->"Italic"],
  "After having established the general definition of the gamma functions, I \
have found Cauchy's integral theory to be a means to melt together the theory \
of these functions with the theory of the hypergeometric functions to be a \
systematic whole. Thereby it has turned out, that the conventional theory of \
the gamma function and Euler's integrals, as being presented in handbooks, \
monographies and encyclopediae, is just a fragment of this more general \
theory, which is totally sufficient in regard to uniformity."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "*) The same has been developed first by the author and by Mr. ",
  StyleBox["Pincherle",
    FontWeight->"Bold"],
  " completely. Our elaborations concerning this are cited at the \
corresponding positions of this elaboration."
}], "Text",
  ParagraphIndent->30,
  CellTags->"FootnoteAbstract"],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section]",
  " ",
  CounterBox["Section"],
  ". Introduction to the Gamma Function"
}], "Section"],

Cell["By the formula", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(Sin[\[Pi]\ z] \[Equal] 
      \[Pi]\ z\ \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 - z\^2\/n\^2)
            \)\) \[Equal] 
      \[Pi]\ z\ \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + z\/n)\) 
            \[ExponentialE]\^\(-
                  \(z\/n\)\)\[CenterDot]\(\[Product]\+\(n\  = \ 1
                    \)\%\[Infinity]\((1 - z\/n)\) 
                  \[ExponentialE]\^\(z\/n\)\)\)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[\[Pi]\ z] \[Equal] 
        \[Pi]\ z\ 
          \(\[Product]\+\(n = 1\)\%\[Infinity]\((1 - z\^2\/n\^2)\)\) // 
      PowerExpand\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
we have got a starting point belonging to the elements of function theory, \
from which we can arrive quickly at the gamma function without compulsion. \
Thus by the function\
\>", "Text"],

Cell[BoxData[
    \(F[z] \[Equal] 
      \[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + z\/n)\) 
          \[ExponentialE]\^\(-\(z\/n\)\)\)], "NumberedEquation1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Sin[\[Pi]\ z]\)]],
  " can be explessed the following:"
}], "Text"],

Cell[BoxData[
    \(Sin[\[Pi]\ z] \[Equal] \[Pi]\ z\ F[z] \(F[\(-z\)].\)\)], 
  "NumberedEquation1",
  CellTags->"Equation3"],

Cell[TextData[{
  "Now the left hand side of the substitution ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] z + 1\)]],
  " changes the sign only, thus the question occurs, what will happen to ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " by this. The result is:"
}], "Text"],

Cell[BoxData[
    \(F[z + 1]\/F[z] \[Equal] 
      \[Product]\+\(n\  = \ 1\)\%\[Infinity]\(\( z + n + 1\)\/\(z + n\)\) 
          \[ExponentialE]\^\(-\(1\/n\)\) \[Equal] 
      lim\+\(n\  = \ \[Infinity]\)\(\(z + 2\)\/\(z + 1\)\) 
          \(\[ExponentialE]\^\(-1\)\) \(\(z + 3\)\/\(z + 2\)\) 
          \[ExponentialE]\^\(-\(1\/2\)\)\ 
            \[CenterDot]\[CenterDot]\[CenterDot]\ \(z + n + 1\)\/\(z + n\) 
          \[ExponentialE]\^\(-\(1\/n\)\)\n \[Equal] 
      \(1\/\(z + 1\)\) 
        \(lim\+\(n\  = \ \[Infinity]\)\((1 + \(z + 1\)\/n)\) 
            \(\[ExponentialE]\^\(\(-1\) - 1\/2 - \ 
                  \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\(1\/n\)\)\) + 
                  Log[n]\).\)\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(z + n + 1\)\/\(z + 1\) == 
        \(1\/\((z + 1)\)\) \((1 + \(z + 1\)\/n)\) \[ExponentialE]\^Log[n] // 
      ExpandAll\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Therefore exists", "Text"],

Cell[BoxData[
    \(lim\+\(n\  = \ \[Infinity]\)\(\((
          1 + 1\/2 + 
            \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(+\(1\/n\)\)\) - Log[n])
          \).\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\[Sum]\+\(k = 1\)\%n 1\/k - Log[n], n \[Rule] \[Infinity]]\)], 
  "Input"],

Cell[BoxData[
    \(EulerGamma\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EulerGamma\)\)], "Input"],

Cell[BoxData[
    \("EulerGamma is Euler's constant gamma, with numerical value \
approximately equal to 0.577216."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "With the symbol ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " for this limit, this is Euler's constant gamma, we have got the formula"
}], "Text"],

Cell[BoxData[
    \(\(F[z + 1] \[Equal] \(\[ExponentialE]\^\(-C\)\/\(z + 1\)\) F[z], \)\)], 
  "NumberedEquation1",
  CellTags->"Equation4"],

Cell[TextData[{
  "which gives an answer to the question above. This functional equation \
becomes more simple, if we introduce the gamma function instead of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " by the definition"
}], "Text"],

Cell[BoxData[
    \(\[CapitalGamma][z] \[Equal] \[ExponentialE]\^\(\(-C\)\ z\)\/\(z\ F[z]\) 
      \[Equal] \(\[ExponentialE]\^\(\(-C\)\ z\)\/z\) 
        \(\((\[Product]\+\(n\  = \ 1\)\%\[Infinity] 
                  \[ExponentialE]\^\(z\/n\)\/\(1 + z\/n\))\).\)\)], 
  "NumberedEquation1",
  CellTags->"Equation5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z] == 
        \(\[ExponentialE]\^\(\(-EulerGamma\)\ z\)\/z\) 
          Limit[\[Product]\+\(n\  = \ 1\)\%N
                 \[ExponentialE]\^\(z\/n\)\/\(1 + z\/n\), 
            N \[Rule] \[Infinity]] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then with the equations (",
  CounterBox["NumberedEquation", "Equation4"],
  ") and (",
  CounterBox["NumberedEquation", "Equation5"],
  ") succeeds"
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalGamma][z + 1] \[Equal] z\ \[CapitalGamma][z], \)\)], 
  "NumberedEquation1",
  CellTags->"Equation6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z + 1] == z\ Gamma[z] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "while equation (",
  CounterBox["NumberedEquation", "Equation3"],
  ") gets the form:"
}], "Text"],

Cell[BoxData[
    \(\[CapitalGamma][z] \[CapitalGamma][1 - z] \[Equal] 
      \(\((\[Pi]\/Sin[\[Pi]\ z])\).\)\)], "NumberedEquation1",
  CellTags->"Equation7"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z]\ Gamma[1 - z] == \[Pi]\/Sin[\[Pi]\ z] // FullSimplify\)], 
  "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Due to the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[ExponentialE]\^\(-C\) \[Equal] 
      lim\+\(n\  = \ \[Infinity]\)\((1 + 1\/n)\) 
          \[ExponentialE]\^\(Log[n] - 1 - 1\/2 - \ 
              \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\(1\/n\)\)\)\)\n 
      \[Equal] lim\+\(n\  = \ \[Infinity]\)\((1 + 1\/1)\) 
          \((1 + 1\/2)\)\ \[CenterDot]\[CenterDot]\[CenterDot]\ 
            \((1 + 1\/n)\) 
          \[ExponentialE]\^\(\(-1\) - 1\/2 - \ 
              \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\(1\/n\)\)\)\)\n 
      \[Equal] \[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\) 
          \(\[ExponentialE]\^\(-\(1\/n\)\).\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(1\/\((z + 1)\)\) \((1 + \(z + 1\)\/n)\) \[ExponentialE]\^Log[n] == 
          \((\(z + n + 1\)\/\(z + n\))\) \((\(z + n\)\/\(z + 3\))\) 
            \((\(z + 3\)\/\(z + 2\))\) \((\(z + 2\)\/\(z + 1\))\) /. {
          z \[Rule] 0} // ExpandAll\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "From this follows first, that ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is positive due to ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((1 + 1\/n)\) \[ExponentialE]\^\(-\(1\/n\)\) < 1\)]],
  ", and second, that because of equation (",
  CounterBox["NumberedEquation", "Equation5"],
  ") the gamma function can also be presented the following:"
}], "Text"],

Cell[BoxData[
    \(\[CapitalGamma][z] \[Equal] 
      \(1\/z\) \(\((
            \[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\)\^z\/\(1 + 
                  z\/n\))\).\)\)], "NumberedEquation1",
  CellTags->"Equation8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[ExponentialE]\^\(\(-C\)\ z\)\/z\) 
            \(\[Product]\+\(n\  = \ 1\)\%\[Infinity] 
                  \[ExponentialE]\^\(z\/n\)\/\(1 + z\/n\)\) == 
          \(1\/z\) 
            \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\)\^z\/\(1 + 
                  z\/n\)\) /. {
          \[ExponentialE]\^\(\(-C\)\ z + a_.\) \[Rule] 
            \(\[ExponentialE]\^a\) 
              \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\(\((1 + 1\/n)\)\^z\) 
                  \[ExponentialE]\^\(-\(z\/n\)\)\)}\) /. {
        Product[a_, {__}] \[RuleDelayed] a}\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "From this follows furthermore ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][1] \[Equal] 1\)]],
  " and"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\(1\/z\) \((1 + 1\/n)\)\^z\/\(1 + z\/n\), z \[Rule] 1]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\[CapitalGamma][z] \[Equal] 
      lim\+\(n\  = \ 
            \[Infinity]\)\(\(1\[CenterDot]2
                \[CenterDot]\[CenterDot]\[CenterDot]n\)\/\(z 
                \((z + 1)\)\ 
                  \[CenterDot]\[CenterDot]\[CenterDot]\((z + n)\)\)\) 
          \(n\^z.\)\)], "NumberedEquation1",
  CellTags->"Equation9"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Product[1 + 1\/n, {n, 1, N}]\^z\/\(z\ Product[1 + z\/n, {n, 1, N}]\) == 
        \(Product[n, {n, 1, N}]\/\(z\ Product[z + n, {n, 1, N}]\)\) N\^z // 
      Simplify\), 
    \(Limit@@{First[%], N \[Rule] \[Infinity]}\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\((N\^z - \((1 + N)\)\^z)\)\ \(N!\)\)\/\(z\ 
              Pochhammer[1 + z, N]\)\)\) == 0\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Combining this formula with the one following from equation (",
  CounterBox["NumberedEquation", "Equation6"],
  ")"
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalGamma][z] \[Equal] 
      \[CapitalGamma][z + n + 1]\/\(z 
          \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + n)\)\) 
      \[Equal] \(\(1\[CenterDot]2\[CenterDot]\[CenterDot]\[CenterDot]n\)\/\(z 
              \((z + 1)\)\ 
                \[CenterDot]\[CenterDot]\[CenterDot]\((z + n)\)\)\) \(n\^z\) 
        \[CapitalGamma][z + n + 1]\/\(\(n!\)\ n\^z\), \)\)], "Equation"],

Cell["the result is", "Text"],

Cell[BoxData[
    \(lim\+\(n\  = \ \[Infinity]\)\[CapitalGamma][z + n + 1]\/\(\(n!\)\ 
            n\^z\) \[Equal] 1.\)], "NumberedEquation1",
  CellTags->"Equation10"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[Gamma[z + n + 1]\/\(\(n!\)\ \((n + p)\)\^z\), 
        n \[Rule] \[Infinity]] == 1\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Vice verca obviously follows formula (",
  CounterBox["NumberedEquation", "Equation9"],
  ") from equations (",
  CounterBox["NumberedEquation", "Equation6"],
  ") and (",
  CounterBox["NumberedEquation", "Equation10"],
  "), thus ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z]\)]],
  " is defined by these two properties (",
  CounterBox["NumberedEquation", "Equation6"],
  ") and (",
  CounterBox["NumberedEquation", "Equation10"],
  ") completely."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z] == 
      Limit[\(\(n!\)\/\(\[Product]\+\(k = 0\)\%n\((z + k)\)\)\) \(n\^z\) 
            \[CapitalGamma][z + n + 1]\/\(\(n!\)\ n\^z\) /. {
            \[CapitalGamma][z + n + 1] \[Rule] \(n!\)\ n\^z}, 
        n \[Rule] \[Infinity]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This introduction to the theory of gamma functions has also been suggested \
by me in a former ",
  ButtonBox["elaboration*)",
    ButtonData:>"FootnoteSection1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  ParagraphIndent->30],

Cell["\<\
*) Om Gammafunktionen. \[CapitalODoubleDot]fvers. af. Sv. \
Vetenskapsakademiens F\[ODoubleDot]rh. 1883, No. 5.\
\>", "Text",
  ParagraphIndent->30,
  CellTags->"FootnoteSection1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". The Behaviour of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][s + \[ImaginaryI]\ t]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \) = \[Infinity]\)]]
}], "Section",
  CellTags->"Section2"],

Cell["\<\
For the applications of the gamma function on the field of definite integrals \
the following sentence is of fundamental importance.\
\>", "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If the variable ",
  Cell[BoxData[
      \(TraditionalForm\`z = s + \[ImaginaryI]\ t\)]],
  " is limited to an arbitrary stripe of restricted width being parallel to \
the imaginary axis by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[LessEqual] s \[LessEqual] \[Beta]\)]],
  ", and if furthermore is assumed"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(\(\(|\[CapitalGamma][s + \[ImaginaryI]\ t] | 
           \[Equal] 
            \[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) | t | \)\[CenterDot]\((
                  \(|t | \))\)\^\(s - 1\/2\)\[CenterDot]\) | 
        \@\(2  \[Pi]\) + \[Epsilon] | \), \)\)], "NumberedEquation1",
  CellTags->"Equation11"],

Cell[TextData[{
  "then by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " reaches equally the limit null."
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "Because of equations (",
  CounterBox["NumberedEquation", "Equation6"],
  ") and (",
  CounterBox["NumberedEquation", "Equation7"],
  ") is"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\((\(|\[CapitalGamma][\[ImaginaryI]\ t] | \))\) \[Equal] 
        \@\(\[CapitalGamma][\[ImaginaryI]\ t] 
            \[CapitalGamma][\(-\[ImaginaryI]\)\ t]\) \[Equal] 
        \@\(\(2  \[Pi]\)\/\(t 
                \((\[ExponentialE]\^\(\[Pi]\ t\) - 
                    \[ExponentialE]\^\(\(-\[Pi]\)\ t\))\)\)\) \[Equal] 
        \(\[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) | t | \)\) 
            \((\(|t | \))\)\^\(-\(1\/2\)\)\[CenterDot]|\@\(2  \[Pi]\) + 
          \[Epsilon] | .\)], "NumberedEquation1",
  CellTags->"Equation12"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Pi]\/\(\(-\[ImaginaryI]\)\ t\ Sin[\[ImaginaryI]\ \[Pi]\ t]\) == 
        \(2  \[Pi]\)\/\(t 
            \((\[ExponentialE]\^\(\[Pi]\ t\) - 
                \[ExponentialE]\^\(\(-\[Pi]\)\ t\))\)\) // FullSimplify\)], 
  "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus formula (",
  CounterBox["NumberedEquation", "Equation11"],
  ") is valid for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][\[ImaginaryI]\ t]\)]],
  ". Now the task is to find out the behaviour of the quotient ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalGamma][s + \[ImaginaryI]\ t] : 
        \[CapitalGamma][\[ImaginaryI]\ t]\)]],
  ". By use of equation (",
  CounterBox["NumberedEquation", "Equation8"],
  ") and by multiplication by"
}], "Text"],

Cell[BoxData[
    \(1 \[Equal] 
      \(\((\[ImaginaryI]\ t)\)\^s\) \(\((1 + 1\/\(\[ImaginaryI]\ t\))\)\^s\) 
        \(\[Product]\+\(n\  = \ 1
              \)\%\[Infinity]\((1 + 1\/\(\[ImaginaryI]\ t + n\))\)\^s
              \/\((1 + 1\/n)\)\^s\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 == 
      Limit[\(\((\[ImaginaryI]\ t)\)\^s\) 
            \(\((1 + 1\/\(\[ImaginaryI]\ t\))\)\^s\) 
            \(\[Product]\+\(n\  = \ 1\)\%N
                \((1 + 1\/\(\[ImaginaryI]\ t + n\))\)\^s\/\((1 + 1\/n)\)\^s
                  \) /. {s \[Rule] 1}, N \[Rule] \[Infinity]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["results:", "Text"],

Cell[BoxData[
    \(\[CapitalGamma][s + \[ImaginaryI]\ t]\/\[CapitalGamma][\[ImaginaryI]\ t]
           \[Equal] 
      \(1\/\(1 + s\/\(\[ImaginaryI]\ t\)\)\) 
        \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\)\^s\/\(1 + 
              s\/\(\[ImaginaryI]\ t + n\)\)\)\n \[Equal] 
      \(\((\[ImaginaryI]\ t)\)\^s\) 
        \(\((\[Product]\+\(n\  = \ 0
                  \)\%\[Infinity]\((1 + 1\/\(\[ImaginaryI]\ t + n\))\)\^s\/\(1
                   + s\/\(\[ImaginaryI]\ t + n\)\))\).\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[CapitalGamma][s + \[ImaginaryI]\ t]\/\[CapitalGamma][
                \[ImaginaryI]\ t] == 
            \(1\/\(1 + s\/\(\[ImaginaryI]\ t\)\)\) 
              \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\)\^s\/\(1
                     + s\/\(\[ImaginaryI]\ t + n\)\)\) /. {
            \[CapitalGamma][z_] \[RuleDelayed] 
              \(1\/z\) 
                \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\)\^z\/\(1
                       + z\/n\)\)}\) /. {Product[a_, {__}] \[RuleDelayed] a}
           // Simplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(1\/\(1 + s\/\(\[ImaginaryI]\ t\)\)\) 
              \(\[Product]\+\(n\  = \ 1\)\%\[Infinity]\((1 + 1\/n)\)\^s\/\(1
                     + s\/\(\[ImaginaryI]\ t + n\)\)\))\) 
          \((\(\((\[ImaginaryI]\ t)\)\^s\) 
              \(\((1 + 1\/\(\[ImaginaryI]\ t\))\)\^s\) 
              \(\[Product]\+\(n\  = \ 1
                    \)\%\[Infinity]\((1 + 1\/\(\[ImaginaryI]\ t + n\))\)\^s
                    \/\((1 + 1\/n)\)\^s\))\) == 
        \(\((\[ImaginaryI]\ t)\)\^s\) 
          \((\((1 + 1\/\(\[ImaginaryI]\ t + n\))\)\^s\/\(1 + 
                  s\/\(\[ImaginaryI]\ t + n\)\) /. {n \[Rule] 0})\) 
          \(\[Product]\+\(n\  = \ 1
                \)\%\[Infinity]\((1 + 1\/\(\[ImaginaryI]\ t + n\))\)\^s\/\(1
                 + s\/\(\[ImaginaryI]\ t + n\)\)\) /. {
        Product[a_, {__}] \[RuleDelayed] a}\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["From this follows", "Text"],

Cell[BoxData[
    \(\(Log[
        \[CapitalGamma][s + \[ImaginaryI]\ t]
            \/\(\(\((\[ImaginaryI]\ t)\)\^s\) 
            \[CapitalGamma][\[ImaginaryI]\ t]\)] \[Equal] 
      \[Sum]\+\(n\  = \ 0\)\%\[Infinity]\((
          s\ Log[1 + 1\/\(\[ImaginaryI]\ t + n\)] - 
            Log[1 + s\/\(\[ImaginaryI]\ t + n\)])\)\n\t \[Equal] 
      \[Sum]\+\(n\  = \ 0\)\%\[Infinity]\( 1\/\((\[ImaginaryI]\ t + n)\)\^2\) 
          \[GothicCapitalP][1\/\(\[ImaginaryI]\ t + n\)], \)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Log[
              \(\(\((\[ImaginaryI]\ t)\)\^s\) 
                  \(\[Product]\+\(n\  = \ 0
                        \)\%\[Infinity]\((1 + 1\/\(\[ImaginaryI]\ t + n\))
                          \)\^s\/\(1 + s\/\(\[ImaginaryI]\ t + n\)\)\)\)\/\((
                    \[ImaginaryI]\ t)\)\^s] == 
            \[Sum]\+\(n\  = \ 0\)\%\[Infinity]\((
                s\ Log[1 + 1\/\(\[ImaginaryI]\ t + n\)] - 
                  Log[1 + s\/\(\[ImaginaryI]\ t + n\)])\) /. {
            Product[a_, {__}] \[RuleDelayed] a, 
            Sum[a_, {__}] \[RuleDelayed] a} // PowerExpand\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(Sum::"div" \( : \ \) "Sum does not converge."\)], "Message"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((s\ Log[1 + 1\/\(\[ImaginaryI]\ t + n\)] - 
            Log[1 + s\/\(\[ImaginaryI]\ t + n\)])\) /. 
        Log[1 + x_] \[RuleDelayed] 
          Evaluate[Normal[Series[Log[1 + x], {x, 0, 2}]]] // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\(\((\(-1\) + s)\)\ s\)\/\(2\ \((n + I\ t)\)\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP][x]\)]],
  " stands for a series of positive integer powers in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", which converges for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  < 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(|s\ x\) | \( < 1\)\)]],
  ", and whose coefficients are simple terms of ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " being independent of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". With the limitation ",
  Cell[BoxData[
      \(TraditionalForm\`\(-R\) \[LessEqual] s \[LessEqual] \(+R\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " being an arbitrary positive number, the absolute value of"
}], "Text"],

Cell[BoxData[
    \(\[GothicCapitalP][1\/\(\[ImaginaryI]\ t + n\)]\)], "Equation"],

Cell[TextData[{
  "stays beneath a finite limit ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\)\)]],
  " and each ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " fulfilling the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t |  > R + 1\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". Therefore from the formula above results"
}], "Text"],

Cell[BoxData[
    \(\(|Log[
        \[CapitalGamma][s + \[ImaginaryI]\ t]
            \/\(\(\((\[ImaginaryI]\ t)\)\^s\) 
            \[CapitalGamma][\[ImaginaryI]\ t]\)] | 
       < \[Sum]\+\(n\  = \ 0\)\%\[Infinity] M
            \/\(\(|\[ImaginaryI]\ t\) + n\(|\^2\)\) \[Equal] 
        \[Sum]\+\(n\  = \ 0\)\%\[Infinity] M\/\(t\^2 + n\^2\)\n \[LessEqual] 
        \[Sum]\+\(n\  = \ 0\)\%\[Infinity]\( 2  M\)\/\((\(|t | \(+n\)\))\)\^2
               < \[Sum]\+\(n\  = \ 0\)\%\[Infinity]\( 2  M
              \)\/\(\((\(|t | \(+n\) - 1\))\) \((\(|t | \(+n\)\))\)\) 
        \[Equal] \(\((\(2  M\)\/\(|t | \(-1\)\))\).\)\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(2  M\)\/\(\((Abs[t] + n - 1)\) \((Abs[t] + n)\)\) // Apart\), 
    \(\[Sum]\+\(n\  = \ 0\)\%\[Infinity]\( 2  M\)\/\(\((Abs[t] + n - 1)\) 
            \((Abs[t] + n)\)\) == \(2\ M\)\/\(Abs[t] - 1\)\)}], "Input"],

Cell[BoxData[
    \(\(2\ M\)\/\(\(-1\) + n + Abs[t]\) - \(2\ M\)\/\(n + Abs[t]\)\)], 
  "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Thus with the assumption", "Text"],

Cell[BoxData[
    \(\(|\((
        \[CapitalGamma][s + \[ImaginaryI]\ t]
            \/\(\(\((\[ImaginaryI]\ t)\)\^s\) 
            \[CapitalGamma][\[ImaginaryI]\ t]\))\) | 
       \[Equal] 1 + \[Epsilon]\)\)], "NumberedEquation1",
  CellTags->"Equation13"],

Cell[TextData[{
  "is equally ",
  Cell[BoxData[
      \(TraditionalForm\`lim\ \[Epsilon] \[Equal] 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t |  \[Equal] \[Infinity]\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " stays between arbitrary finite limitations. From the equations (",
  CounterBox["NumberedEquation", "Equation12"],
  ") and (",
  CounterBox["NumberedEquation", "Equation13"],
  ") finally results formula (",
  CounterBox["NumberedEquation", "Equation11"],
  "), which obviously can also be written the following:"
}], "Text"],

Cell[BoxData[
    \(\(|\[CapitalGamma][z] | 
        \( \[Equal] \[ExponentialE]\)\^\(\(-\(\[Pi]\/2\)\) | t | 
              \)\[CenterDot]\) | \((z\^\(s - 1\/2\))\) | 
      \(\[CenterDot] | \@\(2  \[Pi]\)\) + \[Epsilon] | .\)], 
  "NumberedEquation1",
  CellTags->"Equation14"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[ExponentialE]\^\(s\ Log[z]\) // Simplify\), 
    \(\@\(s\^2 + t\^2\) == 
      \(\@t\^2\) Limit[\@\(1 + s\^2\/t\^2\), t \[Rule] \[Infinity]]\)}], 
  "Input"],

Cell[BoxData[
    \(z\^s\)], "Output"],

Cell[BoxData[
    \(\@\(s\^2 + t\^2\) == \@t\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Although to a certain degree this formula is contained within ",
  ButtonBox["Stirling's formula*)",
    ButtonData:>"Footnote1Section2",
    ButtonStyle->"Hyperlink"],
  ", which in  the year 1889 has been extended first by ",
  StyleBox["Stieltjes",
    FontWeight->"Bold"],
  " to complex arguments, it is worth to be elucidated and developed to a \
particular sentence in the above given form being important for applications, \
especially since the derivation of it can be done by simpler assumptions than \
the one of Stirling's formula. Mr. ",
  StyleBox["Pincherle",
    FontWeight->"Bold"],
  " has reached this ",
  ButtonBox["sentence above**)",
    ButtonData:>"Footnote2Section2",
    ButtonStyle->"Hyperlink"],
  " approximately already in the year 1888, while the same has been shown \
completely by me in an ",
  ButtonBox["elaboration***)",
    ButtonData:>"Footnote3Section2",
    ButtonStyle->"Hyperlink"],
  " of the year 1890. The proof above is a simplification of the former one. \
At the same time Mr. ",
  StyleBox["Jensen",
    FontWeight->"Bold"],
  " has derived a ",
  ButtonBox["formula",
    ButtonData:>"Footnote4Section2",
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[Dagger]",
    ButtonData:>"Footnote4Section2",
    ButtonStyle->"Hyperlink"],
  ButtonBox[")",
    ButtonData:>"Footnote4Section2",
    ButtonStyle->"Hyperlink"],
  ", which contains the above one as a special case."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[
"*) Sur le d\[EAcute]veloppement de log \[CapitalGamma](a). Journal de Math. \
(4) vol. 5; 1889."], "Text",
  ParagraphIndent->50,
  CellTags->"Footnote1Section2"],

Cell[TextData[{
  "**) Sulle funzioni ipergeometriche generalizzate. Accad. dei Lincei. Rend. \
(4). vol. 4; 1888. If in equation (",
  CounterBox["NumberedEquation", "Equation14"],
  ") ",
  Cell[BoxData[
      \(TraditionalForm\`s - 1\/2\)]],
  " is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`m + \[Epsilon]\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the largest integer number being contained in ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ", then with ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(-\(1\/2\)\) \[LessEqual] \[Epsilon] \[LessEqual] 1\/2\)]],
  " the result of Pincherle is reached."
}], "Text",
  ParagraphIndent->40,
  CellTags->"Footnote2Section2"],

Cell["\<\
***) Zur Theorie der linearen Differenzengleichungen erster Ordnung. Acta \
Math. vol. 15. The elaboration of Stieltjes was not known to me at that time.\
\
\>", "Text",
  ParagraphIndent->32,
  CellTags->"Footnote3Section2"],

Cell[TextData[
"\[Dagger]) Gammafunktionens Theorie, Nyt Tidskrift f\[ODoubleDot]r Math. \
vol. 2 C."], "Text",
  ParagraphIndent->50,
  CellTags->"Footnote4Section2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". Definition of the Gamma Functions"
}], "Section",
  CellTags->"Section3"],

Cell["\<\
The functional equation of the gamma function is a special case of\
\>", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(F[z + 1] \[Equal] \(\[PlusMinus]R[z]\) F[z], \)\)], 
  "NumberedEquation1",
  CellTags->"Equation15"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R[z]\)]],
  " stands for the rational function"
}], "Text"],

Cell[BoxData[
    \(R[z] \[Equal] 
      \(\((\(\((z - \[Rho]\_1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((
                z - \[Rho]\_m)\)\)\/\(\((z - \[Sigma]\_1)
                \)\[CenterDot]\[CenterDot]\[CenterDot]\((z - \[Sigma]\_n)\)\))
          \).\)\)], "NumberedEquation1",
  CellTags->"Equation16"],

Cell["We consider the expression", "Text"],

Cell[BoxData[
    \(G[z] \[Equal] 
      \[CapitalGamma][z - \[Rho]\_1]
            \[CenterDot]\[CenterDot]\[CenterDot]\[CapitalGamma][z - \[Rho]\_m]
             \[CapitalGamma][1 + \[Sigma]\_1 - z]
            \[CenterDot]\[CenterDot]\[CenterDot]\[CapitalGamma][
            1 + \[Sigma]\_n - z]\)], "NumberedEquation1",
  CellTags->"Equation17"],

Cell["to be the basic form fulfilling the equation", "Text"],

Cell[BoxData[
    \(\(G[z + 1] \[Equal] \(\((\(-1\))\)\^n\) R[z] G[z], \)\)], 
  "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(G[z + 1] == 
            \(\((\(-1\))\)\^n\) 
              \(\(\((z - \[Rho]\_1)\) 
                    \((z - \[Rho]\_m)\)\)\/\(\((z - \[Sigma]\_1)\) 
                    \((z - \[Sigma]\_n)\)\)\) G[z] /. {
            G[z_] \[RuleDelayed] 
              Gamma[z - \[Rho]\_1] Gamma[z - \[Rho]\_m] 
                Gamma[1 + \[Sigma]\_1 - z] Gamma[1 + \[Sigma]\_n - z]}\) /. {
          n \[Rule] 2} // FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "from which all remaining solutions of equation (",
  CounterBox["NumberedEquation", "Equation15"],
  ") can be yielded by multiplication by periodic functions, and which is \
connected to the also remarkable solution"
}], "Text"],

Cell[BoxData[
    \(H[z] \[Equal] 
      \(\[CapitalGamma][z - \[Rho]\_1]
            \[CenterDot]\[CenterDot]\[CenterDot]\[CapitalGamma][z - \[Rho]\_m]
            \)\/\(\[CapitalGamma][z - \[Sigma]\_1]
            \[CenterDot]\[CenterDot]\[CenterDot]\[CapitalGamma][
            z - \[Sigma]\_n]\)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H[z + 1] == 
          \(\(\((z - \[Rho]\_1)\) 
                  \((z - \[Rho]\_m)\)\)\/\(\((z - \[Sigma]\_1)\) 
                  \((z - \[Sigma]\_n)\)\)\) H[z] /. {
          H[z_] \[RuleDelayed] 
            \(Gamma[z - \[Rho]\_1] 
                Gamma[z - \[Rho]\_m]\)\/\(Gamma[z - \[Sigma]\_1] 
                Gamma[z - \[Sigma]\_n]\)} // FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "by the formula due to equation (",
  CounterBox["NumberedEquation", "Equation7"],
  ")"
}], "Text"],

Cell[BoxData[
    \(\(\[Pi]\^n\) H[z] \[Equal] 
      G[z] Sin[\[Pi] \((z - \[Sigma]\_1)\)]
            \[CenterDot]\[CenterDot]\[CenterDot]\(Sin[
              \[Pi] \((z - \[Sigma]\_n)\)].\)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[Pi]\^n\) H[z] \[Equal] 
            G[z] Sin[\[Pi] \((z - \[Sigma]\_1)\)] 
              Sin[\[Pi] \((z - \[Sigma]\_n)\)] /. {
            G[z_] \[RuleDelayed] 
              Gamma[z - \[Rho]\_1] Gamma[z - \[Rho]\_m] 
                Gamma[1 + \[Sigma]\_1 - z] Gamma[1 + \[Sigma]\_n - z], 
            H[z_] \[RuleDelayed] 
              \(Gamma[z - \[Rho]\_1] 
                  Gamma[z - \[Rho]\_m]\)\/\(Gamma[z - \[Sigma]\_1] 
                  Gamma[z - \[Sigma]\_n]\)}\) /. {n \[Rule] 2} // FullSimplify
      \)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The most general solution of equation (",
  CounterBox["NumberedEquation", "Equation15"],
  ") obviously can be presented in the form ",
  Cell[BoxData[
      \(TraditionalForm\`P[z] G[z]\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " being an arbitrary function with the property ",
  Cell[BoxData[
      \(TraditionalForm\`P[z + 1] \[Equal] \(\[PlusMinus]P[z]\)\)]],
  ". In the theory of the gamma functions however there is no use to handle ",
  
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " as a totally undetermined periodical function. The uniformity of this \
theory rather requires, that only the solutions of equation (",
  CounterBox["NumberedEquation", "Equation15"],
  ") are considered, that result by confining the factor ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " in the following way:"
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "I. ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " is an unequivocal analytic function with the property ",
  Cell[BoxData[
      \(TraditionalForm\`P[z + 1] \[Equal] \(\[PlusMinus]P[z]\)\)]],
  "."
}], "Text",
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  ParagraphIndent->-20],

Cell[TextData[{
  "II. In a certain parallel stripe ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Alpha] \[LessEqual] Re[z] \[LessEqual] \[Alpha] + 1\)]],
  " the function ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " has got a finite number  at the most of singular locations, which are all \
poles of ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  "."
}], "Text",
  CellMargins->{{50, Inherited}, {Inherited, Inherited}},
  ParagraphIndent->-25],

Cell[TextData[{
  "III. If a positive constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is assumed to be sufficiently large, then ",
  Cell[BoxData[
      \(TraditionalForm
      \`P[s + \[ImaginaryI]\ t] \[ExponentialE]\^\(\(-C\)\  | t | \)\)]],
  " reaches equally null by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  "."
}], "Text",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  ParagraphIndent->-33],

Cell[TextData[{
  "The most general function ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " with this properties results by the following conclusions. All the poles \
of ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  ", that are located in the stripe ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Alpha] \[LessEqual] Re[z] \[LessEqual] \[Alpha] + 1\)]],
  ", shall be found in the series ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1, a\_2, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), a\_\[Mu]\)]],
  " as often as their corresponding ordinary numbers tell. Then"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(P\_1[z] \[Equal] 
      P[z] Sin[\[Pi] \((z - a\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
            \[Pi] \((z - a\_\[Mu])\)]\)], "Equation"],

Cell[TextData[{
  "is an entire function with the property ",
  Cell[BoxData[
      \(TraditionalForm\`P\_1[z + 1] \[Equal] \(\[PlusMinus]P\_1[z]\)\)]],
  ". Because of III ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " can be assumed to be so large, that the expression"
}], "Text"],

Cell[BoxData[
    \(P\_2[z] \[Equal] 
      P[z] \(Sin[\[Pi] \((z - a\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
              \[Pi] \((z - a\_\[Mu])\)]\)\/\(Sin[\[Pi] \((z - c\_1)\)]
              \[CenterDot]\[CenterDot]\[CenterDot]Sin[
              \[Pi] \((z - c\_\[Lambda])\)]\)\)], "Equation"],

Cell[TextData[{
  "has got the property ",
  Cell[BoxData[
      \(TraditionalForm\`lim\ P\_2[s + \[ImaginaryI]\ t] \[Equal] 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t |  \[Equal] \[Infinity]\)\)]],
  ". To simplify the argumentation, we choose the sizes ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in such a way, that the difference of any two of them does not give an \
integer number. The constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1, C\_2, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), C\_\[Lambda]\)]],
  " then can be determined in such a way, that the expression "
}], "Text"],

Cell[BoxData[
    \(P\_3[z] \[Equal] 
      P\_2[z] - 
        \((C\_1\/Sin[\[Pi] \((z - c\_1)\)] + 
            \(\[CenterDot]\[CenterDot]\[CenterDot]\(+
                \(C\_\[Lambda]\/Sin[\[Pi] \((z - c\_\[Lambda])\)]\)\)\))\)\)],
   "Equation"],

Cell[TextData[{
  "is regularly at the positions ",
  Cell[BoxData[
      \(TraditionalForm\`z = c\_1, c\_2, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), c\_\[Lambda]\)]],
  ". If furthermore ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is choosen in such a way, that ",
  Cell[BoxData[
      \(TraditionalForm\`P\_2[z + 1] \[Equal] \(-P\_2[z]\)\)]],
  " is valid, so also ",
  Cell[BoxData[
      \(TraditionalForm\`P\_3[z + 1] \[Equal] \(-P\_3[z]\)\)]],
  " is valid, and thus ",
  Cell[BoxData[
      \(TraditionalForm\`P\_3[z]\)]],
  " is an entire function. Moreover, ",
  Cell[BoxData[
      \(TraditionalForm\`lim\ P\_3[s + \[ImaginaryI]\ t] \[Equal] 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t |  \[Equal] \[Infinity]\)\)]],
  ", thus ",
  Cell[BoxData[
      \(TraditionalForm\`P\_3[z]\)]],
  " must be a constant, which indeed is null."
}], "Text"],

Cell[TextData[{
  "From this for ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " results the expression"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(P[z] \[Equal] 
      \(\(Sin[\[Pi] \((z - c\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
                \[Pi] \((z - c\_\[Lambda])\)]\)\/\(Sin[\[Pi] \((z - a\_1)\)]
                \[CenterDot]\[CenterDot]\[CenterDot]Sin[
                \[Pi] \((z - a\_\[Mu])\)]\)\) 
        \((C\_1\/Sin[\[Pi] \((z - c\_1)\)] + 
            \(\[CenterDot]\[CenterDot]\[CenterDot]\(+
                \(C\_\[Lambda]\/Sin[\[Pi] \((z - c\_\[Lambda])\)]\)\)\))\), 
    \)\)], "NumberedEquation1",
  CellTags->"Equation21"],

Cell["\<\
and vice versa also each expression of this form obviously has got the \
properties in question, namely I, II, III.\
\>", "Text",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(P[z] == 
        \(\(Sin[\[Pi] \((z - c\_1)\)] 
                Sin[\[Pi] \((z - c\_\[Lambda])\)]\)\/\(Sin[
                  \[Pi] \((z - a\_1)\)] Sin[\[Pi] \((z - a\_\[Mu])\)]\)\) 
          \((C\_1\/Sin[\[Pi] \((z - c\_1)\)] + 
              C\_\[Lambda]\/Sin[\[Pi] \((z - c\_\[Lambda])\)])\) /. 
      Flatten[Solve[
          P\_2[z] == 
              P[z] \(Sin[\[Pi] \((z - a\_1)\)] 
                    Sin[\[Pi] \((z - a\_\[Mu])\)]\)\/\(Sin[
                      \[Pi] \((z - c\_1)\)] 
                    Sin[\[Pi] \((z - c\_\[Lambda])\)]\) /. {
              P\_2[z] \[Rule] 
                \((C\_1\/Sin[\[Pi] \((z - c\_1)\)] + 
                    C\_\[Lambda]\/Sin[\[Pi] \((z - c\_\[Lambda])\)])\)}, 
          P[z]]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Therefore the following definition should not seem to be unfounded: ",
  StyleBox[
  "We discuss a gamma function to be each function that can be presented by \
the form",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P[z] G[z]\)]],
  StyleBox[", where",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " ",
  StyleBox["and",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " ",
  StyleBox["stand for the general expressions (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation17"],
    FontSlant->"Italic"],
  StyleBox[") and (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation21"],
    FontSlant->"Italic"],
  StyleBox[").",
    FontSlant->"Italic"],
  " This definition obviously is completely congruent with the other one: ",
  StyleBox[
  "We discuss a gamma function to be each monogene function fulfilling the \
functional equation (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation15"],
    FontSlant->"Italic"],
  StyleBox[
  "), which beyond this has got the above given properties II and III in a \
certain parallel stripe ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Alpha] \[LessEqual] Re[z] \[LessEqual] \[Alpha] + 1\),
          FontSlant->"Italic"], TraditionalForm]]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "Its complete argumentation to this definition is found only later (\
\[Section]\[Section] ",
  ButtonBox["10",
    ButtonData:>"Section10",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["11",
    ButtonData:>"Section11",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["12",
    ButtonData:>"Section12",
    ButtonStyle->"Hyperlink"],
  ") by the result, that each integral of the form"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
      \(\[Integral]\_L F[z] \(x\^\(-z\)\) \[DifferentialD]z\), \)\)], 
  "Equation"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " being an arbitrary gamma function in the sence above and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " being a fitting integration curvation, is a presentation of a \
hypergeometric function, while also vice versa each hypergeometric function \
can be expressed by such an integral."
}], "Text"],

Cell[TextData[{
  "By reason of the formulae (",
  CounterBox["NumberedEquation", "Equation7"],
  "), (",
  CounterBox["NumberedEquation", "Equation17"],
  ") and (",
  CounterBox["NumberedEquation", "Equation21"],
  ") each gamma function can be expressed by the elementary gamma function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z]\)]],
  "."
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell["\<\
Due to the definition given above obviously all rational and also all \
trigonometric functions belong to the gamma functions.\
\>", "Text",
  ParagraphIndent->30]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". The Behaviour of the Gamma Functions ",
  Cell[BoxData[
      \(TraditionalForm\`F[s + \[ImaginaryI]\ t]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t |  \[Equal] \[Infinity]\)\)]]
}], "Section",
  CellTags->"Section4"],

Cell["\<\
According to the expositions above each gamma function can linearly be \
presented by expressions of the form\
\>", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(G[z]
        \[CenterDot]\(\((
          \(Sin[\[Pi] \((z - c\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
                \[Pi] \((z - c\_p)\)]\)\/\(Sin[\[Pi] \((z - a\_1)\)]
                \[CenterDot]\[CenterDot]\[CenterDot]Sin[
                \[Pi] \((z - a\_\[Mu])\)]\))\).\)\)], "NumberedEquation1",
  CellTags->"Equation21"],

Cell[TextData[{
  "The behaviour of these expressions for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t |  \[Equal] \[Infinity]\)\)]],
  " by use of equation (",
  CounterBox["NumberedEquation", "Equation14"],
  ") can be presented more detailed than done above. The following important \
formulae need to be emphasized especially:"
}], "Text"],

Cell[BoxData[
    \(\(\(|G[z] | 
      \(\( \[Equal] \[ExponentialE]\)\^\(\(-\(\(m + n\)\/2\)\) \[Pi]\  | t | 
              \)\) f[s, t]\); \)\)], "NumberedEquation1",
  CellTags->"Equation23"],

Cell[BoxData[
    \(\(\(|H[z] | 
      \(\( \[Equal] \[ExponentialE]\)\^\(\(-\(\(m - n\)\/2\)\) \[Pi]\  | t | 
              \)\) f[s, t]\); \)\)], "NumberedEquation1",
  CellTags->"Equation24"],

Cell[BoxData[
    \(\(\(|G[z] 
        Sin[\[Pi] \((z - c\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
            \[Pi] \((z - c\_p)\)]\) | 
      \( \[Equal] 
        \(\[ExponentialE]\^\(\(-\((\(m + n\)\/2 - p)\)\) \[Pi]\  | t | \)\) 
        f[s, t]\), \)\)], "NumberedEquation1",
  CellTags->"Equation25"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`f[s, t]\)]],
  " having the form"
}], "Text"],

Cell[BoxData[
    \(f[s, t] \[Equal] |\((z\^\(\((m - n)\) \((s - 1\/2)\) - \[Kappa]\))\) | 
      g[s, t], \ \ \ \ \ \ \ \ \ \ \ 
    \[Kappa] \[Equal] 
      \[Sigma]\_1 + \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(+\[Sigma]\_n\)\) - 
        \[Rho]\_1 - \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\[Rho]\_m\)\), \)], 
  "NumberedEquation1"],

Cell["Correction of misprint:", "Text",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    \(f[s, t] \[Equal] |\((z\^\(\((m - n)\) \((s - 1\/2)\) - \[Kappa]\))\) | 
      g[s, t], \ \ \ \ \ \ \ \ \ \ \ 
    \[Kappa] \[Equal] 
      \[Rho]\_1 + \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(+\[Rho]\_m\)\) - 
        \[Sigma]\_1 - \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\[Sigma]\_n\)\), \)], 
  "Equation",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[TextData[{
  "while ",
  Cell[BoxData[
      \(TraditionalForm\`g[s, t]\)]],
  " stands for a positive variable, which by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  " converges equally to a finite limit, which is not zero and independent of \
",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ", if ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " is confined to an arbitrary finite interval ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[LessEqual] s \[LessEqual] \[Beta]\)]],
  ". Thus the size of ",
  Cell[BoxData[
      \(TraditionalForm\`f[s, t]\)]],
  " can increase or decrease as a finite power of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " at the most."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\[ExponentialE]\^\(\(-\(\(m + n\)\/2\)\) \[Pi]\ Abs[t]\)\) 
                Abs[z\^\(\((m - n)\) \((s - 1\/2)\) - \[Kappa]\)] g[s, t] == 
              \[CapitalGamma][z - \[Rho]\_1] \[CapitalGamma][z - \[Rho]\_m] 
                \[CapitalGamma][1 + \[Sigma]\_1 - z] 
                \[CapitalGamma][1 + \[Sigma]\_n - z] /. \n
            \t{\[CapitalGamma][a_. + b_.  z] \[RuleDelayed] 
                \(\[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) Abs[t]\)\) 
                  Abs[z\^\(a + b\ s - 1\/2\)] \@\(g[s, t]\)\%4, 
              \[Kappa] \[Rule] 
                \[Rho]\_1 + \[Rho]\_m - \[Sigma]\_1 - \[Sigma]\_n}\) //. {
            \(Abs[z\^a_.]\^c_.\) Abs[z\^b_.]\^d_. \[RuleDelayed] 
              Abs[z\^\(a\ c + b\ d\)]}\) /. {m \[Rule] 2, n \[Rule] 2} // 
      Simplify\)], "Input",
  CellTags->"Equation17"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\[ExponentialE]\^\(\(-\(\(m - n\)\/2\)\) \[Pi]\ Abs[t]\)\) 
                Abs[z\^\(\((m - n)\) \((s - 1\/2)\) - \[Kappa]\)] g[s, t] == 
              \(\[CapitalGamma][z - \[Rho]\_1] 
                  \[CapitalGamma][z - \[Rho]\_m]\)\/\(\[CapitalGamma][
                    z - \[Sigma]\_1] \[CapitalGamma][z - \[Sigma]\_n]\) /. \n
            \t{\[CapitalGamma][a_. + b_.  z] \[RuleDelayed] 
                \(\[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) Abs[t]\)\) 
                  Abs[z\^\(a + b\ s - 1\/2\)] \@\(g[s, t]\)\%4, 
              \[Kappa] \[Rule] 
                \[Rho]\_1 + \[Rho]\_m - \[Sigma]\_1 - \[Sigma]\_n}\) //. {
            \(Abs[z\^a_.]\^c_.\) Abs[z\^b_.]\^d_. \[RuleDelayed] 
              Abs[z\^\(a\ c + b\ d\)]}\) /. {m \[Rule] 2, n \[Rule] 2, 
          g[s, t] \[Rule] 1} // Simplify\)], "Input",
  CellTags->"Equation17"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\(\[ExponentialE]\^\(\(-\((\(m + n\)\/2 - p)\)\) \[Pi]\ 
                        Abs[t]\)\) 
                  Abs[z\^\(\((m - n)\) \((s - 1\/2)\) - \[Kappa]\)] 
                  g[s, t] == 
                \[CapitalGamma][z - \[Rho]\_1] \[CapitalGamma][z - \[Rho]\_m] 
                  \[CapitalGamma][1 + \[Sigma]\_1 - z] 
                  \[CapitalGamma][1 + \[Sigma]\_n - z] 
                  Sin[\[Pi] \((z - c\_1)\)] Sin[\[Pi] \((z - c\_p)\)] /. \n
              \t{Sin[\[Pi]\ z_] \[RuleDelayed] 
                  \[Pi]\/\(\[CapitalGamma][z] \[CapitalGamma][1 - z]\)}\) /. 
            \n\t{\[CapitalGamma][a_. + b_.  z] \[RuleDelayed] 
                \(\[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) Abs[t]\)\) 
                  Abs[z\^\(a + b\ s - 1\/2\)] \@\(g[s, t]\)\%4, 
              \[Kappa] \[Rule] 
                \[Rho]\_1 + \[Rho]\_m - \[Sigma]\_1 - \[Sigma]\_n}\) //. {
            \(Abs[z\^a_.]\^c_.\) Abs[z\^b_.]\^d_. \[RuleDelayed] 
              Abs[z\^\(a\ c + b\ d\)]}\) /. {m \[Rule] 2, n \[Rule] 2, 
          p \[Rule] 2, g[s, t] \[Rule] \[Pi]\^2} // Simplify\)], "Input",
  CellTags->"Equation17"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". The Behaviour of the Gamma Functions ",
  Cell[BoxData[
      \(TraditionalForm\`F[s + \[ImaginaryI]\ t]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|s |  \[Equal] \[Infinity]\)\)]]
}], "Section",
  CellTags->"Section5"],

Cell[TextData[{
  "By iterated application of equation (",
  CounterBox["NumberedEquation", "Equation15"],
  ") results"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(F[z + k] \[Equal] 
      \(\[PlusMinus]R[z]\) 
        R[z + 1]\[CenterDot]\[CenterDot]\[CenterDot]R[z + k - 1] F[z]\)], 
  "NumberedEquation1",
  CellTags->"Equation27"],

Cell["and from this", "Text"],

Cell[BoxData[
    \(F[z - k] \[Equal] 
      \(\[PlusMinus]\(\((
            F[z]\/\(R[z - 1] 
                R[z - 2]\[CenterDot]\[CenterDot]\[CenterDot]R[z - k]\))\).
          \)\)\)], "NumberedEquation1",
  CellTags->"Equation28"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Flatten[
          Solve[F[z + k] == 
                \(\[PlusMinus]R[z]\) R[z + 1] R[z + k - 1] F[z] /. {
                z \[Rule] z - k}, F[z - k]]] /. Rule \[Rule] Equal // First
      \)], "Input"],

Cell[BoxData[
    \(F[\(-k\) + z] == 
      F[z]\/\(\(\[PlusMinus]R[\(-k\) + z]\)\ R[\(-1\) + z]\ R[1 - k + z]\)\)],
   "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the behaviour of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z \[PlusMinus] k]\)]],
  " with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is to be determined in detail."
}], "Text"],

Cell["With the abbreviation", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[Kappa] \[Equal] 
      \[Sigma]\_1 + \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(+\[Sigma]\_n\)\) - 
        \[Rho]\_1 - \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\[Rho]\_m\)\)\)], 
  "NumberedEquation1"],

Cell["Correction of misprint:", "Text",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\[Kappa] \[Equal] 
      \[Rho]\_1 + \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(+\[Rho]\_m\)\) - 
        \[Sigma]\_1 - \ 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\ \(-\[Sigma]\_n\)\)\)], 
  "Equation",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[TextData[{
  "results from equation (",
  CounterBox["NumberedEquation", "Equation16"],
  ")"
}], "Text"],

Cell[BoxData[
    \(Log[R[z]] \[Equal] 
      \((m - n)\) Log[z] - \[Kappa]\/z + 
        \(1\/z\^2\) \(\[GothicCapitalP]\_1[1\/z].\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PowerExpand[
              Log[\(\((z - \[Rho]\_1)\) 
                      \((z - \[Rho]\_m)\)\)\/\(\((z - \[Sigma]\_1)\) 
                      \((z - \[Sigma]\_n)\)\)] /. {
                  \((z - a_)\) \[RuleDelayed] z \((1 - a\/z)\)}] == 
            \((m - n)\) Log[z] - \[Kappa]\/z + 
              \(1\/z\^2\) \[GothicCapitalP]\_1[1\/z] /. {
            Log[1 + x_] \[RuleDelayed] 
              Evaluate[Normal[Series[Log[1 + x], {x, 0, 2}]]], 
            \[Kappa] \[Rule] 
              \[Rho]\_1 + \[Rho]\_m - \[Sigma]\_1 - \[Sigma]\_n}\) /. {
          m \[Rule] 2, n \[Rule] 2, 
          \[GothicCapitalP]\_1[1\/z] \[Rule] 
            \(\[Sigma]\_1\%2 + \[Sigma]\_2\%2 - \[Rho]\_1\%2 - 
                \[Rho]\_2\%2\)\/2} // Simplify\)], "Input",
  CellTags->"Equation16"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Because of", "Text"],

Cell[BoxData[
    \(\[Kappa]\ Log[1 + 1\/z] \[Equal] 
      \[Kappa]\/z + \(1\/z\^2\) \[GothicCapitalP]\_2[1\/z]\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[Series[\[Kappa]\ Log[1 + y], {y, 0, 2}] /. {y \[Rule] 1\/z}] == 
        \[Kappa]\/z + \(1\/z\^2\) \[GothicCapitalP]\_2[1\/z] /. {
        \[GothicCapitalP]\_2[1\/z] \[Rule] \(-\(\[Kappa]\/2\)\)}\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["is also valid", "Text"],

Cell[BoxData[
    \(\(Log[R[z]] \[Equal] 
      \((m - n)\) Log[z] - \[Kappa]\ Log[1 + 1\/z] + 
        \(1\/z\^2\) \[GothicCapitalP][1\/z], \)\)], "Equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(\[GothicCapitalP][x], \[GothicCapitalP]\_1[x], 
      \[GothicCapitalP]\_2[x]\)]],
  " stand for functions, that for sufficient small ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " can be expanded into ordinary power series of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". By replacing ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`z + 1\)]],
  " unto ",
  Cell[BoxData[
      \(TraditionalForm\`z + k - 1\)]],
  " results by addition of the developed equations"
}], "Text"],

Cell[BoxData[
    \(Log[R[z] R[z + 1]\[CenterDot]\[CenterDot]\[CenterDot]R[z + k - 1]] 
      \[Equal] \((m - n)\) 
          Log[z \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + k - 1)
                  \)]\n\t - \[Kappa]\ Log[1 + k\/z] + 
        \[Sum]\+\(\[Nu]\  = \ 0\)\%\(k - 1\)\(1\/\((z + \[Nu])\)\^2\) 
            \(\[GothicCapitalP][1\/\(z + \[Nu]\)].\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(PowerExpand[
                Log[R[z] R[z + 1] R[z + k - 1]] == \n\t\t
                  \((m - n)\) Log[z \((z + 1)\) \((z + k - 1)\)] - 
                    \[Kappa]\ Log[1 + k\/z]] /. \n
              \t{Log[R[z_]] \[RuleDelayed] 
                  \((m - n)\) Log[z] - \[Kappa]\ Log[1 + 1\/z]}\) /. {
              k \[Rule] 3} // \n\tSimplify\) // MapAll[Together, #]&\) // 
      PowerExpand\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["From this follows:", "Text"],

Cell[BoxData[
    \(R[z] R[z + 1]\[CenterDot]\[CenterDot]\[CenterDot]R[z + k - 1] \[Equal] 
      \(\((z \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + k - 1)\))
              \)\^\(m - n\)\) \(\((1 + k\/z)\)\^\(-\[Kappa]\)\) 
        \[ExponentialE]\^\[Phi]\_k[z]\)], "NumberedEquation1",
  CellTags->"Equation30"],

Cell["and", "Text"],

Cell[BoxData[
    \(\(R[z - 1] R[z - 2]\[CenterDot]\[CenterDot]\[CenterDot]R[z - k] 
      \[Equal] \(\((
              \((z - 1)\) 
                \((z - 2)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z - k)\))
              \)\^\(m - n\)\) \(\((1 - k\/z)\)\^\[Kappa]\) 
        \[ExponentialE]\^\[Psi]\_k[z], \)\)], "NumberedEquation1",
  CellTags->"Equation31"],

Cell["with", "Text"],

Cell[BoxData[
    \(\(\[Phi]\_k[z] \[Equal] 
      \[Sum]\+\(\[Nu]\  = \ 0\)\%\(k - 1\)\(1\/\((z + \[Nu])\)\^2\) 
          \[GothicCapitalP][1\/\(z + \[Nu]\)], \)\)], "Equation"],

Cell[BoxData[
    \(\[Psi]\_k[z] \[Equal] 
      \[Sum]\+\(\[Nu]\  = \ 1\)\%k\( 1\/\((z - \[Nu])\)\^2\) 
          \(\[GothicCapitalP][1\/\(z - \[Nu]\)].\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((
              \(\((z \((z + 1)\) \((z + k - 2)\) \((z + k - 1)\))\)\^\(m - n
                        \)\) \((1 + k\/z)\)\^\(-\[Kappa]\) /. {
                  z \[Rule] z - k})\) == 
            \(\((\((z - 1)\) \((z - 2)\) \((z - k + 1)\) \((z - k)\))\)\^\(m
                     - n\)\) \((1 - k\/z)\)\^\[Kappa] /. {k \[Rule] 4} // 
        Simplify\) // MapAll[PowerExpand, #]&\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Because of the importance of ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP][1\/z]\)]],
  " this size has got a regular behaviour for all ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1, \(\[CenterDot]\[CenterDot]\[CenterDot]\), 
      \[Rho]\_m, \[Sigma]\_1, \(\[CenterDot]\[CenterDot]\[CenterDot]\), 
      \[Sigma]\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " not being ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ". As soon as the absolute value of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is greater than the mentioned values, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP][1\/z]\)]],
  " can be expanded into positive powers of ",
  Cell[BoxData[
      \(TraditionalForm\`1\/z\)]],
  ". Therefore if the variable ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is confined to the half plane ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] > a\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " standing for an arbitrary real number, of which plane, if containing any \
of the locations"
}], "Text"],

Cell[BoxData[
    \(z \[Equal] \(-\[Nu]\), \ \ \ \[Rho]\_\[Lambda] - \[Nu], \ \ \ 
    \[Sigma]\_\[Mu] - 
      \[Nu]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        \((\[Nu] \[Equal] 0, 1, 2, \(\[CenterDot]\[CenterDot]\[CenterDot]\))
          \), \)], "Equation"],

Cell[TextData[{
  "arbitrary small circles around these locations are omitted, then results \
analogously to ",
  ButtonBox["\[Section] 2",
    ButtonData:>"Section2",
    ButtonStyle->"Hyperlink"],
  ", that ",
  Cell[BoxData[
      \(TraditionalForm\`\(|\((\[Phi]\_k[z])\) | \)\)]],
  " stays beneath a finite limit being independent of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". In a similar way behaves ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_k[z]\)]],
  " according to the half place ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] < a\)]],
  ". With respect to the equations (",
  CounterBox["NumberedEquation", "Equation27"],
  "), (",
  CounterBox["NumberedEquation", "Equation28"],
  "), (",
  CounterBox["NumberedEquation", "Equation30"],
  "), (",
  CounterBox["NumberedEquation", "Equation31"],
  ") hereby the behaviour of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z + k]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Equal] \(\[PlusMinus]\[Infinity]\)\)]],
  " is given."
}], "Text"],

Cell[TextData[{
  "For the determination of series expansions of hypergeometric functions, \
which can be expressed by certain integrals over gamma functions, the \
following result is needed, which can be found easily from the formulae (",
  CounterBox["NumberedEquation", "Equation30"],
  ") and (",
  CounterBox["NumberedEquation", "Equation31"],
  ")."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If the variable ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is confined to a straight line ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] \[Equal] a\)]],
  ", whereon none of the sizes"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    \(\((R[z \[PlusMinus] k])\)\^\(\[MinusPlus]1
          \)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
      \((k \[Equal] 0, 1, 2, \(\[CenterDot]\[CenterDot]\[CenterDot]\))\)\)], 
  "Equation"],

Cell[TextData[{
  "is equal to zero, then in the case ",
  Cell[BoxData[
      \(TraditionalForm\`m > n\)]],
  " is equally"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(lim\+\(k\  = \ \[Infinity]\)\(F[z - k]\/F[z]\) x\^k \[Equal] 
      lim\+\(k\  = \ \[Infinity]\)x\^k
            \/\(R[z - 1]\[CenterDot]\[CenterDot]\[CenterDot]R[z - k]\) 
      \[Equal] 0\)], "NumberedEquation1"],

Cell[TextData[{
  "for each fixed value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". With ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Equal] n\)]],
  " this formula is valid for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  < 1\)\)]],
  ", and the formula"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(lim\+\(k\  = \ \[Infinity]\)\(F[z + k]\/F[z]\) x\^\(-k\) \[Equal] 
      lim\+\(k\  = \ 
            \[Infinity]\)R[z]\[CenterDot]\[CenterDot]\[CenterDot]R[z + k - 1] 
          x\^\(-k\) \[Equal] 0\)], "NumberedEquation1"],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  > 1\)\)]],
  "."
}], "Text",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z - k]\/Gamma[z] /. {k \[Rule] 5} // FunctionExpand\)], "Input"],

Cell[BoxData[
    \(1\/\(\((\(-5\) + z)\)\ \((\(-4\) + z)\)\ \((\(-3\) + z)\)\ 
        \((\(-2\) + z)\)\ \((\(-1\) + z)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Limit[
      \(\((Gamma[z - k]\/Gamma[z])\)\^\(m - n\)\) \(x\^k\) 
        \((1 - k\/z)\)\^\[Kappa], k \[Rule] \[Infinity]]\), 
    \(% /. {m \[Rule] n + 1}\)}], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["E", 
        RowBox[{\((m - n)\), " ", 
          InterpretationBox[\( - \[Infinity]\),
            DirectedInfinity[ -1]]}]], " ", 
      \(\((\[Pi]\/2)\)\^\(m\/2 - n\/2\)\), " ", \(z\^\(-\[Kappa]\)\), " ", \((
      Cos[\[Pi]\ \[Kappa]] + I\ Sin[\[Pi]\ \[Kappa]])\)}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[
      \(\(x\^k\) \((1 - k\/z)\)\^\[Kappa]\)\/\(\(\((\(-1\))\)\^k\) \(k!\)\), 
      k \[Rule] \[Infinity]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Limit[\(x\^k\) \((1 - k\/z)\)\^\[Kappa], k \[Rule] \[Infinity]]\), 
    \(% /. {Log[x] \[Rule] \(-1\)}\)}], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["E", 
        RowBox[{
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]], " ", \(Sign[Log[x]]\)}]], " ", 
      \(z\^\(-\[Kappa]\)\), " ", \((
      Cos[\[Pi]\ \[Kappa]] + I\ Sin[\[Pi]\ \[Kappa]])\)}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Limit[Log[\(x\^\(-k\)\) \((1 + k\/z)\)\^\(-\[Kappa]\)], 
      k \[Rule] \[Infinity]]\), 
    \(Exp[% /. {Log[x] \[Rule] 1}]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[\(-\[Infinity]\),
        DirectedInfinity[ -1]], " ", \(Log[x]\)}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The case ",
  Cell[BoxData[
      \(TraditionalForm\`m < n\)]],
  " does not need to be mentioned especially, because it always can be \
reduced to the case ",
  Cell[BoxData[
      \(TraditionalForm\`m > n\)]],
  " by a proper substitution."
}], "Text",
  ParagraphIndent->30],

Cell[CellGroupData[{

Cell[BoxData[
    \(G[z] == 
        \[CapitalGamma][z - \[Rho]\_1] \[CapitalGamma][z - \[Rho]\_m] 
          \[CapitalGamma][1 + \[Sigma]\_1 - z] 
          \[CapitalGamma][1 + \[Sigma]\_2 - z] 
          \[CapitalGamma][1 + \[Sigma]\_n - z] /. {z \[Rule] 1 - z}\)], 
  "Input"],

Cell[BoxData[
    \(G[1 - z] == 
      \[CapitalGamma][1 - z - \[Rho]\_1]\ \[CapitalGamma][1 - z - \[Rho]\_m]\ 
        \[CapitalGamma][z + \[Sigma]\_1]\ \[CapitalGamma][z + \[Sigma]\_2]\ 
        \[CapitalGamma][z + \[Sigma]\_n]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". The Connection between the Gamma and the Exponential Function"
}], "Section",
  CellTags->"Section6"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " stands for a point within a rectangle having the edges ",
  Cell[BoxData[
      \(TraditionalForm\`a \[PlusMinus] \[ImaginaryI]\ \[Omega]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b \[PlusMinus] \[ImaginaryI]\ \[Omega]\)]],
  ", that shall lie because of simplification within the half plane ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] > 0\)]],
  ", whereon ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z]\)]],
  " behaves regularly everywhere, then is due to the sentence of Cauchy:"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\[CapitalGamma][s] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[CounterClockwiseContourIntegral]\(\[CapitalGamma][z]\/\(z - s\)\) 
            \[DifferentialD]z\), \)\)], "Equation"],

Cell[TextData[{
  "where the integral is extended in positive direction over the boundary of \
the rectangle. Moreover, the integral is equal to the sum of integrals being \
extended along each of the sides. If now ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are constant, but ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " increasing without limitation, where the sides being parallel to the real \
axis withdraw to infinity, then the integrals being extended along these \
sides draw near the limit null because of equation (",
  CounterBox["NumberedEquation", "Equation11"],
  "), while both of the other integrals also converge to finite limits. With \
the  assumption ",
  Cell[BoxData[
      \(TraditionalForm\`a < b\)]]
}], "Text"],

Cell[BoxData[
    \(\[CapitalGamma][s] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                \[ImaginaryI]\ \[Infinity]\)\(\[CapitalGamma][z]\/\(s - z\)\) 
              \[DifferentialD]z\) + 
        \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(b - \[ImaginaryI]\ \[Infinity]\)\%\(b + 
                \[ImaginaryI]\ \[Infinity]\)\(\[CapitalGamma][z]\/\(z - s\)\) 
              \[DifferentialD]z\), \ \ \ \ \ \ \ \ \ \ \ \ a < Re[z] < b\)], 
  "NumberedEquation1",
  CellTags->"Equation34"],

Cell[TextData[{
  "is also valid. During the integration of the first integral is ",
  Cell[BoxData[
      \(TraditionalForm\`Re[s - z] > 0\)]],
  ", of the last is ",
  Cell[BoxData[
      \(TraditionalForm\`Re[s - z] < 0\)]],
  ". Now depending on the first or last case can be set:"
}], "Text"],

Cell[BoxData[
    \(1\/\(s - z\) \[Equal] 
      \[Integral]\_0\%1\( x\^\(s - z - 1\)\) 
          \[DifferentialD]x\ \ \ \ \ \ \ \ \ \ or\ \ \ \ \ \ \ \ \ \ 
          1\/\(z - s\) \[Equal] 
      \[Integral]\_1\%\[Infinity]\( x\^\(s - z - 1\)\) 
          \(\[DifferentialD]x.\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\( x\^\(s - z - 1\)\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(If[Re[s - z] > 0, 1\/\(s - z\), 
      \[Integral]\_0\%1\( x\^\(\(-1\) + s - z\)\) \[DifferentialD]x]\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_1\%\[Infinity]\( x\^\(s - z - 1\)\) \[DifferentialD]x\)], 
  "Input"],

Cell[BoxData[
    RowBox[{"If", "[", 
      RowBox[{\(Re[\(-s\) + z] > 0\), ",", \(1\/\(\(-s\) + z\)\), ",", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", "1", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\(x\^\(\(-1\) + s - z\)\) \[DifferentialD]x\)}]}], "]"}]], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "If these integrals are introduced to equation (",
  CounterBox["NumberedEquation", "Equation34"],
  "), then follows"
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalGamma][s] \[Equal] 
      \[Integral]\_0\%1\( x\^\(s - 1\)\) 
            \(\[DifferentialD]x\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
            \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                  \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] 
                \(x\^\(-z\)\) \[DifferentialD]z\) + 
        \[Integral]\_1\%\[Infinity]\( x\^\(s - 1\)\) 
            \(\[DifferentialD]x\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
            \(\[Integral]\_\(b - \[ImaginaryI]\ \[Infinity]\)\%\(b + 
                  \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] 
                \(x\^\(-s\)\) \[DifferentialD]z\), \)\)], "NumberedEquation1",\

  CellTags->"Equation35"],

Cell[TextData[{
  "where is presupposed, that the exchange of the integration order is \
allowed, which shall be shown in ",
  ButtonBox["\[Section]",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  " with even more general assupmtions. Beyond this by use of the above \
mentioned rectangle results, that"
}], "Text"],

Cell[BoxData[
    \(\(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
            \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] \(x\^\(-z\)\) 
          \[DifferentialD]z \[Equal] 
      \[Integral]\_\(b - \[ImaginaryI]\ \[Infinity]\)\%\(b + 
            \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] \(x\^\(-z\)\) 
          \[DifferentialD]z; \)\)], "NumberedEquation1",
  CellTags->"Equation36"],

Cell[TextData[{
  "since the integral of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalGamma][z] \(x\^\(-z\)\) \[DifferentialD]z\)]],
  " being extended over the border of the rectangle yields null, because this \
expression behaves within the rectangle and at its border regularly, and the \
integrals being extended along the sides being infinitely afar off disappear \
because of equation (",
  CounterBox["NumberedEquation", "Equation11"],
  "). Now from equation (",
  CounterBox["NumberedEquation", "Equation35"],
  ") follows because of equation (",
  CounterBox["NumberedEquation", "Equation36"],
  ")"
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalGamma][s] \[Equal] 
      \[Integral]\_0\%\[Infinity]\( x\^\(s - 1\)\) 
          \(\[DifferentialD]x\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] \(x\^\(-z\)\) 
              \[DifferentialD]z\) \[Equal] 
      \[Integral]\_0\%\[Infinity] J[x, a] \(x\^\(s - 1\)\) \[DifferentialD]x, 
    \)\)], "NumberedEquation1",
  CellTags->"Equation37"],

Cell["thus we are caused to examine the integral", "Text"],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] \(x\^\(-z\)\) 
            \(\[DifferentialD]z.\)\)\)], "NumberedEquation1",
  CellTags->"Equation38"],

Cell[TextData[{
  "The convergence area of this integral shall be determined more detailed in \
",
  ButtonBox["\[Section]",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ". Here it is enough to know, that because of equation (",
  CounterBox["NumberedEquation", "Equation11"],
  ") it converges at least for all real positive ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[CapitalGamma][s + \[ImaginaryI]\ t] 
        x\^\(-\((s + \[ImaginaryI]\ t)\)\) /. {
        \[CapitalGamma][z_] \[RuleDelayed] 
          \(\[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) t\)\) \(t\^\(s - 1\/2\)\) 
            \((\@\(2  \[Pi]\) + \[Epsilon])\)}\), 
    \(Limit[%, t \[Rule] \[Infinity]]\)}], "Input"],

Cell[BoxData[
    \(E\^\(-\(\(\[Pi]\ t\)\/2\)\)\ t\^\(\(-\(1\/2\)\) + s\)\ 
      x\^\(\(-s\) - I\ t\)\ \((\@\(2\ \[Pi]\) + \[Epsilon])\)\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If we compare ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`a > 0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, 1\/2 - n]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is a positive integer number, then by application of Cauchy's sentence in \
the way given above results the formula"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(J[x, a] \[Equal] 
      \[Sum]\+\(\[Nu]\  = \ 0\)\%\(n - 1\)\((\(-x\))\)\^\[Nu]\/\(\[Nu]!\) + 
        J[x, 1\/2 - n], \)\)], "NumberedEquation1",
  CellTags->"Equation39"],

Cell[TextData[{
  "because the residuum of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z] x\^\(-z\)\)]],
  " connected to the pole ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] \(-\[Nu]\)\)]],
  " is because of ",
  Cell[BoxData[
      \(TraditionalForm
      \`lim\+\(z\  \[Equal] \ 0\)z\ \[CapitalGamma][z] \[Equal] 1\)]],
  " and equation (",
  CounterBox["NumberedEquation", "Equation6"],
  ") equal to"
}], "Text"],

Cell[BoxData[
    \(lim\+\(z\  \[Equal] \ \(-\[Nu]\)\)\((z + \[Nu])\) \[CapitalGamma][z] 
          x\^\(-z\) \[Equal] 
      lim\+\(z\  \[Equal] \ \(-\[Nu]\)\)\(\((z + \[Nu])\) 
            \[CapitalGamma][z + \[Nu]] x\^\(-z\)\)\/\(z 
            \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + \[Nu] - 1)
                \)\) \[Equal] \(\((\((\(-x\))\)\^\[Nu]\/\(\[Nu]!\))\).\)\)], 
  "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[z\ Gamma[z], z \[Rule] 0]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Residue[Gamma[z] x\^\(-z\), {z, \(-#\)}]&\)/@Range[0, 7]\)], "Input"],

Cell[BoxData[
    \({1, \(-x\), x\^2\/2, \(-\(x\^3\/6\)\), x\^4\/24, \(-\(x\^5\/120\)\), 
      x\^6\/720, \(-\(x\^7\/5040\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\((z + \[Nu])\) Gamma[z + \[Nu]] x\^\(-z\)\)\/\(z \((z + 1)\) 
            \((z + \[Nu] - 1)\)\) /. {z \[Rule] z - \[Nu]}\) /. {
        \[Nu] \[Rule] 3}\), 
    \(Limit[%, z \[Rule] 0]\)}], "Input"],

Cell[BoxData[
    \(\(x\^\(3 - z\)\ z\ Gamma[z]\)\/\(\((\(-3\) + z)\)\ \((\(-2\) + z)\)\ 
        \((\(-1\) + z)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(x\^3\/6\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "By the substitution ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] 1\/2 - n + \[ImaginaryI]\ t\)]],
  " results"
}], "Text"],

Cell[BoxData[
    \(\(J[x, 1\/2 - n] \[Equal] 
      \(x\^\(n - 1\/2\)\/\(2  \[Pi]\)\) 
        \(\[Integral]\_\(-
              \[Infinity]\)\%\[Infinity]\(\( \[CapitalGamma][
                    1\/2 + \[ImaginaryI]\ t] 
                  x\^\(\(-\[ImaginaryI]\)\ t\)\)\/\(\((
                    1\/2 + \[ImaginaryI]\ t - 1)
                    \)\[CenterDot]\[CenterDot]\[CenterDot]\((
                    1\/2 + \[ImaginaryI]\ t - n)\)\)\) \[DifferentialD]t\), 
    \)\)], "Equation"],

Cell["from which follows", "Text"],

Cell[BoxData[
    \(J[x, 1\/2 - n] < 
      \(x\^\(n - 1\/2\)\/\(\(1\/2\) 
              \((1\/2 + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((
                  1\/2 + n - 1)\)\)\) 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\((
              \(|\[CapitalGamma][1\/2 + \[ImaginaryI]\ t] | \))\) 
            \(\[DifferentialD]t.\)\)\)], "Equation"],

Cell[TextData[{
  "The integral on the right hand side of equation (",
  CounterBox["NumberedEquation", "Equation39"],
  ") therefore reaches with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " the result null, thus ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(-x\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[1\/2 - n + \[ImaginaryI]\ t] == 
          Gamma[1\/2 + \[ImaginaryI]\ t]\/\(\((1\/2 + \[ImaginaryI]\ t - 1)\) 
              \((1\/2 + \[ImaginaryI]\ t - n)\)\) /. {n \[Rule] 2} // 
      FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
  \(J[x, a] == 
        \(\[ImaginaryI]\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[CapitalGamma][
                1\/2 - n + \[ImaginaryI]\ t] 
              \(x\^\(n - 1\/2 - \[ImaginaryI]\ t\)\) \[DifferentialD]t\) /. {
        a \[Rule] 1\/2 - n, 
        \[CapitalGamma][1\/2 - n + \[ImaginaryI]\ t] \[RuleDelayed] 
          \[CapitalGamma][1\/2 + \[ImaginaryI]\ t]
              \/\(\((1\/2 + \[ImaginaryI]\ t - 1)\) 
              \((1\/2 + \[ImaginaryI]\ t - n)\)\)}\), 
  \(\(\(% /. {Integrate \[Rule] Dummy}\) //. {Equal \[Rule] Less, 
          b_\/\((\[ImaginaryI]\ t + a_)\) \[RuleDelayed] b\/a, 
          x\^\(\(-\[ImaginaryI]\)\ t + a_\) \[RuleDelayed] x\^a}\) /. {
        Dummy \[Rule] Integrate}\), 
    RowBox[{"Limit", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", 
          RowBox[{\(Last[%]\), "/.", 
            RowBox[{"{", 
              RowBox[{\(\((1\/2 - n)\) \[Rule] \(n!\)\), ",", 
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox["\[Integral]", 
                      InterpretationBox[\(-\[Infinity]\),
                        DirectedInfinity[ -1]], 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    \(\[CapitalGamma][1\/2 + I\ t] \[DifferentialD]t\)}], 
                  "\[Rule]", "M"}]}], "}"}]}], "]"}], ",", 
        \(n \[Rule] \[Infinity]\)}], "]"}]}], "Input"],

Cell[BoxData[
    RowBox[{\(J[x, 1\/2 - n]\), "==", 
      FractionBox[
        RowBox[{
          SubsuperscriptBox["\[Integral]", 
            InterpretationBox[\(-\[Infinity]\),
              DirectedInfinity[ -1]], 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\(\(x\^\(\(-\(1\/2\)\) + n - I\ t\)\ 
                  \[CapitalGamma][1\/2 + I\ t]\)\/\(\((\(-\(1\/2\)\) + I\ t)
                    \)\ \((1\/2 - n + I\ t)\)\)\) \[DifferentialD]t\)}], 
        \(2\ \[Pi]\)]}]], "Output"],

Cell[BoxData[
    RowBox[{\(J[x, 1\/2 - n]\), "<", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{\(x\^\(\(-\(1\/2\)\) + n\)\), " ", 
            RowBox[{
              SubsuperscriptBox["\[Integral]", 
                InterpretationBox[\(-\[Infinity]\),
                  DirectedInfinity[ -1]], 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\[CapitalGamma][1\/2 + I\ t] \[DifferentialD]t\)}]}], 
          \(\((1\/2 - n)\)\ \[Pi]\)]}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity]\((\(-x\))\)\^\[Nu]\/\(\[Nu]!
            \) == \[ExponentialE]\^\(-x\)\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If in the equations (",
  CounterBox["NumberedEquation", "Equation37"],
  ") and (",
  CounterBox["NumberedEquation", "Equation38"],
  ") is set ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a] \[Equal] \[ExponentialE]\^\(-x\)\)]],
  ", then it has turned out as final result, ",
  StyleBox[
  "that between the gamma and the exponential function exists the remarkable \
reciprocity:",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\[ExponentialE]\^\(-x\) \[Equal] 
              \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                      \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] 
                    \(x\^\(-z\)\) \[DifferentialD]z\), \), 
            \(\(-\(\[Pi]\/2\)\) < Arg[x] < \[Pi]\/2, \ \(a > 0; \)\)},
          {
            \(\[CapitalGamma][z] \[Equal] 
              \[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(-x\)\) 
                  \(x\^\(z - 1\)\) \[DifferentialD]x, \), \(Re[z] > 0.\)}
          }]}]], "NumberedEquation1",
  CellTags->"Equation40"],

Cell[TextData[{
  "From ",
  ButtonBox["\[Section]",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  " will result, that the first integral converges for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " fulfilling the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/2\)\) < Arg[x] < \(+\(\[Pi]\/2\)\)\)]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "Already in the year 1894 the transformations above were the starting point \
of my elaboration ",
  StyleBox[ButtonBox[
  "On the fundamental importance of the sentence of Cauchy for the theories \
of the gamma and the hypergeometric functions",
    ButtonData:>"FootnoteSection6",
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ButtonBox["*)",
    ButtonData:>"FootnoteSection6",
    ButtonStyle->"Hyperlink"],
  ", where, as far as I know, they have been used at the first time."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "*) ",
  StyleBox[
  "\[CapitalUDoubleDot]ber die fundamentale Wichtigkeit des Satzes von Cauchy \
f\[UDoubleDot]r die Theorien der Gamma- und der hypergeometrischen \
Funktionen",
    FontSlant->"Italic"],
  ", Acta Societatis Scientiarum Fennicae. Tom. 21. 1896. Submitted to the \
society on Nov. 19th, 1894."
}], "Text",
  ParagraphIndent->30,
  CellTags->"FootnoteSection6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". The Preceding Method is Applicable to More General Gamma Functions"
}], "Section"],

Cell[TextData[{
  "The method used in the previous section, where the reciprocal formulae (",
  CounterBox["NumberedEquation", "Equation40"],
  ") have been found, obviously is not limited to ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z]\)]],
  " only. At the derivation of formula (",
  CounterBox["NumberedEquation", "Equation37"],
  "), where ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " is defined by equation (",
  CounterBox["NumberedEquation", "Equation38"],
  "), indeed has been made use of the circumstance only, that a stripe being \
parallel to the imaginary axis can be assumed, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z]\)]],
  " behaves regularly and reaches the limit null by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  " according to the formula"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(|\[CapitalGamma][s + \[ImaginaryI]\ t] | 
       \[Equal] 
        \(\[ExponentialE]\^\(\(-\(\[Pi]\/2\)\) | t | \)\) 
          \((\(|t | \))\)\^\(s - 1\/2\) | \@\(2  \[Pi]\) + \[Epsilon] | .
      \)\)], "Equation"],

Cell[TextData[{
  "But at the following discussion expressing the integral ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " by the exponential function, the functional equation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][z]\)]],
  " has been used to determine the series expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "If we now consider e.g. the expressions of ",
  ButtonBox["\[Section]",
    ButtonData:>"Section4",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 4",
    ButtonData:>"Section4",
    ButtonStyle->"Hyperlink"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(G[z], \ H[z], \ 
    G[z] Sin[\[Pi] \((z - c\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
          \[Pi] \((z - c\_p)\)], \)], "NumberedEquation1",
  CellTags->"Equation41"],

Cell[TextData[{
  "by taking within ",
  Cell[BoxData[
      \(TraditionalForm\`H[z]\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`m > n\)]],
  " and within the last expression ",
  Cell[BoxData[
      \(TraditionalForm\`p < \(m + n\)\/2\)]],
  ", then we find, that the absolute value each of these functions because of \
the equations (",
  CounterBox["NumberedEquation", "Equation23"],
  "), (",
  CounterBox["NumberedEquation", "Equation24"],
  "), (",
  CounterBox["NumberedEquation", "Equation25"],
  ") can be brought to the form"
}], "Text"],

Cell[BoxData[
    \(\(\(\[ExponentialE]\^\(\(-\[CurlyTheta]\)\  | t | \)\) f[s, t], \)\)], 
  "Equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyTheta]\)]],
  " stands for a positive constant, while ",
  Cell[BoxData[
      \(TraditionalForm\`f[s, t]\)]],
  " can grow at the most like a finite power of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", if ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " stays between finite borders. A stripe being parallel to the imaginary \
axis obviously can be assumed, indeed in many ways, that the above given \
expressions behave regularly there. For ",
  Cell[BoxData[
      \(TraditionalForm\`H[z]\)]],
  " there is even a half plane of this kind."
}], "Text"],

Cell[TextData[{
  "Now this elucidates, that the method of the previous section can be \
applied to the above given functions (",
  CounterBox["NumberedEquation", "Equation41"],
  "), which we want to name ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  ", thus we yield instead of the formulae (",
  CounterBox["NumberedEquation", "Equation40"],
  ") the following more general ones:"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(F[z] \[Equal] 
      \[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(z - 1\)\) 
          \[DifferentialD]x, \)\)], "NumberedEquation1",
  CellTags->"Equation42"],

Cell[BoxData[
    \(\[CapitalPhi][x] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
            \(\[DifferentialD]z.\)\)\)], "NumberedEquation1",
  CellTags->"Equation43"],

Cell["\<\
By the first formula obviously a considerable amount of integrals is reduced \
to the gamma function, among which Euler's integral of second kind is the \
simplest special case.\
\>", "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[TextData[{
  "The importance of the last formula (",
  CounterBox["NumberedEquation", "Equation43"],
  ") for our theory meanwhile is even much greater than the one of the first. \
Indeed it will turn out, ",
  StyleBox["that the functions ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)],
    FontSlant->"Italic"],
  StyleBox[", yielded by equation (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation43"],
    FontSlant->"Italic"],
  StyleBox[") from the gamma functions, are ",
    FontSlant->"Italic"],
  StyleBox["hypergeometric functions",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "Before we switch to this proof, we want to develop the ",
  StyleBox["law of reciprocity",
    FontSlant->"Italic"],
  " being expressed by the above given formulae, in its full generality. That \
indeed it cannot be limited to gamma functions only, already is evident by \
the fact, that the last formula is valid without use of the functional \
equation of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  "."
}], "Text",
  ParagraphIndent->30]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". Two General Integral Classes and their Reciprocity Law"
}], "Section",
  CellTags->"Section8"],

Cell[TextData[{
  "Further on we understand ",
  Cell[BoxData[
      \(TraditionalForm\`f[s, t]\)]],
  " to be a positive variable, which after multiplication by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[Epsilon]\)\  | t | \)\)]],
  " ",
  StyleBox["equally",
    FontSlant->"Italic"],
  " reaches null with infinitely increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  ", if ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " stays between certain borders, that have to be given in detail in each \
case. Here and further on, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is understood to be an arbitrary small, positive constant."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  StyleBox["Sentence (I.)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)],
    FontSlant->"Italic"],
  StyleBox[" be an analytic function of ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] s + \[ImaginaryI]\ t\)],
    FontSlant->"Italic"],
  StyleBox[
  ", which behaves regularly near each finite location within and at the \
border of a certain parallel stripe being defined by",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[Alpha] \[LessEqual] s \[LessEqual] \[Beta], \ \ \ \ \ \ \ \ \ \ 
    \[Alpha] < \[Beta], \)], "NumberedEquation1",
  CellTags->"Equation44"],

Cell[TextData[{
  "and which within equation (",
  CounterBox["NumberedEquation", "Equation44"],
  ") reaches null with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  " accrding to the formula"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(\(|F[z] | 
       \[Equal] \(\[ExponentialE]\^\(\(-\[CurlyTheta]\)\  | t | \)\) 
        f[s, t]\), \)\)], "NumberedEquation1",
  CellTags->"Equation45"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyTheta]\)]],
  " stands for a certain positive constant, while ",
  Cell[BoxData[
      \(TraditionalForm\`f[s, t]\)]],
  " has got the above given meaning for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[LessEqual] s \[LessEqual] \[Beta]\)]],
  ". Then the integral"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
            \[DifferentialD]z\ \ \ \ \ \ \ \ \ \ \[Alpha]\) \[LessEqual] a 
      \[LessEqual] \[Beta]\)], "NumberedEquation1",
  CellTags->"Equation46"],

Cell[TextData[{
  "converges equally in each area of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(x \[Equal] |x | \) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  
  ", defined by the inequalities"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(-\((\[CurlyTheta] - 2  \[Epsilon])\)\) \[LessEqual] \[Theta] 
      \[LessEqual] \(+\((\[CurlyTheta] - 2  \[Epsilon])\)\), 
    \ \ \ \ \ \ \ \ \ \ 
    \[Epsilon]' \[LessEqual] |x | \( \[LessEqual] \((1\/\[Epsilon]')\)\)\)], 
  "NumberedEquation1",
  CellTags->"Equation47"],

Cell["and also fulfills the fundamental inequatlity", "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(\(|J[x, a] |  < C[a, \[Epsilon]]\  | x\)\(|\^\(-a\)\), \)\)], 
  "NumberedEquation1",
  CellTags->"Equation48"],

Cell[TextData[{
  "for each ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " fulfilling the first condition (",
  CounterBox["NumberedEquation", "Equation47"],
  "), where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a size being independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]'\)]],
  "."
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "To prove this sentence, ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] a + \[ImaginaryI]\ t\)]],
  " is assumed. Then because of the relations (",
  CounterBox["NumberedEquation", "Equation45"],
  ") and (",
  CounterBox["NumberedEquation", "Equation47"],
  ")"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\(|F[z] x\^\(-z\)\) | 
      \( \[LessEqual]  | 
        \(x\(|\^\(-a\)\)\(\[ExponentialE]\^\(\(-2\) \[Epsilon]\  | t | \)\) 
          f[a, t]\)\), \)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Abs[F[z]] x\^\(-z\) /. {z \[Rule] a + \[ImaginaryI]\ Abs[t], 
        x \[Rule] 
          Abs[x] \[ExponentialE]\^\(\[ImaginaryI] 
                \((\[CurlyTheta] - 2  \[Epsilon])\)\)}\), 
    \(\(% /. {
            Abs[F[s_ + \[ImaginaryI]\ t_]] \[RuleDelayed] 
              Exp[\(-\[CurlyTheta]\)\ Abs[t]] f[s, t]} // PowerExpand\) // 
      ExpandAll\), 
    \(% == 
        E\^\(\(-2\)\ \[Epsilon]\ Abs[t]\)\ Abs[x]\^\(-a\)\ f[a, Abs[t]] /. {
        Complex[0, _] \[RuleDelayed] 0}\)}], "Input"],

Cell[BoxData[
    \(\((E\^\(I\ \((\(-2\)\ \[Epsilon] + \[CurlyTheta])\)\))\)\^\(\(-a\) - 
          I\ Abs[t]\)\ Abs[x]\^\(\(-a\) - I\ Abs[t]\)\ 
      Abs[F[a + I\ Abs[t]]]\)], "Output"],

Cell[BoxData[
    \(E\^\(2\ I\ a\ \[Epsilon] - I\ a\ \[CurlyTheta] - 
          2\ \[Epsilon]\ Abs[t]\)\ Abs[x]\^\(\(-a\) - I\ Abs[t]\)\ 
      f[a, Abs[t]]\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". Thus within the series"
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(\[Nu]\  = \ \(-\[Infinity]\)\)\%\(\[Nu]\  = \ 
            \(+\[Infinity]\)\)\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(a + \[ImaginaryI]\ \[Nu]\)\%\(a + 
                \[ImaginaryI] \((\[Nu] + 1)\)\)F[z] \(x\^\(-z\)\) 
              \[DifferentialD]z\) \[Equal] J[x, a]\)], "NumberedEquation1",
  CellTags->"Equation49"],

Cell["\<\
the absolute values of each serial member are equal or less than\
\>", "Text"],

Cell[BoxData[
    \(\(\[Sum]\+\(\[Nu]\  = \ \(-\[Infinity]\)\)\%\(\[Nu]\  = \ 
            \(+\[Infinity]\)\)\(\((\(|x | \))\)\^\(-a\)\) 
          \(\[Integral]\_\[Nu]\%\(\[Nu] + 1
                \)\(\[ExponentialE]\^\(\(-2\) \[Epsilon]\  | t | \)\) f[a, t] 
              \[DifferentialD]t\) \[Equal] 
      \(\((\(|x | \))\)\^\(-a\)\) 
        \(\[Integral]\_\(-
              \[Infinity]\)\%\[Infinity] 
                \[ExponentialE]\^\(\(-\[Epsilon]\)\  | t | 
                  \)\[CenterDot]\[ExponentialE]\^\(\(-\[Epsilon]\)\  | t | \) 
            f[a, t] \[DifferentialD]t\), \)\)], "Equation"],

Cell[TextData[{
  "which because of the mentioned properties of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " has got a finite value being independent of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", except for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x\(|\^\(-a\)\)\)\)]],
  ". From this elucidates the availability of the sentence."
}], "Text"],

Cell[TextData[{
  "Because each member of the in relation (",
  CounterBox["NumberedEquation", "Equation47"],
  ") equally converging series (",
  CounterBox["NumberedEquation", "Equation49"],
  ") is a monogene function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", also the integral ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " in relation (",
  CounterBox["NumberedEquation", "Equation47"],
  ") is a monogene, everywhere there regularly behaving function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". We name this function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If Cauchy's integral sentence is applied due to ",
  ButtonBox["\[Section]",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 6",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  ", the resut is, that ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " fulfilling ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[LessEqual] a \[LessEqual] \[Beta]\)]],
  " represents one and the same function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If the width ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] - \[Alpha]\)]],
  " of the stripe (",
  CounterBox["NumberedEquation", "Equation44"],
  ") is finite, then ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " obviously can be understood to be a constant being dependent of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " only."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "From relation (",
  CounterBox["NumberedEquation", "Equation48"],
  ") results, if ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is any number fulfilling the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[LessEqual] a \[LessEqual] \[Beta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] - \[Alpha]\)]],
  " is finite, that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\(x\^a\) \[CapitalPhi][x]\) | \)\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " within relation (",
  CounterBox["NumberedEquation", "Equation47"],
  ") stays beneath a finite limit:"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(|\(x\^a\) \[CapitalPhi][x]\) | \( < K\), \ \ \ \ \ \ \ \ \ \ 
    \[Alpha] \[LessEqual] a \[LessEqual] \(\[Beta].\)\)], "NumberedEquation1"],

Cell[TextData[{
  StyleBox["Sentence (II.)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Now from this results in the known way, that the integral",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(s - 1\)\) 
        \[DifferentialD]x\)], "NumberedEquation1"],

Cell[TextData[{
  "converges for each value ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Equal] u + \[ImaginaryI]\ v\)]],
  " being located within the stripe ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] < a < \[Beta]\)]],
  ". Now we claim, that this integral is equal to our original function ",
  Cell[BoxData[
      \(TraditionalForm\`F[s]\)]],
  "."
}], "Text",
  FontSlant->"Italic"],

Cell["\<\
For the first we remark, that the integral or the series respectively\
\>", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(J\_1[x, a] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)\(F[z]\/\(z - s\)\) 
            \(x\^\(s - z\)\) \[DifferentialD]z\) \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ \(-\[Infinity]\)\)\%\(v\  = \ 
              \(+\[Infinity]\)\)\[Integral]\_\(a + \[ImaginaryI]\ \[Nu]\)\%\(a
                 + \[ImaginaryI] \((\[Nu] + 1)\)\)\(F[z]\/\(z - s\)\) 
              \(x\^\(s - z\)\) \[DifferentialD]z\), \)\)], "NumberedEquation1",\

  CellTags->"Equation52"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`Re[s] \[NotEqual] a\)]],
  ", obviously within relation (",
  CounterBox["NumberedEquation", "Equation47"],
  ") converges equally at the same reason as the series (",
  CounterBox["NumberedEquation", "Equation49"],
  "). Thus series (",
  CounterBox["NumberedEquation", "Equation52"],
  ") is allowed to be differentiated at each member. Because each member is \
an integral between regular borders, it is allowed to practise the \
differentiation under the integral sign. By this results:"
}], "Text"],

Cell[BoxData[
    \(\(\(\[DifferentialD]\/\[DifferentialD]x\) J\_1[x, a]]\) \[Equal] 
      \(-x\^\(s - 1\)\) \(J[x, a].\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Abs[F[z]]\/\(z - s\)\) x\^\(s - z\) /. {
        z \[Rule] a + \[ImaginaryI]\ Abs[t], 
        x \[Rule] 
          Abs[x] \[ExponentialE]\^\(\[ImaginaryI] 
                \((\[CurlyTheta] - 2  \[Epsilon])\)\)}\), 
    \(\(% /. {1\/\(a - s + \[ImaginaryI]\ _\) \[RuleDelayed] 1\/\(a - s\), 
            Abs[F[s_ + \[ImaginaryI]\ t_]] \[RuleDelayed] 
              Exp[\(-\[CurlyTheta]\)\ Abs[t]] f[s, t]} // PowerExpand\) // 
      Simplify\), 
    \(% /. {Complex[0, _] \[RuleDelayed] 0}\)}], "Input"],

Cell[BoxData[
    \(\(\((E\^\(I\ \((\(-2\)\ \[Epsilon] + \[CurlyTheta])\)\))\)\^\(\(-a\) + s
             - I\ Abs[t]\)\ Abs[x]\^\(\(-a\) + s - I\ Abs[t]\)\ 
        Abs[F[a + I\ Abs[t]]]\)\/\(a - s + I\ Abs[t]\)\)], "Output"],

Cell[BoxData[
    \(\(E\^\(I\ \((a - s)\)\ \((2\ \[Epsilon] - \[CurlyTheta])\) - 
            2\ \[Epsilon]\ Abs[t]\)\ Abs[x]\^\(\(-a\) + s - I\ Abs[t]\)\ 
        f[a, Abs[t]]\)\/\(a - s\)\)], "Output"],

Cell[BoxData[
    \(\(E\^\(\(-2\)\ \[Epsilon]\ Abs[t]\)\ Abs[x]\^\(\(-a\) + s\)\ 
        f[a, Abs[t]]\)\/\(a - s\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_x\((\(F[z]\/\(z - s\)\) x\^\(s - z\))\) == 
        \(-x\^\(s - 1\)\) F[z] x\^\(-z\) // Simplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Because of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] < Re[s] < \[Beta]\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`J\_1[0, \[Alpha]] \[Equal] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`J\_1[\[Infinity], \[Beta]] \[Equal] 0\)]],
  " and thus"
}], "Text"],

Cell[BoxData[
    \(\(\[Integral]\_0\%1 J[x, a] \(x\^\(s - 1\)\) \[DifferentialD]x \[Equal] 
      \(-J\_1[1, \[Alpha]]\) \[Equal] 
      \(-\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\)\) 
        \(\[Integral]\_\(\[Alpha] - 
              \[ImaginaryI]\ \[Infinity]\)\%\(\[Alpha] + 
              \[ImaginaryI]\ \[Infinity]\)\(F[z]\/\(z - s\)\) 
            \[DifferentialD]z\), \)\)], "Equation"],

Cell[BoxData[
    \(\[Integral]\_1\%\[Infinity] J[x, \[Beta]] \(x\^\(s - 1\)\) 
          \[DifferentialD]x \[Equal] J\_1[1, \[Beta]] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(\[Beta] - \[ImaginaryI]\ \[Infinity]\)\%\(\[Beta] + 
              \[ImaginaryI]\ \[Infinity]\)\(F[z]\/\(z - s\)\) 
            \(\[DifferentialD]z.\)\)\)], "Equation"],

Cell["\<\
After these preparations the proof of the above given claim has the following \
shape:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(s - 1\)\) 
          \[DifferentialD]x \[Equal] 
      \[Integral]\_0\%\[Infinity] J[x, a] \(x\^\(s - 1\)\) \[DifferentialD]x\n
       \[Equal] 
      \[Integral]\_0\%1 J[x, a] \(x\^\(s - 1\)\) \[DifferentialD]x + 
        \[Integral]\_1\%\[Infinity] J[x, a] \(x\^\(s - 1\)\) 
            \[DifferentialD]x\n \[Equal] 
      \[Integral]\_0\%1 J[x, \[Alpha]] \(x\^\(s - 1\)\) \[DifferentialD]x + 
        \[Integral]\_1\%\[Infinity] J[x, \[Beta]] \(x\^\(s - 1\)\) 
            \[DifferentialD]x\n \[Equal] 
      \(-\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\)\) 
          \(\[Integral]\_\(\[Alpha] - 
                \[ImaginaryI]\ \[Infinity]\)\%\(\[Alpha] + 
                \[ImaginaryI]\ \[Infinity]\)\(F[z]\/\(z - s\)\) 
              \[DifferentialD]z\) + 
        \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(\[Beta] - 
                \[ImaginaryI]\ \[Infinity]\)\%\(\[Beta] + 
                \[ImaginaryI]\ \[Infinity]\)\(F[z]\/\(z - s\)\) 
              \(\[DifferentialD]z.\)\)\)], "Equation"],

Cell[TextData[{
  "The last expression is equal to the integral, that is extended in positive \
direction over the borders of the stripe (",
  CounterBox["NumberedEquation", "Equation44"],
  ")"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
      \(\[CounterClockwiseContourIntegral]\(F[z]\/\(z - s\)\) 
          \[DifferentialD]z\), \)\)], "Equation"],

Cell[TextData[{
  "which is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`F[s]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Thus between both the functions ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  " consists the reciprocity"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\[CapitalPhi][x] \[Equal] 
              \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                      \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
                    \[DifferentialD]z\), \), 
            \(\(-\[CurlyTheta]\) < Arg[x] < \(+\[CurlyTheta]\), \ 
            \(\[Alpha] \[LessEqual] a \[LessEqual] \[Beta]; \)\)},
          {
            \(F[z] \[Equal] 
              \[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(z - 1\)\) 
                  \[DifferentialD]x, \), \(\[Alpha] < Re[z] < \(\[Beta].\)\)}
          }]}]], "NumberedEquation1"],

Cell[TextData[{
  "Thus for each function ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " having the properties of sentence (I.) the inverse formula is valid"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[GridBox[{
        {\(F[s] \[Equal] 
            \[Integral]\_0\%\[Infinity]\( x\^\(s - 1\)\) 
                \(\[DifferentialD]x\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                      \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
                    \[DifferentialD]z\), \), GridBox[{
              {\(\[Alpha] < Re[s] < \[Beta], \)},
              {\(\[Alpha] \[LessEqual] a \[LessEqual] \(\[Beta].\)\)}
              }]}
        }]], "NumberedEquation1",
  CellTags->"Equation54"],

Cell[TextData[{
  "However, our examination still needs an essential completion. Until now ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " has been an independently defined function, while ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  " has been generated by use of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  ". Now we want to start by an independently defined function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  StyleBox["Sentence (I'.)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)],
    FontSlant->"Italic"],
  StyleBox[
  " be a monogene function, which behaves regularly within and at the border \
of the area being defined by",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(-\[CurlyTheta]\) \[LessEqual] \[Theta] \[LessEqual] 
      \(+\[CurlyTheta]\)\)], "NumberedEquation1",
  CellTags->"Equation55"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm
      \`x \[Equal] |x | \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)]],
  ", where the locations ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] \[Infinity]\)]],
  " are eventually excluded. Further be assumed, that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\(x\^a\) \[CapitalPhi][x]\) | \)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " being an arbitrary number fulfilling ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[LessEqual] a \[LessEqual] \[Beta]\)]],
  " stays beneath a finite limit for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in relation (",
  CounterBox["NumberedEquation", "Equation55"],
  "). Then the integral"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(F[z] \[Equal] 
      \[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(z - 1\)\) 
          \[DifferentialD]x\)], "NumberedEquation1"],

Cell["converges equally within the stripe", "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\[Alpha] + \[Epsilon] \[LessEqual] Re[z] \[LessEqual] 
      \[Beta] - \[Epsilon]\)], "NumberedEquation1"],

Cell[TextData[{
  "and reaches the limit null by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|z |  \[Equal] \) | s + \[ImaginaryI]\ t | \)]],
  " according to the formula"
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(\(|F[z] | 
       \[Equal] 
        \(\[ExponentialE]\^\(\(-\[CurlyTheta]\)\  | t | \)\) f[s, t]\), \)\)],
   "NumberedEquation1",
  CellTags->"Equation58"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " have got their properties given ealier."
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "The convergence of the integral is shown in the known way. The integral \
along the straight line ",
  Cell[BoxData[
      \(TraditionalForm\`0  \[LongDash]R\)]],
  ", the arc ",
  Cell[BoxData[
      \(TraditionalForm
      \`R\[LongDash]R\ 
        \[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[CurlyTheta]\)\)]],
  
  " and the straight line ",
  Cell[BoxData[
      \(TraditionalForm
      \`R\ \(\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ 
              \[CurlyTheta]\)\) \[LongDash]0\)]]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[ContourIntegral]\ 
      \[CapitalPhi][x] \(x\^\(z - 1\)\) \[DifferentialD]x\)], "Equation"],

Cell[TextData[{
  "gives null due to the sentence of Cauchy. Because of ",
  Cell[BoxData[
      \(TraditionalForm\`lim\ \[CapitalPhi][x] x\^a \[Equal] 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] \[Infinity], \ \[Alpha] < a < \[Beta]\)]],
  
  " the part of the integral along the arc reaches null by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ". Thus for ",
  Cell[BoxData[
      \(TraditionalForm\`R \[Equal] \[Infinity]\)]],
  " and by the substitutions ",
  Cell[BoxData[
      \(TraditionalForm
      \`x \[Equal] 
        \(\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ \[CurlyTheta]\)\) 
          \[Tau]\)]],
  " results"
}], "Text"],

Cell[BoxData[GridBox[{
        {\(F[z] \[Equal] 
            \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\ z\)\) 
              \(\[Integral]\_0
                  \%\[Infinity] \[CapitalPhi][
                    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\)\) 
                      \[Tau]] \(\[Tau]\^\(z - 1\)\) \[DifferentialD]\[Tau]\), 
          \), \(F[z] \[Equal] 
            \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[CurlyTheta]\ z\)\) 
              \(\[Integral]\_0
                  \%\[Infinity] \[CapitalPhi][
                    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 
                            \[CurlyTheta]\)\) \[Tau]] \(\[Tau]\^\(z - 1\)\) 
                  \[DifferentialD]\[Tau]\), \)}
        }]], "Equation"],

Cell["and from this", "Text"],

Cell[BoxData[
    \(F[z] \[Equal] 
      \(1\/Sin[\[CurlyTheta]\ z]\) 
        \(\[Integral]\_0
            \%\[Infinity]\(\( \[CapitalPhi][
                    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 
                            \[CurlyTheta]\)\) \[Tau]] - 
                  \[CapitalPhi][
                    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\)\) 
                      \[Tau]]\)\/\(2  \[ImaginaryI]\)\) \(\[Tau]\^\(z - 1\)\) 
            \(\[DifferentialD]\[Tau].\)\)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CapitalPhi][x] \(x\^\(z - 1\)\) x /. {x \[Rule] #}&\)/@{
          \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\)\) \[Tau], 
          \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[CurlyTheta]\)\) \[Tau]}
           // PowerExpand\), 
    \(\(\((
              F[z]\/\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[CurlyTheta]\ z
                      \) - F[z]
                    \/\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\ z\))
              \) == \((
              Last[#]\/\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[CurlyTheta]\ z
                      \) - First[#]
                    \/\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\ z\))\)&
          \)[%] // FullSimplify\), 
    \(Last[%]\/\(2  \[ImaginaryI]\ Sin[\[CurlyTheta]\ z]\) == 
      \(\(\[CapitalPhi][
                \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[CurlyTheta]\)\) 
                  \[Tau]] - 
              \[CapitalPhi][
                \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\)\) \[Tau]]
                \)\/\(2  \[ImaginaryI]\ Sin[\[CurlyTheta]\ z]\)\) 
        \[Tau]\^z\)}], "Input"],

Cell[BoxData[
    \({E\^\(I\ z\ \[CurlyTheta]\)\ \[Tau]\^z\ 
        \[CapitalPhi][E\^\(I\ \[CurlyTheta]\)\ \[Tau]], 
      E\^\(\(-I\)\ z\ \[CurlyTheta]\)\ \[Tau]\^z\ 
        \[CapitalPhi][E\^\(\(-I\)\ \[CurlyTheta]\)\ \[Tau]]}\)], "Output"],

Cell[BoxData[
    \(2\ I\ F[z]\ Sin[z\ \[CurlyTheta]] == 
      \[Tau]\^z\ \((
        \[CapitalPhi][E\^\(\(-I\)\ \[CurlyTheta]\)\ \[Tau]] - 
          \[CapitalPhi][E\^\(I\ \[CurlyTheta]\)\ \[Tau]])\)\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Because ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " is a real positive variable, the absolute value of the integral on the \
right hand side stays with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|t | \)\)]],
  " beneath a finite limit, thus ",
  Cell[BoxData[
      \(TraditionalForm\`\(|F[z] | \)\)]],
  " indeed can be brought to the form (",
  CounterBox["NumberedEquation", "Equation58"],
  "). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(1\/Sin[\[CurlyTheta]\ z]\) 
        \(\[Integral]\_0
            \%\[Infinity]\(\( \[CapitalPhi][
                    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 
                            \[CurlyTheta]\)\) \[Tau]] - 
                  \[CapitalPhi][
                    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyTheta]\)\) 
                      \[Tau]]\)\/\(2  \[ImaginaryI]\)\) \(\[Tau]\^\(z - 1\)\) 
            \[DifferentialD]\[Tau]\) /. {z \[Rule] s + \[ImaginaryI]\ t}\), 
    \(Limit[
      Evaluate[%
           /. {\[Integral]\_0\%\[Infinity] a_ \[DifferentialD]\[Tau] \[Rule] 
              K, \[CurlyTheta] \[Rule] 1}], t \[Rule] \[Infinity]]\)}], 
  "Input"],

Cell[BoxData[
    RowBox[{
    \(-\(1\/2\)\), " ", "I", " ", \(Csc[\((s + I\ t)\)\ \[CurlyTheta]]\), " ",
       
      RowBox[{
        SubsuperscriptBox["\[Integral]", "0", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]], 
        \(\(\[Tau]\^\(\(-1\) + s + I\ t\)\ \((
            \[CapitalPhi][E\^\(\(-I\)\ \[CurlyTheta]\)\ \[Tau]] - 
              \[CapitalPhi][E\^\(I\ \[CurlyTheta]\)\ \[Tau]])\)\) 
          \[DifferentialD]\[Tau]\)}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Sentence (II'.)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Thus according to sentence (I) the integral",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[GridBox[{
        {\(J[x, a] \[Equal] 
            \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                    \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
                  \[DifferentialD]z\)\), \(\ \ \ \ \ \ \ \ \ \ \ \ \ 
          \[Alpha] < a < \[Beta]\)}
        }]], "NumberedEquation1"],

Cell[TextData[{
  "converges for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " fulfilling the condition ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(-\[CurlyTheta]\) < \[Theta] < \(+\[CurlyTheta]\)\)]],
  ". Now we claim, that this integral is equal to our original function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  "."
}], "Text",
  FontSlant->"Italic"],

Cell["With the substitution in the formula", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)\(x\^\(-z\)\) \[DifferentialD]z 
            \(\[Integral]\_0\%\[Infinity] \[CapitalPhi][t] \(t\^\(z - 1\)\) 
                \[DifferentialD]\(t : \)\)\)\)], "Equation"],

Cell[BoxData[
    \(x \[Equal] \[ExponentialE]\^\(\[ImaginaryI]\ u\), \ \ \ \ \ \ \ \ \ \ 
    z \[Equal] \(\[Alpha] + \[Beta]\)\/2 + \[ImaginaryI]\ Log[y], 
    \ \ \ \ \ \ \ \ \ \ t \[Equal] \[ExponentialE]\^\(\[ImaginaryI]\ w\), 
    \ \ \ \ \ \ \ \ \ \ a \[Equal] \(\[Alpha] + \[Beta]\)\/2, \)], "Equation"],

Cell["results", "Text"],

Cell[BoxData[
    \(J[\[ExponentialE]\^\(\[ImaginaryI]\ u\), a] 
        \[ExponentialE]\^\(\(\(\[Alpha] + \[Beta]\)\/2\) \[ImaginaryI]\ u\) 
      \[Equal] \[Integral]\_0\%\[Infinity]\( y\^\(u - 1\)\) 
          \(\[DifferentialD]y\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(\(-\[ImaginaryI]\)\ 
                \[Infinity]\)\%\(\[ImaginaryI]\ \[Infinity]\)\[CapitalPhi][
                \[ExponentialE]\^\(\[ImaginaryI]\ w\)] 
              \(\[ExponentialE]\^\(\(\(\[Alpha] + \[Beta]\)\/2\) 
                    \[ImaginaryI]\ w\)\) \(y\^\(-w\)\) 
              \(\[DifferentialD]w.\)\)\)], "NumberedEquation1",
  CellTags->"Equation61"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[CapitalPhi][t] \(t\^\(z - 1\)\) \[DifferentialD]t == 
              \(-\(1\/\[ImaginaryI]\)\) 
                \[CapitalPhi][\[ExponentialE]\^\(\[ImaginaryI]\ w\)] 
                \(\[ExponentialE]\^\(\(\(\[Alpha] + \[Beta]\)\/2\) 
                      \[ImaginaryI]\ w\)\) \(y\^\(-w\)\) 
                \[DifferentialD]w /. {
              \[DifferentialD]t \[Rule] 
                \(\[ExponentialE]\^\(\[ImaginaryI]\ w\)\) \[ImaginaryI]\ 
                  \[DifferentialD]w, 
              t \[Rule] \[ExponentialE]\^\(\[ImaginaryI]\ w\), 
              z \[Rule] \(\[Alpha] + \[Beta]\)\/2 + \[ImaginaryI]\ Log[y]} // 
          PowerExpand\) // ExpandAll\) // Simplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(1\/\(2  \[Pi]\)\) \(x\^\(-z\)\) \[DifferentialD]z == 
              \(-\(y\^\(u - 1
                          \)\/\[ExponentialE]\^\(\(\(\[Alpha] + \[Beta]\)\/2
                              \) \[ImaginaryI]\ u\)\)\) 
                \[DifferentialD]y\/\(2  \[Pi]\ \[ImaginaryI]\) /. {
              x \[Rule] \[ExponentialE]\^\(\[ImaginaryI]\ u\), 
              \[DifferentialD]z \[Rule] 
                \(\[ImaginaryI]\ \[DifferentialD]y\)\/y, 
              z \[Rule] \(\[Alpha] + \[Beta]\)\/2 + \[ImaginaryI]\ Log[y]} // 
          PowerExpand\) // ExpandAll\) // Simplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Because of the assumptions for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " the expression ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalPhi][\[ExponentialE]\^\(\[ImaginaryI]\ w\)] 
        \[ExponentialE]\^\(\(\(\[Alpha] + \[Beta]\)\/2\) \[ImaginaryI]\ w
            \)\)]],
  " is regular within the stripe ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(-\[CurlyTheta]\) \[LessEqual] Re[w] < \(+\[CurlyTheta]\)\)]],
  " with the absolue value being less than ",
  Cell[BoxData[
      \(TraditionalForm
      \`K\ \[ExponentialE]\^\(\(-\(\(\[Beta] - \[Alpha]\)\/2\)\) | t | \)\)]],
  
  ". Thus for this expression the inversion formula (",
  CounterBox["NumberedEquation", "Equation54"],
  ") is valid, so that the right hand side of equation (",
  CounterBox["NumberedEquation", "Equation61"],
  ") must be equal to ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalPhi][\[ExponentialE]\^\(\[ImaginaryI]\ u\)] 
        \[ExponentialE]\^\(\(\(\[Alpha] + \[Beta]\)\/2\) \[ImaginaryI]\ u
            \)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[CurlyTheta]\) < Re[u] < \(+\[CurlyTheta]\)\)]],
  " and by this ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a] \[Equal] \[CapitalPhi][x]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[CurlyTheta]\) < Arg[x] < \(+\[CurlyTheta]\)\)]],
  
  "."
}], "Text"],

Cell[TextData[{
  "Thus between both the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " consists the reciprocity:"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(F[z] \[Equal] 
              \[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(z - 1\)\) 
                  \[DifferentialD]x, \), \(\[Alpha] < Re[z] < \[Beta]; \)},
          {
            \(\[CapitalPhi][x] \[Equal] 
              \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                      \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
                    \[DifferentialD]x\), \), 
            \(\(-\[CurlyTheta]\) < Arg[x] < \(+\[CurlyTheta]\), \ 
            \[Alpha] < a < \(\[Beta].\)\)}
          }]}]], "NumberedEquation1",
  CellTags->"Equation62"],

Cell["Correction of misprint:", "Text",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(F[z] \[Equal] 
              \[Integral]\_0\%\[Infinity] \[CapitalPhi][x] \(x\^\(z - 1\)\) 
                  \[DifferentialD]x, \), \(\[Alpha] < Re[z] < \[Beta]; \)},
          {
            \(\[CapitalPhi][x] \[Equal] 
              \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                      \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
                    \[DifferentialD]z\), \), 
            \(\(-\[CurlyTheta]\) < Arg[x] < \(+\[CurlyTheta]\), \ 
            \[Alpha] < a < \(\[Beta].\)\)}
          }]}]], "Equation",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[TextData[{
  "Thus for each function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " having the properties of sentence (I'.) the inverse formula is valid"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[GridBox[{
        {\(\[CapitalPhi][t] \[Equal] 
            \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                    \[ImaginaryI]\ \[Infinity]\)\(t\^\(-z\)\) 
                  \[DifferentialD]z 
                  \(\[Integral]\_0\%\[Infinity] \[CapitalPhi][x] 
                      \(x\^\(z - 1\)\) \[DifferentialD]x\)\), \), GridBox[{
              {\(\[Alpha] < a < \[Beta], \)},
              {\(\(-\[CurlyTheta]\) < Arg[t] < \(+\(\[CurlyTheta].\)\)\)}
              }]}
        }]], "NumberedEquation1",
  CellTags->"Equation63"],

Cell[TextData[{
  "If we name by ",
  Cell[BoxData[
      \(TraditionalForm\`\((F)\)\)]],
  " or by ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalPhi])\)\)]],
  " respectively the whole of all functions having the properties of sentence \
(I.) or sentence (I'.) respectively, then due to the elaboration above the \
functions of both classes correspond to each other unequivocally in the \
following way. Each function of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalPhi])\)\)]],
  " is transformed by the first formula (",
  CounterBox["NumberedEquation", "Equation62"],
  ") into a function of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((F)\)\)]],
  ", and also vice versa each function of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((F)\)\)]],
  " is transformed by the last formula (",
  CounterBox["NumberedEquation", "Equation62"],
  ") into a function of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalPhi])\)\)]],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " is changed into ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " by the first formula and then ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " by the last one into ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_1\)]],
  ", then always is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_1[x] \[Equal] \[CapitalPhi][x]\)]],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " is transformed by the last one into ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " and then ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " by the first one into ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  ", then also always is ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1[z] \[Equal] F[z]\)]],
  ". Two functions being coupled to each other by this ",
  StyleBox["reciprocity law",
    FontSlant->"Italic"],
  " suitably can be called ",
  StyleBox["reciprocal",
    FontSlant->"Italic"],
  " or ",
  StyleBox["conjugated",
    FontSlant->"Italic"],
  " functions. The gamma and the exponential function according to ",
  ButtonBox["\[Section] 6",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  " are two such reciprocal functions."
}], "Text",
  ParagraphIndent->30],

Cell["\<\
An immediate consequence of this reciprocity law is the following sentence \
being important when integrating hypergeometric differential equations:\
\>", "Text",
  ParagraphIndent->30],

Cell["\<\
One of two reciprocal functions can be identical to null just if also the \
other one is equal to zero only.\
\>", "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[TextData[{
  "The general results of this section also already occur in my above (",
  ButtonBox["\[Section]",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 6",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  ") mentioned elaboration (\[Section]\[Section] 14 and 29), where as far as \
I know they have been developed for the first time. Have also a look at \
\[Section] 7 of my ",
  ButtonBox["elaboration*)",
    ButtonData:>"Footnote1Section8",
    ButtonStyle->"Hyperlink"],
  " in the Acta Mathematica vol. 25. I have also ",
  ButtonBox["shown**)",
    ButtonData:>"Footnote2Section8",
    ButtonStyle->"Hyperlink"],
  " some years ago, that these results can be transfered completely to \
corresponding functions of several variables."
}], "Text",
  ParagraphIndent->30],

Cell["\<\
The above given formulae certainly are connected to Fourier's integral \
formula, which however I do not want to show in detail on this occasion.\
\>", "Text",
  ParagraphIndent->30],

Cell["\<\
*) \[CapitalUDoubleDot]ber den Zusammenhang zwischen den linearen \
Differential- und Differenzengleichungen (On the Connection between the \
Linear Differential and Difference Equations).\
\>", "Text",
  ParagraphIndent->40,
  CellTags->"Footnote1Section8"],

Cell["\<\
**) Zur Theorie zweier allgemeiner Klassen bestimmter Integrale (On the \
Theory of two General Classes of Definite Integrals). Acta Soc. Sc. Fennicae, \
Tom. 22. 1896.\
\>", "Text",
  ParagraphIndent->30,
  CellTags->"Footnote2Section8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". ",
  "Examples of Conjugated Functions"
}], "Section"],

Cell["\<\
We want to present only the following of the numberless possible examples of \
such functions.\
\>", "Text",
  ParagraphIndent->30],

Cell[TextData[{
  StyleBox["First Example.",
    FontWeight->"Bold"],
  " Because of simplification we assume, that ",
  Cell[BoxData[
      \(TraditionalForm\`Re[s] > 0\)]],
  " and build up the integral"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[GridBox[{
        {\(J[x, a] \[Equal] 
            \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                    \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] 
                  \[CapitalGamma][s - z] \(x\^\(-z\)\) \[DifferentialD]z\), 
          \), GridBox[{
              {\(\(-\[Pi]\) < Arg[x] < \(+\[Pi]\), \)},
              {\(0 < a < \(Re[s].\)\)}
              }]}
        }]], "Equation"],

Cell[TextData[{
  "Similar to ",
  ButtonBox["\[Section]",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 6",
    ButtonData:>"Section6",
    ButtonStyle->"Hyperlink"],
  " results"
}], "Text"],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \[Sum]\+\(\[Nu]\  = \ 0\)\%\(n - 1
              \)\(\[CapitalGamma][s + \[Nu]]\/\(\[Nu]!\)\) 
            \((\(-x\))\)\^\[Nu] + J[x, a - n], \ \ \ \ \ \ \ \ \ \ 
    0 < a < 1.\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@
      \((\(Residue[Gamma[z] Gamma[s - z] x\^\(-z\), {z, \(-#\)}]&\)/@
          Range[0, 4])\)\)], "Input"],

Cell[BoxData[
    \(Gamma[s] - x\ Gamma[1 + s] + 1\/2\ x\^2\ Gamma[2 + s] - 
      1\/6\ x\^3\ Gamma[3 + s] + 1\/24\ x\^4\ Gamma[4 + s]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If we assume ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  < 1\)\)]],
  ", then we yield by the sentence at the end of ",
  ButtonBox["\[Section] 5",
    ButtonData:>"Section5",
    ButtonStyle->"Hyperlink"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`lim\ J[x, a - n] \[Equal] 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Equal] \[Infinity]\)]],
  ". Thus is ",
  Cell[BoxData[
      \(TraditionalForm
      \`J[x, a] \[Equal] \[CapitalGamma][s] \((1 + x)\)\^\(-s\)\)]],
  " and this equality indeed consists because of the equalized convergence of \
",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " not for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  < 1\)\)]],
  " only, but also for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\) < Arg[x] < \(+\[Pi]\)\)]],
  ", i.e. for the whole ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-plane, except for the negative half of the real axis. Thus because of the \
preceding section one gets"
}], "Text"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\[CapitalGamma][s]\/\((1 + x)\)\^s \[Equal] 
              \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                      \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z] 
                    \[CapitalGamma][s - z] \(x\^\(-z\)\) \[DifferentialD]z\), 
            \), \(\(-\[Pi]\) < Arg[x] < \(+\[Pi]\), \n\t\(0 < a < Re[s]; 
            \)\)},
          {
            \(\[CapitalGamma][z] \[CapitalGamma][s - z] \[Equal] 
              \[CapitalGamma][s] 
                \(\[Integral]\_0
                    \%\[Infinity]\( x\^\(z - 1\)\/\((1 + x)\)\^s\) 
                    \[DifferentialD]x\), \), \(0 < Re[z] < \(Re[s].\)\)}
          }]}]], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[s + \[Nu]]\/Gamma[\[Nu] + 1] == 
        Gamma[s] Binomial[s + \[Nu] - 1, \[Nu]] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Gamma[s]\/\((1 + x)\)\^s - 
          Gamma[s] 
            \(\[Sum]\+\(\[Nu]\  = \ 0\)\%N Binomial[s + \[Nu] - 1, \[Nu]] 
                \((\(-x\))\)\^\[Nu]\) // ExpandAll\) // FullSimplify\), 
    \(0 == 
      Limit[Evaluate[% /. {x \[Rule] 1\/2} // Simplify], 
        N \[Rule] \[Infinity]]\)}], "Input"],

Cell[BoxData[
    \(\((\(-x\))\)\^\(1 + N\)\ Gamma[1 + N + s]\ 
      Hypergeometric2F1Regularized[1, 1 + N + s, 2 + N, \(-x\)]\)], "Output"],

Cell[BoxData[
    RowBox[{
    \(Series::"esss"\), \( : \ \), 
      "\<\"Essential singularity encountered in \
\\!\\(Gamma[\\(\\*InterpretationBox[\\(1\\/N + \\((1 + s)\\) + \
\\*InterpretationBox[\\(\\(O[N]\\)\\^3\\), SeriesData[N, 0, List[], -1, 3, \
1]]\\), SeriesData[N, 0, List[1, Plus[1, s]], -1, 3, 1]]\\)]\\).\"\>"}]], 
  "Message"],

Cell[BoxData[
    RowBox[{
    \(Series::"esss"\), \( : \ \), 
      "\<\"Essential singularity encountered in \
\\!\\(Gamma[\\(\\*InterpretationBox[\\(1\\/N + \\((1 + s)\\) + \
\\*InterpretationBox[\\(\\(O[N]\\)\\^3\\), SeriesData[N, 0, List[], -1, 3, \
1]]\\), SeriesData[N, 0, List[1, Plus[1, s]], -1, 3, 1]]\\)]\\).\"\>"}]], 
  "Message"],

Cell[BoxData[
    RowBox[{"0", "==", 
      RowBox[{"Limit", "[", 
        RowBox[{
        \(\((\(-\(1\/2\)\))\)\^\(1 + N\)\ Gamma[1 + N + s]\ 
            Hypergeometric2F1Regularized[1, 1 + N + s, 2 + N, \(-\(1\/2\)\)]
              \), ",", 
          RowBox[{"N", "\[Rule]", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z] Gamma[s - z] == 
        Gamma[s] 
          \(\[Integral]\_0\%\[Infinity]\( x\^\(z - 1\)\/\((x + 1)\)\^s\) 
              \[DifferentialD]x\) /. {
        If[a_, b_, __] \[RuleDelayed] \((Print[a]; b)\)}\)], "Input"],

Cell[BoxData[
    \(Re[s - z] > 0 && Re[z] > 0\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
The last integral changes as everybody knows by a suitable substitution into \
Euler's integral of first kind.\
\>", "Text",
  ParagraphIndent->30],

Cell[TextData[{
  StyleBox["Second Example.",
    FontWeight->"Bold"],
  " If we consider the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  " being defined by the integral"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[GridBox[{
        {\(\[CapitalPhi][x] \[Equal] 
            \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                    \[ImaginaryI]\ \[Infinity]\)\[CapitalGamma][z - \[Rho]\_1]
                     \[CapitalGamma][z - \[Rho]\_2] \(x\^\(-z\)\) 
                  \[DifferentialD]z\)\), GridBox[{
              {\(a > Re[\[Rho]\_1]\)},
              {\(a > Re[\[Rho]\_2]\)}
              }]}
        }]], "NumberedEquation1"],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\) < Arg[x] < \(+\[Pi]\)\)]],
  ", then results in the way described above the steady converging expansion"
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalPhi][x] \[Equal] 
      \(x\^\(-\[Rho]\_1\)\) 
          \(\[Sum]\+\(\[Nu]\  = \ 0
                \)\%\[Infinity]\( \[CapitalGamma][
                    \[Rho]\_1 - \[Rho]\_2 - \[Nu]]\/\(\[Nu]!\)\) 
              \((\(-x\))\)\^\[Nu]\) + 
        \(x\^\(-\[Rho]\_2\)\) 
          \(\[Sum]\+\(\[Nu]\  = \ 0
                \)\%\[Infinity]\( \[CapitalGamma][
                    \[Rho]\_2 - \[Rho]\_1 - \[Nu]]\/\(\[Nu]!\)\) 
              \((\(-x\))\)\^\[Nu]\), \)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@
        \((\(Residue[
                Gamma[z - \[Rho]1] Gamma[z - \[Rho]2] x\^\(-z\), {z, 
                  \[Rho]1 - #}]&\)/@Range[0, 4])\) // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/24\ x\^\(-\[Rho]1\)\ \((
      x\^4\ Gamma[\(-4\) + \[Rho]1 - \[Rho]2] - 
        4\ \((x\^3\ Gamma[\(-3\) + \[Rho]1 - \[Rho]2] - 
              3\ x\^2\ Gamma[\(-2\) + \[Rho]1 - \[Rho]2] + 
              6\ x\ Gamma[\(-1\) + \[Rho]1 - \[Rho]2] - 
              6\ Gamma[\[Rho]1 - \[Rho]2])\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@
        \((\(Residue[
                Gamma[z - \[Rho]1] Gamma[z - \[Rho]2] x\^\(-z\), {z, 
                  \[Rho]2 - #}]&\)/@Range[0, 4])\) // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/24\ x\^\(-\[Rho]2\)\ \((
      x\^4\ Gamma[\(-4\) - \[Rho]1 + \[Rho]2] - 
        4\ \((x\^3\ Gamma[\(-3\) - \[Rho]1 + \[Rho]2] - 
              3\ x\^2\ Gamma[\(-2\) - \[Rho]1 + \[Rho]2] + 
              6\ x\ Gamma[\(-1\) - \[Rho]1 + \[Rho]2] - 
              6\ Gamma[\(-\[Rho]1\) + \[Rho]2])\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x\^\(-\[Rho]\_1\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ 0
              \)\%\[Infinity]\( Gamma[\[Rho]\_1 - \[Rho]\_2 - \[Nu]]\/\(\[Nu]!
                  \)\) \((\(-x\))\)\^\[Nu]\) + 
      \(x\^\(-\[Rho]\_2\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ 0
              \)\%\[Infinity]\( Gamma[\[Rho]\_2 - \[Rho]\_1 - \[Nu]]\/\(\[Nu]!
                  \)\) \((\(-x\))\)\^\[Nu]\)\), 
    \(% // FullSimplify\), 
    \(Gamma[z - \[Rho]\_1]\ Gamma[z - \[Rho]\_2] == 
        \[Integral]\_0\%\[Infinity] % \( x\^\(z - 1\)\) \[DifferentialD]x /. {
        If[a_, b_, __] \[RuleDelayed] \((Print[a]; b)\)}\)}], "Input"],

Cell[BoxData[
    \(\[Pi]\ x\^\(\(-\(\[Rho]\_1\/2\)\) - \[Rho]\_2\/2\)\ 
        BesselI[\(-\[Rho]\_1\) + \[Rho]\_2, 2\ \@x]\ 
        Csc[\[Pi]\ \((\[Rho]\_1 - \[Rho]\_2)\)] + 
      \[Pi]\ x\^\(\(-\(\[Rho]\_1\/2\)\) - \[Rho]\_2\/2\)\ 
        BesselI[\[Rho]\_1 - \[Rho]\_2, 2\ \@x]\ 
        Csc[\[Pi]\ \((\(-\[Rho]\_1\) + \[Rho]\_2)\)]\)], "Output"],

Cell[BoxData[
    \(2\ x\^\(1\/2\ \((\(-\[Rho]\_1\) - \[Rho]\_2)\)\)\ 
      BesselK[\[Rho]\_1 - \[Rho]\_2, 2\ \@x]\)], "Output"],

Cell[BoxData[
    \(Re[z - \[Rho]\_1] > 0\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "whereof elucidates, that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " is closely related to the cylinder and the Bessel functions. If ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1 - \[Rho]\_2\)]],
  " is an integer number, then the expansion has got ",
  Cell[BoxData[
      \(TraditionalForm\`Log[x]\)]],
  " terms. Although the steady converging series expansion must be considered \
to be a more complete expression of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " than the integral, so this one has got an essential advantage instead of \
that one, if the behaviour of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  " for infinite large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is dealt with. From the fundamental inequality (",
  CounterBox["NumberedEquation", "Equation48"],
  "), where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " can be assumed in this case to be arbitrary large, indeed equally \
follows"
}], "Text"],

Cell[BoxData[
    \(lim\ \(x\^k\) \[CapitalPhi][x] \[Equal] 0\)], "Equation"],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] \[Infinity], \ 
      \(-\[Pi]\) + \[Epsilon] \[LessEqual] Arg[x] \[LessEqual] 
        \(+\[Pi]\) - \[Epsilon]\)]],
  ", independently how large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " may be. This remarkable property cannot be seen from the series expansion \
at all."
}], "Text"],

Cell[TextData[{
  "In the case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1 \[Equal] \[Rho]\_2 \[Equal] 0\)]],
  " results for ",
  Cell[BoxData[
      \(TraditionalForm\`a > 0\)]],
  ":"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)\(\[CapitalGamma]\^2\)[z] 
            \(x\^\(-z\)\) \[DifferentialD]z\) \[Equal] 
      2 \(\[Sum]\+\(\[Nu]\  = \ 0
                \)\%\[Infinity]\(\( \[CapitalGamma]'\)[\[Nu] + 1]
                    \/\[CapitalGamma][\[Nu] + 1]\) 
              x\^\[Nu]\/\((\(\[Nu]!\))\)\^2\) - 
        Log[x]\[CenterDot]\(\((
              \[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity] x
                    \^\[Nu]\/\((\(\[Nu]!\))\)\^2)\).\)\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@
      \((\(Residue[\(Gamma[z]\^2\) x\^\(-z\), {z, \(-#\)}]&\)/@Range[0, 4])
        \)\)], "Input"],

Cell[BoxData[
    \(\(-2\)\ EulerGamma - Log[x] - 
      1\/4\ x\^2\ \((\(-3\) + 2\ EulerGamma + Log[x])\) - 
      x\ \((\(-2\) + 2\ EulerGamma + Log[x])\) - 
      1\/108\ x\^3\ \((\(-11\) + 6\ EulerGamma + 3\ Log[x])\) - 
      \(x\^4\ \((\(-25\) + 12\ EulerGamma + 6\ Log[x])\)\)\/3456\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[PartialD]\_\[Nu] Gamma[\[Nu] + 1]\), 
    \(2 \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity] PolyGamma[0, \[Nu] + 1] 
          x\^\[Nu]\/\((\(\[Nu]!\))\)\^2\)\), 
    \(% - 
      Log[x] \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity] x
              \^\[Nu]\/\((\(\[Nu]!\))\)\^2\)\), 
    \(2\ x\^\(1\/2\ \((\(-\[Rho]\_1\) - \[Rho]\_2)\)\)\ 
          BesselK[\[Rho]\_1 - \[Rho]\_2, 2\ \@x] == % /. {
        \[Rho]\_1 \[Rule] 0, \[Rho]\_2 \[Rule] 0}\)}], "Input"],

Cell[BoxData[
    \(Gamma[1 + \[Nu]]\ PolyGamma[0, 1 + \[Nu]]\)], "Output"],

Cell[BoxData[
    \(2\ BesselK[0, 2\ \@x] + BesselI[0, 2\ \@x]\ Log[x]\)], "Output"],

Cell[BoxData[
    \(2\ BesselK[0, 2\ \@x]\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[z]\^2 == 
        \[Integral]\_0\%\[Infinity] 2\ BesselK[0, 2\ \@x] \(x\^\(z - 1\)\) 
            \[DifferentialD]x /. {
        If[a_, b_, __] \[RuleDelayed] \((Print[a]; b)\)}\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Third Example.",
    FontWeight->"Bold"],
  " For the integral"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ 
                \[Infinity]\)\(\[CapitalGamma][\[Sigma] - z]\/\[CapitalGamma][
                  \[Rho] - z]\) \[CapitalGamma][z] \(x\^\(-z\)\) 
            \[DifferentialD]z\), \ \ \ \ \ \ \ \ \ \ 
    \(-\(\[Pi]\/2\)\) < Arg[x] < \(+\(\[Pi]\/2\)\), \)], "NumberedEquation1"],

Cell[TextData[{
  "which we want to consider under the assumption ",
  Cell[BoxData[
      \(TraditionalForm\`0 < a < \[Sigma]\)]],
  ", results on the one hand the steady converging power series"
}], "Text"],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \[Sum]\+\(\[Nu]\  = \ 0
            \)\%\[Infinity]\( \[CapitalGamma][\[Sigma] + \[Nu]]
                \/\[CapitalGamma][\[Rho] + \[Nu]]\) 
          \((\(-x\))\)\^\[Nu]\/\(\[Nu]!\)\)], "NumberedEquation1",
  CellTags->"Equation68"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@
      \((\(Residue[
              \(Gamma[\[Sigma] - z]\/Gamma[\[Rho] - z]\) Gamma[z] x\^\(-z\), {
                z, \(-#\)}]&\)/@Range[0, 4])\)\)], "Input"],

Cell[BoxData[
    \(Gamma[\[Sigma]]\/Gamma[\[Rho]] - 
      \(x\ Gamma[1 + \[Sigma]]\)\/Gamma[1 + \[Rho]] + 
      \(x\^2\ Gamma[2 + \[Sigma]]\)\/\(2\ Gamma[2 + \[Rho]]\) - 
      \(x\^3\ Gamma[3 + \[Sigma]]\)\/\(6\ Gamma[3 + \[Rho]]\) + 
      \(x\^4\ Gamma[4 + \[Sigma]]\)\/\(24\ Gamma[4 + \[Rho]]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Sum]\+\(\[Nu]\  = \ 0
          \)\%\[Infinity]\( Gamma[\[Sigma] + \[Nu]]\/Gamma[\[Rho] + \[Nu]]\) 
        \((\(-x\))\)\^\[Nu]\/\(\[Nu]!\)\), 
    \(\(Gamma[\[Sigma] - z]\/Gamma[\[Rho] - z]\) Gamma[z] == 
        \[Integral]\_0\%\[Infinity] % \( x\^\(z - 1\)\) \[DifferentialD]x /. {
        If[a_, b_, __] \[RuleDelayed] \((Print[a]; b)\)}\)}], "Input"],

Cell[BoxData[
    \(\(Gamma[\[Sigma]]\ Hypergeometric1F1[\[Sigma], \[Rho], \(-x\)]\)\/Gamma[
        \[Rho]]\)], "Output"],

Cell[BoxData[
    \(Re[z] > 0\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "and on the other hand the ",
  StyleBox["asymptotic",
    FontSlant->"Italic"],
  " presentation"
}], "Text"],

Cell[BoxData[
    \(J[x, a] \[Equal] 
      \(x\^\(-\[Sigma]\)\) 
          \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\(n - 1
                \)\(\[CapitalGamma][\[Sigma] + \[Nu]]\/\[CapitalGamma][
                    \[Rho] - \[Sigma] - \[Nu]]\) 
              \((\(-x\))\)\^\(-\[Nu]\)\/\(\[Nu]!\)\) + J[x, a + n], 
    \ \ \ \ \ \ \ \ \ \ \[Sigma] - 1 < a < \[Sigma], \)], "NumberedEquation1",\

  CellTags->"Equation69"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus@@
        \((\(Residue[
                \(Gamma[\[Sigma] - z]\/Gamma[\[Rho] - z]\) Gamma[z] 
                  x\^\(-z\), {z, \[Sigma] + #}]&\)/@Range[0, 4])\) // Simplify
      \)], "Input"],

Cell[BoxData[
    \(1\/24\ x\^\(-\[Sigma]\)\ \((
      \(-\(\(24\ Gamma[\[Sigma]]\)\/Gamma[\[Rho] - \[Sigma]]\)\) + 
        \(\(24\ x\^3\ Gamma[1 + \[Sigma]]\)\/Gamma[\(-1\) + \[Rho] - \[Sigma]]
                 - \(12\ x\^2\ Gamma[2 + \[Sigma]]\)\/Gamma[
                \(-2\) + \[Rho] - \[Sigma]] + 
            \(4\ x\ Gamma[3 + \[Sigma]]\)\/Gamma[\(-3\) + \[Rho] - \[Sigma]]
                 - Gamma[4 + \[Sigma]]\/Gamma[\(-4\) + \[Rho] - \[Sigma]]\)\/x
            \^4)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x\^\(-\[Sigma]\)\) 
      \(\[Sum]\+\(\[Nu]\  = \ 0
            \)\%\[Infinity]\( Gamma[\[Sigma] + \[Nu]]\/Gamma[
                \[Rho] - \[Sigma] - \[Nu]]\) 
          \((\(-x\))\)\^\(-\[Nu]\)\/\(\[Nu]!\)\)\)], "Input"],

Cell[BoxData[
    \(Sum::"div" \( : \ \) "Sum does not converge."\)], "Message"],

Cell[BoxData[
    \(x\^\(-\[Sigma]\)\ 
      \(\[Sum]\+\(\[Nu] = 0\)\%\[Infinity]\( Gamma[\[Sigma] + \[Nu]]\ 
            \((\(-x\))\)\^\(-\[Nu]\)\)\/\(Gamma[\[Rho] - \[Sigma] - \[Nu]]\ 
            \(\[Nu]!\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which shows, how ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " behaves for large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " belonging to the area"
}], "Text"],

Cell[BoxData[
    \(\(-\(\[Pi]\/2\)\) + \[Epsilon] \[LessEqual] Arg[x] \[LessEqual] 
      \[Pi]\/2 - \(\[Epsilon].\)\)], "Equation"],

Cell[TextData[{
  "By use of the fundamental inequality (",
  CounterBox["NumberedEquation", "Equation48"],
  ") namely one finds for the rest member the inequality"
}], "Text"],

Cell[BoxData[
    \(\(\(|J[x, a + n] |  < C[a + n, \[Epsilon]] | x\)\(|\^\(\(-a\) - n\)\).
      \)\)], "NumberedEquation1",
  CellTags->"Equation70"],

Cell[TextData[{
  "From the series (",
  CounterBox["NumberedEquation", "Equation68"],
  ") the property being expressed by the equations (",
  CounterBox["NumberedEquation", "Equation69"],
  ") and (",
  CounterBox["NumberedEquation", "Equation70"],
  ") cannot be seen at all. By use of equation (",
  CounterBox["NumberedEquation", "Equation69"],
  ") can be proved, that ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " has got a finite number of zeros at the most within the discussed area."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". ",
  "Proof to a Sentence of Pincherle"
}], "Section",
  CellTags->"Section10"],

Cell[TextData[{
  "Due to Mr. ",
  StyleBox[ButtonBox["Goursat",
    ButtonData:>"Footnote1Section10",
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  ButtonBox["*)",
    ButtonData:>"Footnote1Section10",
    ButtonStyle->"Hyperlink"],
  " we understand a ",
  StyleBox["hypergeometric differential equation",
    FontSlant->"Italic"],
  " to be each equation of the form"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    RowBox[{
      RowBox[{
      \(\((a\_0 + \(b\_0\) x)\) y\), "+", \(\((a\_1 + \(b\_1\) x)\) x\ y'\), 
        "+", 
        RowBox[{
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((a\_m + \(b\_m\) x)\)\)\), 
          \(x\^m\), 
          SuperscriptBox["y", 
            TagBox[\((m)\),
              Derivative],
            MultilineFunction->None]}]}], "\[Equal]", "0."}]], 
  "NumberedEquation1",
  CellTags->"Equation71"],

Cell[TextData[{
  "Each solution of such an equation we call a ",
  StyleBox["hypergeometric function",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["Now we claim, that the integral", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(y \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_L F[z] \(x\^\(-z\)\) \[DifferentialD]z\), \)\)], 
  "NumberedEquation1",
  CellTags->"Equation72"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " is a gamma function due to ",
  ButtonBox["\[Section]",
    ButtonData:>"Section3",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 3",
    ButtonData:>"Section3",
    ButtonStyle->"Hyperlink"],
  ", under certain assumptions fulfills an equation of the form (",
  CounterBox["NumberedEquation", "Equation71"],
  ")."
}], "Text"],

Cell[TextData[{
  "Before we go to the proof of this sentence, which is a special case of a \
yet more general sentence of Mr. ",
  StyleBox[ButtonBox["Pincherle",
    ButtonData:>"Footnote2Section10",
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  ButtonBox["**)",
    ButtonData:>"Footnote2Section10",
    ButtonStyle->"Hyperlink"],
  ", we want to give the lines ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " in more detail, along which the integration is to be done preferably."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " is such a gamma function, which with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\( | t | \)\)]],
  " reaches zero according to the formula"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\(|F[s + \[ImaginaryI]\ t] | 
       \[Equal] 
        \(\[ExponentialE]\^\(\(-\[CurlyTheta]\)\  | t | \)\) f[s, t]\), \)\)],
   "Equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyTheta]\)]],
  " have got the meaning given in ",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ", then the integration path can be an infinite straight line ",
  Cell[BoxData[
      \(TraditionalForm\`\((a \[PlusMinus] \[ImaginaryI]\ \[Infinity])\)\)]],
  " being vertical to the real axis, which does not go through a pole of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  ". Thus the integral converges within the area given in ",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ", sentence (I.)."
}], "Text"],

Cell[TextData[{
  "However, it is indispensable to use also other integration paths. By ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " we want to understand the broken line, consisting of three straight \
lines,"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[GridBox[{
        {GridBox[{
              {\(\(-\[Infinity]\) + \[ImaginaryI]\ \[Omega]\_2\)},
              {" "}
              }], GridBox[{
              {GridBox[{
                    {\(\( < \(--\(--\(-\(--\(----\)\)\)\)\)\)\ \)},
                   
                     {\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ |\)}
                    }], GridBox[{
                    {\(a + \[ImaginaryI]\ \[Omega]\_2\)},
                    {" "}
                    }]}
              }]},
        {\(\(-\[Infinity]\) + \[ImaginaryI]\ \[Omega]\_1\), GridBox[{
             
               {\( > \(--\(--\(--\(--\(---\)\)\)\)\)\), 
                \(a + \[ImaginaryI]\ \[Omega]\_1\)}
              }]}
        }]], "NumberedEquation1"],

Cell[TextData[{
  "and by ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  " the broken line:"
}], "Text"],

Cell[BoxData[GridBox[{
        {GridBox[{
              {\(a + \[ImaginaryI]\ \[Omega]\_2\)},
              {" "}
              }], GridBox[{
              {GridBox[{
                    {\(\(--\(--\(-\(-\(--\(---\)\)\)\)\)\) < \)},
                   
                     {\(|\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)}
                    }], GridBox[{
                    {\(\[Infinity] + \[ImaginaryI]\ \[Omega]\_2\)},
                    {" "}
                    }]}
              }]},
        {\(a + \[ImaginaryI]\ \[Omega]\_1\), 
          RowBox[{"--", 
            RowBox[{"--", 
              RowBox[{"--", 
                RowBox[{"--", 
                  RowBox[{"--", 
                    RowBox[{"-", GridBox[{
                          {">", \(\[Infinity] + \[ImaginaryI]\ \[Omega]\_1\)}
                          }]}]}]}]}]}]}]}
        }]], "NumberedEquation1"],

Cell[TextData[{
  "The sizes ",
  Cell[BoxData[
      \(TraditionalForm\`a, \[Omega]\_1, \[Omega]\_2\)]],
  ", which give the location of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  ", can be set to what is needed. Neither ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " nor ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  " are allowed to go through a pole of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "By use of the sentence at the end of ",
  ButtonBox["\[Section]",
    ButtonData:>"Section5",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 5",
    ButtonData:>"Section5",
    ButtonStyle->"Hyperlink"],
  " now easily results the following:"
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`m > n\)]],
  ", then equation (",
  CounterBox["NumberedEquation", "Equation72"],
  ") converges equally along a line ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " within the area of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " being defined by the inequalities ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] < |x | \( < \((1\/\[Epsilon])\)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " being an arbitrary small positive size."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Equal] n\)]],
  ", then the integral (",
  CounterBox["NumberedEquation", "Equation72"],
  ") converges equally within the area being defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] < |x | \( < 1 - \[Epsilon]\)\)]],
  ", if it goes along a line ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  ", and also within the area being defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon] < \) | 1\/x | \( < 1 - \[Epsilon]\)\)]],
  
  ", if it goes along a line ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "The case ",
  Cell[BoxData[
      \(TraditionalForm\`m < n\)]],
  " always can be reduced to the case ",
  Cell[BoxData[
      \(TraditionalForm\`m > n\)]],
  " by suitable substitutions."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " in equation (",
  CounterBox["NumberedEquation", "Equation72"],
  ") stands for a line ",
  Cell[BoxData[
      \(TraditionalForm\`\((a \[PlusMinus] \[ImaginaryI]\ \[Infinity])\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  " due to the circumstances, then we want to show, that equation (",
  CounterBox["NumberedEquation", "Equation72"],
  ") within its convergence area gives a hypergeometric function."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "For the first we compare the integral (",
  CounterBox["NumberedEquation", "Equation72"],
  ") to the following one"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(y\_1 \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_L F[z + 1] \(x\^\(\(-z\) - 1\)\) \[DifferentialD]z\), 
    \)\)], "NumberedEquation1",
  CellTags->"Equation75"],

Cell[TextData[{
  "which can be yielded from the first one by a translation of the \
integration path ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] z + 1\)]],
  " being parallel to the real axis, then is due to the sentence of Cauchy"
}], "Text"],

Cell[BoxData[
    \(\(y\_1 \[Equal] y + S, \)\)], "NumberedEquation1",
  CellTags->"Equation76"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " gives the sum of the residua of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z] x\^\(-z\)\)]],
  ", that belong to the poles of ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " being passed by  the translation. If no pole is passed by ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is equal to zero."
}], "Text"],

Cell["Now with the abbreviations", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(f[z] \[Equal] 
      a\_0 - \(a\_1\) z + \(a\_2\) z \((z + 1)\) + 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((\(-1\))\)\^m\)\) \(a\_m\) 
          z \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + m - 1)\), 
    \)\)], "NumberedEquation1"],

Cell[BoxData[
    \(\(g[z] \[Equal] 
      b\_0 - \(b\_1\) \((z + 1)\) + \(b\_2\) \((z + 1)\) \((z + 2)\) + 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((\(-1\))\)\^m\)\) \(b\_m\) 
          \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + m)\), \)\)], 
  "NumberedEquation1"],

Cell[TextData[{
  "results by use of the equations (",
  CounterBox["NumberedEquation", "Equation72"],
  "), (",
  CounterBox["NumberedEquation", "Equation75"],
  ") and (",
  CounterBox["NumberedEquation", "Equation76"],
  "):"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(\(a\_0\) y\), "+", \(\(a\_1\) x\ y'\), "+", 
          RowBox[{
          \(\[CenterDot]\[CenterDot]\[CenterDot]\(+a\_m\)\), \(x\^m\), 
            SuperscriptBox["y", 
              TagBox[\((m)\),
                Derivative],
              MultilineFunction->None]}]}], "\[Equal]", 
        \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_L f[z] F[z] \(x\^\(-z\)\) \[DifferentialD]z\)\)}], 
      ","}]], "Equation"],

Cell[BoxData[
    RowBox[{
      RowBox[{"x", 
        RowBox[{"(", 
          RowBox[{\(\(b\_0\) y\), "+", \(\(b\_1\) x\ y'\), "+", 
            RowBox[{
            \(\[CenterDot]\[CenterDot]\[CenterDot]\(+b\_m\)\), \(x\^m\), 
              SuperscriptBox["y", 
                TagBox[\((m)\),
                  Derivative],
                MultilineFunction->None]}]}], ")"}]}], "\[Equal]", 
      \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_L g[z] F[z + 1] \(x\^\(-z\)\) \[DifferentialD]z\)\n
         - x \(\((
              \(b\_0\) S + \(b\_1\) x\ S' + 
                \(\[CenterDot]\[CenterDot]\[CenterDot]\(+b\_m\)\) \(x\^m\) 
                  S\^\((m)\))\).\)\)}]], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                \(\(a\_0\) y[x]\), "+", \(\(a\_1\) x\ \(y'\)[x]\), "+", 
                  RowBox[{\(a\_m\), \(x\^m\), 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((m)\),
                          Derivative],
                        MultilineFunction->None], "[", "x", "]"}]}]}], 
                "\[Equal]", 
                \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                  \(\[Integral]f[z] F[z] \(x\^\(-z\)\) 
                      \[DifferentialD]z\)\)}], "/.", 
              \({y \[Rule] 
                  Function[x, 
                    \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                      \(\[Integral]F[z] \(x\^\(-z\)\) \[DifferentialD]z\)]}
                \)}], "/.", \({m \[Rule] 2}\)}], "/.", 
          \({\[Integral]a_ \[DifferentialD]z \[RuleDelayed] a}\)}], "/.", 
        \({f[z] \[Rule] a\_0 - \(a\_1\) z + \(a\_2\) z \((z + 1)\)}\)}], "//",
       "Simplify"}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"x", 
                  RowBox[{"(", 
                    RowBox[{
                    \(\(b\_0\) y[x]\), "+", \(\(b\_1\) x\ \(y'\)[x]\), "+", 
                      RowBox[{\(b\_m\), \(x\^m\), 
                        RowBox[{
                          SuperscriptBox["y", 
                            TagBox[\((m)\),
                              Derivative],
                            MultilineFunction->None], "[", "x", "]"}]}]}], 
                    ")"}]}], "\[Equal]", 
                RowBox[{
                \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                    \(\[Integral]g[z] F[z + 1] \(x\^\(-z\)\) 
                        \[DifferentialD]z\)\), "\n", "-", 
                  RowBox[{"x", 
                    RowBox[{"(", 
                      RowBox[{
                      \(\(b\_0\) S[x]\), "+", \(\(b\_1\) x\ \(S'\)[x]\), "+", 
                        
                        RowBox[{\(b\_m\), \(x\^m\), 
                          RowBox[{
                            SuperscriptBox["S", 
                              TagBox[\((m)\),
                                Derivative],
                              MultilineFunction->None], "[", "x", "]"}]}]}], 
                      ")"}]}]}]}], "/.", 
              \({y \[Rule] 
                  Function[x, 
                    \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                        \(\[Integral]F[z + 1] \(x\^\(\(-z\) - 1\)\) 
                            \[DifferentialD]z\) - S[x]]}\)}], "/.", 
            \({m \[Rule] 2}\)}], "/.", 
          \({\[Integral]a_ \[DifferentialD]z \[RuleDelayed] a}\)}], "/.", 
        \({g[z] \[Rule] 
            b\_0 - \(b\_1\) \((z + 1)\) + \(b\_2\) \((z + 1)\) \((z + 2)\)}
          \)}], "//", "Simplify"}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " finally stands for a gamma function fulfilling the equation"
}], "Text"],

Cell[BoxData[
    \(\(f[z] F[z] + g[z] F[z + 1] \[Equal] 0, \)\)], "NumberedEquation1"],

Cell[TextData[{
  "then we get for the function (",
  CounterBox["NumberedEquation", "Equation72"],
  ") the differential equation"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
      \(\((a\_0 + \(b\_0\) x)\) y\), "+", \(\((a\_1 + \(b\_1\) x)\) x\ y'\), 
        "+", 
        RowBox[{
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((a\_m + \(b\_m\) x)\)\)\), 
          \(x\^m\), 
          SuperscriptBox["y", 
            TagBox[\((m)\),
              Derivative],
            MultilineFunction->None]}]}], "\n", "\[Equal]", 
      RowBox[{\(-x\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{\(\(b\_0\) S\), "+", \(\(b\_1\) x\ S'\), "+", 
              RowBox[{
              \(\[CenterDot]\[CenterDot]\[CenterDot]\(+b\_m\)\), \(x\^m\), 
                SuperscriptBox["S", 
                  TagBox[\((m)\),
                    Derivative],
                  MultilineFunction->None]}]}], ")"}], "."}]}]}]], 
  "NumberedEquation1",
  CellTags->"Equation80"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{\(\(a\_0\) y[x]\), "+", \(\(a\_1\) x\ \(y'\)[x]\), "+", 
            RowBox[{\(a\_m\), \(x\^m\), 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((m)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
            \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
              \(\[Integral]f[z] F[z] \(x\^\(-z\)\) \[DifferentialD]z\)\), "+",
             
            RowBox[{"x", 
              RowBox[{"(", 
                RowBox[{
                \(\(b\_0\) y[x]\), "+", \(\(b\_1\) x\ \(y'\)[x]\), "+", 
                  RowBox[{\(b\_m\), \(x\^m\), 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((m)\),
                          Derivative],
                        MultilineFunction->None], "[", "x", "]"}]}]}], 
                ")"}]}], "-", 
            RowBox[{"(", 
              RowBox[{
              \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                  \(\[Integral]g[z] F[z + 1] \(x\^\(-z\)\) 
                      \[DifferentialD]z\)\), "\n", "-", 
                RowBox[{"x", 
                  RowBox[{"(", 
                    RowBox[{
                    \(\(b\_0\) S[x]\), "+", \(\(b\_1\) x\ \(S'\)[x]\), "+", 
                      RowBox[{\(b\_m\), \(x\^m\), 
                        RowBox[{
                          SuperscriptBox["S", 
                            TagBox[\((m)\),
                              Derivative],
                            MultilineFunction->None], "[", "x", "]"}]}]}], 
                    ")"}]}]}], ")"}]}], "==", 
          RowBox[{
          \(\((a\_0 + \(b\_0\) x)\) y[x]\), "+", 
            \(\((a\_1 + \(b\_1\) x)\) x\ \(y'\)[x]\), "+", 
            RowBox[{\((a\_m + \(b\_m\) x)\), \(x\^m\), 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((m)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}]}], "\n", "-", 
            RowBox[{"(", 
              RowBox[{\(-x\), 
                RowBox[{"(", 
                  RowBox[{
                  \(\(b\_0\) S[x]\), "+", \(\(b\_1\) x\ \(S'\)[x]\), "+", 
                    RowBox[{\(b\_m\), \(x\^m\), 
                      RowBox[{
                        SuperscriptBox["S", 
                          TagBox[\((m)\),
                            Derivative],
                          MultilineFunction->None], "[", "x", "]"}]}]}], 
                  ")"}]}], ")"}]}]}], "/.", 
        \({F[z] \[Rule] \(\(-g[z]\)\/f[z]\) F[z + 1]}\)}], "//", 
      "Simplify"}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
The right hand side of this equation can be brought to the form\
\>", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\[Sum]\+\[Nu]\( x\^\[Lambda]\_\[Nu]\) R\_\[Nu][Log[x]], \)\)], 
  "NumberedEquation1",
  CellTags->"Equation81"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " give entire rational functions, while the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " are real or complex numbers. The residua of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z] x\^\(-z\)\)]],
  " namely have got the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[Lambda]\) R[Log[x]]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Residue[
          Gamma[z] Gamma[z + 1] Gamma[z + 2] Gamma[z + 3] x\^\(-z\), {z, 
            \(-#\)}]&\)/@Range[0, 3]\)], "Input"],

Cell[BoxData[
    \({2, x\ \((\(-2\) + 4\ EulerGamma + Log[x])\), 
      \(-\(1\/24\)\)\ x\^2\ \((
        51 - 120\ EulerGamma + 96\ EulerGamma\^2 + 4\ \[Pi]\^2 + 
          6\ \((\(-5\) + 8\ EulerGamma)\)\ Log[x] + 6\ Log[x]\^2)\), 
      \(1\/3888\((
        x\^3\ \((
          6929 - 14508\ EulerGamma + 11232\ EulerGamma\^2 - 
            3456\ EulerGamma\^3 + 468\ \[Pi]\^2 - 432\ EulerGamma\ \[Pi]\^2 - 
            9\ \((403 - 624\ EulerGamma + 288\ EulerGamma\^2 + 12\ \[Pi]\^2)
                \)\ Log[x] - 54\ \((\(-13\) + 12\ EulerGamma)\)\ Log[x]\^2 - 
            54\ Log[x]\^3 + 54\ PolyGamma[2, 1] + 54\ PolyGamma[2, 2] + 
            54\ PolyGamma[2, 3] + 54\ PolyGamma[2, 4])\))\)\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If the integration path ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " has got such a location, that the part of ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " being parallel to the imaginary axis does no pass any pole of ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " by the translation ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] z + 1\)]],
  ", then the differential equation becomes homogeneous due to the above \
given statements."
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[TextData[{
  "If a hypergeometric function is understood, which is suitable, to be any \
solution of a homogeneous or non-homogeneous equation of the form (",
  CounterBox["NumberedEquation", "Equation80"],
  "), where the right hand side can be brought to the form (",
  CounterBox["NumberedEquation", "Equation81"],
  "), then it is to note, that this definition ",
  StyleBox["only seemingly",
    FontSlant->"Italic"],
  " is more general than the former one. ",
  StyleBox["The right hand side (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation81"],
    FontSlant->"Italic"],
  StyleBox[
  ") namely always can be annihilated by alternating multiplication by powers \
of ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FontSlant->"Italic"],
  StyleBox[
  " and differentiations, where the left hand side indeed changes its order, \
but not its form.",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell["*) Annales de l'Ecole Normale, S\[EAcute]r. II. T. 12. 1883.", "Text",
  ParagraphIndent->40,
  CellTags->"Footnote1Section10"],

Cell[TextData[
"**) Sopra una trasformazione delle equazioni differenziali lineari in \
equazioni lineari alle differenze, e viceversa. Rendiconti del R. Istituto \
Lombardo, Serie II, vol. 19, fasc. 12\[LongDash]13. 1886. Sulle funzioni \
ipergeometriche generalizzate. Rend. d. Accad. dei Lincei. Vol. 4, fasc. 12, \
13, S. 792\[LongDash]799. 1888."], "Text",
  ParagraphIndent->30,
  CellTags->"Footnote2Section10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". Each Hypergeometric Differential Equation can be Integrated Completely \
by Use of Gamma Functions"
}], "Section",
  CellTags->"Section11"],

Cell[TextData[{
  "According to the previous section the integral (",
  CounterBox["NumberedEquation", "Equation72"],
  ") always gives a hypergeometric function, with ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " being an arbitrary gamma function and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " being a line ",
  Cell[BoxData[
      \(TraditionalForm\`\((a \[PlusMinus] \[ImaginaryI]\ \[Infinity])\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  " due to the circumstances. Now the further question is, whether vice versa \
also each such function can be presented by equation (",
  CounterBox["NumberedEquation", "Equation72"],
  ")."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "Because of the remarks at the end of the previous section we can confine \
to ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " hypergeometric equations. Now the following can be shown."
}], "Text",
  ParagraphIndent->30],

Cell["There be", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    RowBox[{
      RowBox[{
      \(\((a\_0 + \(b\_0\) x)\) y\), "+", \(\((a\_1 + \(b\_1\) x)\) x\ y'\), 
        "+", 
        RowBox[{
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((a\_m + \(b\_m\) x)\)\)\), 
          \(x\^m\), 
          SuperscriptBox["y", 
            TagBox[\((m)\),
              Derivative],
            MultilineFunction->None]}]}], "\[Equal]", "0"}]], 
  "NumberedEquation1",
  CellTags->"Equation82"],

Cell[TextData[{
  "the differential equation to be integrated. By a simple substitution \
always is possible, that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  " and the ",
  StyleBox["last",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " of the sites ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0, b\_1, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), b\_m\)]],
  ", that are not equal to zero, both are equal to number one. Now is to be \
build up"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
            \(\((a\_0 + \(b\_0\) x)\) y[x]\), "+", 
              \(\((a\_1 + \(b\_1\) x)\) x\ \(y'\)[x]\), "+", 
              RowBox[{\((a\_m + \(b\_m\) x)\), \(x\^m\), 
                RowBox[{
                  SuperscriptBox["y", 
                    TagBox[\((m)\),
                      Derivative],
                    MultilineFunction->None], "[", "x", "]"}]}]}], "/.", 
            \({y \[Rule] Function[{x}, p[A\ x]\/B], x \[Rule] x\/A}\)}], "/.",
           \({m \[Rule] 3}\)}], "//", "PowerExpand"}], "//", "ExpandAll"}]], 
  "Input"],

Cell[BoxData[
    RowBox[{
    \(\(p[x]\ a\_0\)\/B\), "+", \(\(x\ p[x]\ b\_0\)\/\(A\ B\)\), "+", 
      FractionBox[
        RowBox[{"x", " ", \(a\_1\), " ", 
          RowBox[{
            SuperscriptBox["p", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "B"], "+", 
      FractionBox[
        RowBox[{\(x\^2\), " ", \(b\_1\), " ", 
          RowBox[{
            SuperscriptBox["p", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], \(A\ B\)], "+", 
      FractionBox[
        RowBox[{\(x\^3\), " ", \(a\_3\), " ", 
          RowBox[{
            SuperscriptBox["p", 
              TagBox[\((3)\),
                Derivative],
              MultilineFunction->None], "[", "x", "]"}]}], "B"], "+", 
      FractionBox[
        RowBox[{\(x\^4\), " ", \(b\_3\), " ", 
          RowBox[{
            SuperscriptBox["p", 
              TagBox[\((3)\),
                Derivative],
              MultilineFunction->None], "[", "x", "]"}]}], \(A\ B\)]}]], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{b\_3 == A\ B, a\_3 == B}, {A, B}]\)], "Input"],

Cell[BoxData[
    \({{A \[Rule] b\_3\/a\_3, B \[Rule] a\_3}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f[z] \[Equal] 
      a\_0 - \(a\_1\) z + \(a\_2\) z \((z + 1)\) + 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((\(-1\))\)\^m\)\) \(a\_n\) 
          z \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + m - 1)\), 
    \)\)], "NumberedEquation1"],

Cell["Correction of misprint:", "Text",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(f[z] \[Equal] 
      a\_0 - \(a\_1\) z + \(a\_2\) z \((z + 1)\) + 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((\(-1\))\)\^m\)\) \(a\_m\) 
          z \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + m - 1)\), 
    \)\)], "Equation",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(g[z] \[Equal] 
      b\_0 - \(b\_1\) \((z + 1)\) + \(b\_2\) \((z + 1)\) \((z + 2)\) + 
        \(\[CenterDot]\[CenterDot]\[CenterDot]\(+\((\(-1\))\)\^n\)\) \(b\_n\) 
          \((z + 1)\)\[CenterDot]\[CenterDot]\[CenterDot]\((z + n)\), \)\)], 
  "NumberedEquation1"],

Cell["and to be set", "Text"],

Cell[BoxData[
    \(\(f[z] \[Equal] 
      \(\((\(-1\))\)\^m\) \((z - \[Rho]\_1)\) 
        \((z - \[Rho]\_2)\)\[CenterDot]\[CenterDot]\[CenterDot]\((
            z - \[Rho]\_m)\), \)\)], "NumberedEquation1"],

Cell[BoxData[
    \(\(g[z] \[Equal] 
      \(\((\(-1\))\)\^n\) \((z - \[Sigma]\_1)\) 
        \((z - \[Sigma]\_2)\)\[CenterDot]\[CenterDot]\[CenterDot]\((
            z - \[Sigma]\_n)\), \)\)], "NumberedEquation1"],

Cell[BoxData[
    \(\(G[z] \[Equal] 
      \[CapitalGamma][z - \[Rho]\_1]
            \[CenterDot]\[CenterDot]\[CenterDot]\[CapitalGamma][z - \[Rho]\_m]
             \[CapitalGamma][1 + \[Sigma]\_1 - z]
            \[CenterDot]\[CenterDot]\[CenterDot]\[CapitalGamma][
            1 + \[Sigma]\_n - z], \)\)], "NumberedEquation1"],

Cell[BoxData[
    \(\(P[z] \[Equal] 
      Sin[\[Pi] \((z - c\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
            \[Pi] \((z - c\_m)\)] 
        \(\[Sum]\+\(\[Nu]\  = \ 1\)\%m
             C\_\[Nu]\/Sin[\[Pi] \((z - c\_\[Nu])\)]\), \)\)], 
  "NumberedEquation1"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " stands for an undefined, but ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " for defined constants, among them no pair is found, whose difference is \
equal to an integer number."
}], "Text"],

Cell[TextData[{
  "Thus the ",
  StyleBox["general integral",
    FontSlant->"Italic"],
  " of equation (",
  CounterBox["NumberedEquation", "Equation82"],
  ") can be presented in the form"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(y \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_L G[z] P[z] \(x\^\(-z\)\) \[DifferentialD]z\) + 
        R[x, Log[x]], \)\)], "NumberedEquation1"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " stands for a line being suitably choosen among ",
  Cell[BoxData[
      \(TraditionalForm\`\((a \[PlusMinus] \[ImaginaryI]\ \[Infinity])\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Infinity]\))\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+\[Infinity]\))\)\)]],
  ", while ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " stands for a finite sum of the form (",
  CounterBox["NumberedEquation", "Equation81"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
          \(\((a\_0 + \(b\_0\) x)\) y[x]\), "+", 
            \(\((a\_1 + \(b\_1\) x)\) x\ \(y'\)[x]\), "+", 
            RowBox[{\((a\_m + \(b\_m\) x)\), \(x\^m\), 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((m)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "0"}], 
        "/.", \({
          y \[Rule] 
            Function[x, 
              \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
                \(\[Integral]G[z] P[z] \(x\^\(-z\)\) \[DifferentialD]z\)]}
          \)}], "/.", \({m \[Rule] 2}\)}], 
  \(% /. {a__\ \(x\^\[Mu]_.\) \(\[Integral]b_ \[DifferentialD]z\) 
          \[RuleDelayed] a \(\[Integral]b\ \(x\^\[Mu]\) \[DifferentialD]z\)}
        \), \(% /. {
        d__ \((\[Integral]c_ \[DifferentialD]z)\) \((a_ + b_\ x)\) 
          \[RuleDelayed] 
          d\ a \(\[Integral]c \[DifferentialD]z\) + 
            d\ b \(\[Integral]Evaluate[x\ c /. {z \[Rule] z + 1}] 
                  \[DifferentialD]z\)}\), 
  \(\(% /. {\[Integral]a_ \[DifferentialD]z \[RuleDelayed] a}\) /. {
          a\_2 \[Rule] 1, b\_2 \[Rule] 1} // Simplify\), 
  \(% /. {a\_0 + z\ \((1 + z - a\_1)\) \[Rule] 
          \(\((\(-1\))\)\^m\) \((z - \[Rho]\_1)\) \((z - \[Rho]\_m)\), 
        b\_0 + \((1 + z)\)\ \((2 + z - b\_1)\) \[Rule] 
          \(\((\(-1\))\)\^n\) \((z - \[Sigma]\_1)\) \((z - \[Sigma]\_n)\)}\), 
  \(% /. {G[z_] \[RuleDelayed] 
            Gamma[z - \[Rho]\_1] Gamma[z - \[Rho]\_m] 
              Gamma[1 + \[Sigma]\_1 - z] Gamma[1 + \[Sigma]\_n - z]} // 
      FullSimplify\), 
  \(\(% /. {P[z + 1] \[Rule] \(\((\(-1\))\)\^\(m - n + 1\)\) P[z]}\) /. {
        m \[Rule] 2, n \[Rule] 2}\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(I\ \((\[Integral]\(x\^\(-z\)\ G[z]\ P[z]\) \[DifferentialD]z)\)\ 
                \((a\_0 + x\ b\_0)\)\)\/\(2\ \[Pi]\)\)\) + 
        \(I\ x\ \((
            \[Integral]\(x\^\(\(-1\) - z\)\ z\ G[z]\ P[z]\) \[DifferentialD]z)
            \)\ \((a\_1 + x\ b\_1)\)\)\/\(2\ \[Pi]\) + 
        \(I\ x\^2\ \((
            \[Integral]\(x\^\(\(-2\) - z\)\ \((\(-1\) - z)\)\ z\ G[z]\ P[z]\) 
                \[DifferentialD]z)\)\ \((a\_2 + x\ b\_2)\)\)\/\(2\ \[Pi]\) == 
      0\)], "Output"],

Cell[BoxData[
    \(\(-\(\(I\ \((\[Integral]\(x\^\(-z\)\ G[z]\ P[z]\) \[DifferentialD]z)\)\ 
                \((a\_0 + x\ b\_0)\)\)\/\(2\ \[Pi]\)\)\) + 
        \(I\ \((\[Integral]\(x\^\(-z\)\ z\ G[z]\ P[z]\) \[DifferentialD]z)\)\ 
            \((a\_1 + x\ b\_1)\)\)\/\(2\ \[Pi]\) + 
        \(I\ \((\[Integral]\(x\^\(-z\)\ \((\(-1\) - z)\)\ z\ G[z]\ P[z]\) 
                \[DifferentialD]z)\)\ \((a\_2 + x\ b\_2)\)\)\/\(2\ \[Pi]\) == 
      0\)], "Output"],

Cell[BoxData[
    \(\(-\(\(I\ \((\[Integral]\(x\^\(-z\)\ G[z]\ P[z]\) \[DifferentialD]z)\)\ 
                a\_0\)\/\(2\ \[Pi]\)\)\) + 
        \(I\ \((\[Integral]\(x\^\(-z\)\ z\ G[z]\ P[z]\) \[DifferentialD]z)\)\ 
            a\_1\)\/\(2\ \[Pi]\) + 
        \(I\ \((\[Integral]\(x\^\(-z\)\ \((\(-1\) - z)\)\ z\ G[z]\ P[z]\) 
                \[DifferentialD]z)\)\ a\_2\)\/\(2\ \[Pi]\) - 
        \(I\ \((\[Integral]\(x\^\(-z\)\ G[1 + z]\ P[1 + z]\) 
                \[DifferentialD]z)\)\ b\_0\)\/\(2\ \[Pi]\) + 
        \(I\ \((\[Integral]\(x\^\(-z\)\ \((1 + z)\)\ G[1 + z]\ P[1 + z]\) 
                \[DifferentialD]z)\)\ b\_1\)\/\(2\ \[Pi]\) + 
        \(I\ \((\[Integral]\(x\^\(-z\)\ \((\(-2\) - z)\)\ \((1 + z)\)\ 
                  G[1 + z]\ P[1 + z]\) \[DifferentialD]z)\)\ b\_2\)\/\(2\ 
            \[Pi]\) == 0\)], "Output"],

Cell[BoxData[
    \(\(-\(\(I\ x\^\(-z\)\ \((
              G[z]\ P[z]\ \((a\_0 + z\ \((1 + z - a\_1)\))\) + 
                G[1 + z]\ P[1 + z]\ 
                  \((b\_0 + \((1 + z)\)\ \((2 + z - b\_1)\))\))\)\)\/\(2\ 
              \[Pi]\)\)\) == 0\)], "Output"],

Cell[BoxData[
    \(\(-\(\(I\ x\^\(-z\)\ \((
              \((\(-1\))\)\^m\ G[z]\ P[z]\ \((z - \[Rho]\_1)\)\ 
                  \((z - \[Rho]\_m)\) + 
                \((\(-1\))\)\^n\ G[1 + z]\ P[1 + z]\ \((z - \[Sigma]\_1)\)\ 
                  \((z - \[Sigma]\_n)\))\)\)\/\(2\ \[Pi]\)\)\) == 0\)], 
  "Output"],

Cell[BoxData[
    \(\(-\(1\/\(2\ \[Pi]\)\((
          I\ x\^\(-z\)\ Gamma[1 + z - \[Rho]\_1]\ Gamma[1 + z - \[Rho]\_m]\ 
            Gamma[1 - z + \[Sigma]\_1]\ Gamma[1 - z + \[Sigma]\_n]\ 
            \((\((\(-1\))\)\^m\ P[z] + \((\(-1\))\)\^n\ P[1 + z])\))\)\)\) == 
      0\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(P[z + 1] == \(-P[z]\) /. {
          P[z_] \[RuleDelayed] \[Pi]\/Sin[\[Pi] \((z - c\_1)\)]} // 
      FullSimplify\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Indeed by this sentence the theory of the gamma and the hypergeometric \
functions turns out to be a secluded whole, belonging together. The customary \
doctrine of the gamma function and Euler's integrals ist only a fragment of \
this more general theory, whose uniformity is totally sufficient. The \
uniformity is caused by Cauchy's integral theory.\
\>", "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "In this present elaboration I prove my sentence for the most important \
case ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Equal] n\)]],
  " only. As to the left cases I must refer the reader to my ",
  ButtonBox["elaboration in Acta Math. vol. 25",
    ButtonData:>"Footnote1Section8",
    ButtonStyle->"Hyperlink"],
  ". The following proof, which is based on the theory of the reciprocal \
functions, is totally different from the one in Acta Math."
}], "Text",
  ParagraphIndent->30]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". Integration of Hypergeometric Differential Equations in the Remarkable \
Case ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Equal] n\)]]
}], "Section",
  CellTags->"Section12"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Equal] n\)]],
  " for the differential equation (",
  CounterBox["NumberedEquation", "Equation82"],
  ") and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n \[Equal] b\_n \[Equal] 1\)]],
  ", then it has got three sigular locations ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] 0, x \[Equal] \(-1\), 
      x \[Equal] \[Infinity]\)]],
  "."
}], "Text",
  ParagraphIndent->30],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
              \(\((a\_0 + \(b\_0\) x)\) y[x]\), "+", 
                \(\((a\_1 + \(b\_1\) x)\) x\ \(y'\)[x]\), "+", 
                RowBox[{\((1 + x)\), \(x\^m\), 
                  RowBox[{
                    SuperscriptBox["y", 
                      TagBox[\((m)\),
                        Derivative],
                      MultilineFunction->None], "[", "x", "]"}]}]}], "==", 
              "0"}], "/.", \({x \[Rule] #, m \[Rule] 3}\)}], "&"}], "/@", 
        \({\(-1\), 0, \[Infinity]}\)}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{
                RowBox[{\(\((a\_0 - b\_0)\)\ y[\(-1\)]\), "-", 
                  RowBox[{\((a\_1 - b\_1)\), " ", 
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", \(-1\), "]"}]}]}], 
                "==", "0"}]},
            {\(a\_0\ y[0] == 0\)},
            {
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{\(a\_0\), "+", 
                        RowBox[{
                          InterpretationBox["\[Infinity]",
                            DirectedInfinity[ 1]], " ", \(b\_0\)}]}], ")"}], 
                    " ", 
                    RowBox[{"y", "[", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], "]"}]}], "+", 
                  RowBox[{
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]], " ", 
                    RowBox[{"(", 
                      RowBox[{\(a\_1\), "+", 
                        RowBox[{
                          InterpretationBox["\[Infinity]",
                            DirectedInfinity[ 1]], " ", \(b\_1\)}]}], ")"}], 
                    " ", 
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], "]"}]}], "+", 
                  RowBox[{
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]], " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((3)\),
                          Derivative],
                        MultilineFunction->None], "[", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], "]"}]}]}], "==", "0"}]}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ 
              Plus[ 
                Subscript[ a, 0], 
                Times[ -1, 
                  Subscript[ b, 0]]], 
              y[ -1]], 
            Times[ -1, 
              Plus[ 
                Subscript[ a, 1], 
                Times[ -1, 
                  Subscript[ b, 1]]], 
              Derivative[ 1][ y][ -1]]], 0], 
        Equal[ 
          Times[ 
            Subscript[ a, 0], 
            y[ 0]], 0], 
        Equal[ 
          Plus[ 
            Times[ 
              Plus[ 
                Subscript[ a, 0], 
                Times[ 
                  DirectedInfinity[ 1], 
                  Subscript[ b, 0]]], 
              y[ 
                DirectedInfinity[ 1]]], 
            Times[ 
              DirectedInfinity[ 1], 
              Plus[ 
                Subscript[ a, 1], 
                Times[ 
                  DirectedInfinity[ 1], 
                  Subscript[ b, 1]]], 
              Derivative[ 1][ y][ 
                DirectedInfinity[ 1]]], 
            Times[ 
              DirectedInfinity[ 1], 
              Derivative[ 3][ y][ 
                DirectedInfinity[ 1]]]], 0]}]]], "Output"]
}, Open  ]],

Cell["Now in this case the integral", "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    \(y \[Equal] J[x, a] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)G[z] P[z] \(x\^\(-z\)\) 
            \[DifferentialD]z\)\)], "NumberedEquation1",
  CellTags->"Equation90"],

Cell[TextData[{
  "converges within the whole ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-plane except for the negative half of the real axis."
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "Because ",
  Cell[BoxData[
      \(TraditionalForm\`G[z] P[z]\)]],
  " can be linearly presented by ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " expressions of the form"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(G[z] 
      Sin[\[Pi] \((z - c\_1)\)]\[CenterDot]\[CenterDot]\[CenterDot]Sin[
          \[Pi] \((z - c\_\(n - 1\))\)], \)\)], "NumberedEquation1",
  CellTags->"Equation91"],

Cell[TextData[{
  "and the absolte value of this expression due to ",
  ButtonBox["\[Section] 4",
    ButtonData:>"Section4",
    ButtonStyle->"Hyperlink"],
  ", equation (",
  CounterBox["NumberedEquation", "Equation25"],
  ") can be brought to the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[ExponentialE]\^\(\(-\[Pi]\)\  | t | \)\) f[s, t]\)]],
  ", thus equation (",
  CounterBox["NumberedEquation", "Equation90"],
  ") converges equally due to ",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ", sentence (I.) within each area being defined by"
}], "Text"],

Cell[BoxData[
    \(\(-\((\[Pi] - \[Epsilon])\)\) \[LessEqual] Arg[x] \[LessEqual] 
      \(+\((\[Pi] - \[Epsilon])\)\), \ \ \ \ \ \ \ \ \ \ 
    \[Epsilon] < |x | \( < \((1\/\[Epsilon])\)\), \)], "NumberedEquation1"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " stands for an arbitrary small positive number."
}], "Text"],

Cell[TextData[{
  "Due to ",
  ButtonBox["\[Section] 10",
    ButtonData:>"Section10",
    ButtonStyle->"Hyperlink"],
  " integral (",
  CounterBox["NumberedEquation", "Equation90"],
  ") fulfills equation (",
  CounterBox["NumberedEquation", "Equation82"],
  "), if it is possible to locate the integration path ",
  Cell[BoxData[
      \(TraditionalForm\`\((a \[PlusMinus] \[ImaginaryI]\ \[Infinity])\)\)]],
  " in such a way, that it does not pass any pole of ",
  Cell[BoxData[
      \(TraditionalForm\`G[z]\)]],
  " by the translation ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] z + 1\)]],
  ". This always is possible, if the sizes ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " fulfill a certain condition. The poles of ",
  Cell[BoxData[
      \(TraditionalForm\`G[z]\)]],
  " are members within the ",
  Cell[BoxData[
      \(TraditionalForm\`2  n\)]],
  " arithmetical series"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[Rho]\_\[Nu], \[Rho]\_\[Nu] - 1, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Rho]\_\[Nu] - k, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\)\)], "NumberedEquation1"],

Cell[BoxData[
    \(\[Nu] \[Equal] 1, 2, \(\[CenterDot]\[CenterDot]\[CenterDot]\), n, \)], 
  "Equation",
  TextAlignment->Right],

Cell[BoxData[
    \(\[Sigma]\_\[Nu] + 1, \[Sigma]\_\[Nu] + 2, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Sigma]\_\[Nu] + k, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\)\)], "NumberedEquation1"],

Cell[TextData[{
  "namely the concerning pole is ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "-fold, if ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " series contain it. Now, if all locations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1, \[Rho]\_2, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Rho]\_n\)]],
  " are at the left hand side and all locations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_1 + 1, \[Sigma]\_2 + 1, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Sigma]\_n + 1\)]],
  " are at the right hand side of the parallel stripe"
}], "Text"],

Cell[BoxData[
    \(Re[\[Rho]\_\[Nu]] < a \[LessEqual] Re[z] \[LessEqual] a + 1 < 
      Re[\[Sigma]\_\[Nu] + 1], \ \ \ \ \ \ \ \ \ \ \[Nu] \[Equal] 1, 2, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\), n, \)], "NumberedEquation1",
  CellTags->"Equation95"],

Cell[TextData[{
  "then the integration path ",
  Cell[BoxData[
      \(TraditionalForm\`\((a \[PlusMinus] \[ImaginaryI]\ \[Infinity])\)\)]],
  " obviously has got the desired location. But if no such stripe exists for \
the present, then it is possible, as shown in my mentioned elaboration, \
always by simple operations, that the sizes ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho], \[Sigma]\)]],
  " finally fulfill this condition."
}], "Text"],

Cell[TextData[{
  "Thus by this assumption (",
  CounterBox["NumberedEquation", "Equation95"],
  ") the integral (",
  CounterBox["NumberedEquation", "Equation90"],
  ") fulfills the differential equation (",
  CounterBox["NumberedEquation", "Equation82"],
  "). Now the question is, whether it also is able to present the general \
integral of equation (",
  CounterBox["NumberedEquation", "Equation82"],
  "). We can show directly by our theory being developed in ",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ", that this indeed is the case. Since ",
  Cell[BoxData[
      \(TraditionalForm\`G[z] P[z]\)]],
  " can be considered to be a homogeneous function with undefined \
coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " expressions of the form (",
  CounterBox["NumberedEquation", "Equation91"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " is also such a function of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " particular integrals of equation (",
  CounterBox["NumberedEquation", "Equation82"],
  "). These must build up a fundamental system, because otherwise the \
undefined constants could be determined in such a way, that ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " would disappear identically. But from this would follow further on, \
because of the last sentence in ",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ", that also the corresponding reciprocal function ",
  Cell[BoxData[
      \(TraditionalForm\`G[z] P[z]\)]],
  " would disappear identically, i.e. that"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(C\_1\/Sin[\[Pi] \((z - c\_1)\)] + 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\(+C\_n\)\/Sin[
            \[Pi] \((z - c\_n)\)]\)\)], "Equation"],

Cell[TextData[{
  "would be identical to zero, where not all ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " would be equal to zero. Now this is impossible due to the assumption \
concerning ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1, \(\[CenterDot]\[CenterDot]\[CenterDot]\), 
      c\_n\)]],
  ", thus our statement is proven; ",
  StyleBox["thus the integral (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation90"],
    FontSlant->"Italic"],
  StyleBox[") gives the general solution of equation (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation82"],
    FontSlant->"Italic"],
  StyleBox[") under the above given assumption (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation95"],
    FontSlant->"Italic"],
  StyleBox[").",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "Since the convergence area of equation (",
  CounterBox["NumberedEquation", "Equation90"],
  ") concludes the whole ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-plane except for the negative half of the real axis, equation (",
  CounterBox["NumberedEquation", "Equation90"],
  ") has got a valuable advantage over the series expansions being valid for \
the integrals of equation (",
  CounterBox["NumberedEquation", "Equation82"],
  "), which converge only within a limited neighbourhood of the singular \
locations. We will just as well elucidate, what use derives from this."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  "If we compare the integral ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a - k]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a + k]\)]],
  ", which develop from the first one by shifting of the integration path \
both into negative and into positive direction of the real axis, then \
according to the sentence of Cauchy is"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(J[x, a] \[Equal] \[Sum]\+\[Nu] R\_\[Nu] + J[x, a - k], \)\)], 
  "Equation"],

Cell[BoxData[
    \(\(J[x, a] \[Equal] \(-\(\[Sum]\+\[Nu]\((R')\)\_\[Nu]\)\) + J[x, a + k], 
    \)\)], "Equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\_\[Nu]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((R')\)\_\[Nu]\)]],
  " stand for the residua, that belong to the poles between the corresponding \
integration paths. By the sentence at the end of ",
  ButtonBox["\[Section] 5",
    ButtonData:>"Section5",
    ButtonStyle->"Hyperlink"],
  " now easily follows"
}], "Text"],

Cell[BoxData[
    \(\(lim\+\(k\  \[Equal] \ \[Infinity]\)J[x, a - k] \[Equal] 
        0\ \ \ \ \ \ \ \ \ \ for\  | x | \( < 1\), \)\)], "Equation"],

Cell[BoxData[
    \(lim\+\(k\  \[Equal] \ \[Infinity]\)J[x, a + k] \[Equal] 
        0\ \ \ \ \ \ \ \ \ \ for\  | x | \( > 1.\)\)], "Equation"],

Cell[TextData[{
  "Thus for ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " arise two series expansions, the one of which converges for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  < 1\)\)]],
  ", the other one for ",
  Cell[BoxData[
      \(TraditionalForm\`\(|x |  > 1\)\)]],
  ". These series are without or with logarithms depending on the poles of ",
  Cell[BoxData[
      \(TraditionalForm\`G[z] P[z]\)]],
  " being simple or manifold locations of infinity. In the following because \
of shortness we want to deal with the first case only."
}], "Text"],

Cell[TextData[{
  "Until the end we assume, ",
  StyleBox["that among the differences",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[Rho]\_\[Mu] - 
      \[Rho]\_\[Nu]\ \ \ \ \ \ \ \ \ \ and\ \ \ \ \ \ \ \ \ \ 
        \[Sigma]\_\[Mu] - \[Sigma]\_\[Nu]\)], "NumberedEquation1",
  CellTags->"Equation96"],

Cell[TextData[{
  StyleBox["for ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[NotEqual] \[Nu]\)],
    FontSlant->"Italic"],
  StyleBox[" there is no integer number.",
    FontSlant->"Italic"],
  " Further on we assume continually, ",
  StyleBox["that condition (",
    FontSlant->"Italic"],
  StyleBox[CounterBox["NumberedEquation", "Equation95"],
    FontSlant->"Italic"],
  StyleBox[") is fulfilled.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "By assumption (",
  CounterBox["NumberedEquation", "Equation96"],
  ") we can identify the sizes ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1, \(\[CenterDot]\[CenterDot]\[CenterDot]\), 
      c\_n\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`P[z]\)]],
  " either to be ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  ". By this and by considerations being very similar to the ones in ",
  ButtonBox["\[Section] 3",
    ButtonData:>"Section3",
    ButtonStyle->"Hyperlink"],
  " arises the following important ",
  StyleBox["identity:",
    FontSlant->"Italic"]
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(P[z] \[Equal] 
      \[Product]\+\(\[Nu]\  = \ 1\)\%n
           Sin[\[Pi] \((z - \[Rho]\_\[Nu])\)]\/\[Pi]\[CenterDot]\((
            \[Sum]\+\(\[Nu]\  = \ 1\)\%n
                \( \[Pi]\ A\_\[Nu]\)\/Sin[\[Pi] \((z - \[Rho]\_\[Nu])\)])\)\n 
      \[Congruent] 
      \[Product]\+\(\[Nu]\  = \ 1\)\%n
           Sin[\[Pi] \((z - \[Sigma]\_\[Nu])\)]\/\[Pi]\[CenterDot]\(\((
              \[Sum]\+\(\[Nu]\  = \ 1\)\%n
                  \( \[Pi]\ B\_\[Nu]\)\/Sin[\[Pi] \((z - \[Sigma]\_\[Nu])\)])
              \).\)\)], "NumberedEquation1",
  CellTags->"Equation97"],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] \[Rho]\_1, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Rho]\_n\)]],
  " the ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " are expressed linearly by the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  "; with opposite ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] \[Sigma]\_1, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Sigma]\_n\)]],
  " the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " are vice versa expressed linearly by the ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  "."
}], "Text"],

Cell["We get for our fundamental function", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(G[z] \[Equal] 
      \[Product]\+\(\[Nu]\  = \ 1\)\%n
           \[CapitalGamma][z - \[Rho]\_\[Nu]]
            \[CenterDot]\(\[Product]\+\(\[Nu]\  = \ 1\)\%n \[CapitalGamma][
              1 + \[Sigma]\_\[Nu] - z]\)\)], "NumberedEquation1"],

Cell[TextData[{
  "by use of equation (",
  CounterBox["NumberedEquation", "Equation7"],
  ") both of the expressions"
}], "Text"],

Cell[BoxData[
    \(\(G[z] \[Equal] 
      \[ScriptCapitalG][z] 
        \((\[Product]\+\(\[Nu]\  = \ 1\)\%n 
              \[Pi]\/Sin[\[Pi] \((z - \[Rho]\_\[Nu])\)])\) \[Equal] 
      \[ScriptCapitalH][z] 
        \((\[Product]\+\(\[Nu]\  = \ 1\)\%n 
              \[Pi]\/Sin[\[Pi] \((z - \[Sigma]\_\[Nu])\)])\), \)\)], 
  "NumberedEquation1",
  CellTags->"Equation99"],

Cell["where", "Text"],

Cell[BoxData[
    \(\[ScriptCapitalG][z] \[Equal] 
      \((\[Product]\+\(k\  = \ 1\)\%n
             \[CapitalGamma][1 + \[Sigma]\_k - z]\/\[CapitalGamma][
              1 + \[Rho]\_k - z])\), \ \ \ \ \ \ \ \ \ \ 
    \[ScriptCapitalH][z] \[Equal] 
      \(\((\[Product]\+\(k\  = \ 1\)\%n
               \[CapitalGamma][z - \[Rho]\_k]\/\[CapitalGamma][
                z - \[Sigma]\_k])\).\)\)], "NumberedEquation1",
  CellTags->"Equation100"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[ScriptCapitalG][z] 
            \((\[Product]\+\(\[Nu]\  = \ 1\)\%n 
                  \[Pi]\/Sin[\[Pi] \((z - \[Rho]\_\[Nu])\)])\) == 
          \[ScriptCapitalH][z] 
            \((\[Product]\+\(\[Nu]\  = \ 1\)\%n 
                  \[Pi]\/Sin[\[Pi] \((z - \[Sigma]\_\[Nu])\)])\) /. {
          \[ScriptCapitalG][z] \[Rule] 
            \[Product]\+\(k\  = \ 1\)\%n
                 \[CapitalGamma][1 + \[Sigma]\_k - z]\/\[CapitalGamma][
                  1 + \[Rho]\_k - z], 
          \[ScriptCapitalH][z] \[Rule] 
            \[Product]\+\(k\  = \ 1\)\%n
                 \[CapitalGamma][z - \[Rho]\_k]\/\[CapitalGamma][
                  z - \[Sigma]\_k]}\) /. 
      \ {\[CapitalGamma] \[Rule] Gamma, n \[Rule] 1}\), 
    \(% // FullSimplify\)}], "Input"],

Cell[BoxData[
    \(\(\[Pi]\ Csc[\[Pi]\ \((z - \[Rho]\_1)\)]\ 
          Gamma[1 - z + \[Sigma]\_1]\)\/Gamma[1 - z + \[Rho]\_1] == 
      \(\[Pi]\ Csc[\[Pi]\ \((z - \[Sigma]\_1)\)]\ 
          Gamma[z - \[Rho]\_1]\)\/Gamma[z - \[Sigma]\_1]\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Because of relation (",
  CounterBox["NumberedEquation", "Equation95"],
  ") ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG][z]\)]],
  " behaves regularly within the half plane ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] < a + 1\)]],
  "; in the same way ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH][z]\)]],
  " behaves within the half plane ",
  Cell[BoxData[
      \(TraditionalForm\`Re[z] > a\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Now because of the equations (",
  CounterBox["NumberedEquation", "Equation97"],
  ") and (",
  CounterBox["NumberedEquation", "Equation99"],
  ") we get for ",
  Cell[BoxData[
      \(TraditionalForm\`G[z] P[z]\)]],
  " both of the identical expressions"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(G[z] P[z] \[Equal] 
      \[ScriptCapitalG][z] 
        \(\[Sum]\+\(i\  = \ 1\)\%n
            \( \[Pi]\ A\_i\)\/Sin[\[Pi] \((z - \[Rho]\_i)\)]\) \[Congruent] \ 
      \[ScriptCapitalH][z] 
        \(\[Sum]\+\(i\  = \ 1\)\%n
            \( \[Pi]\ B\_i\)\/Sin[\[Pi] \((z - \[Sigma]\_i)\)]\)\)], 
  "NumberedEquation1"],

Cell[TextData[{
  "and also for ",
  Cell[BoxData[
      \(TraditionalForm\`J[x, a]\)]],
  " both of the corresponding presentations"
}], "Text"],

Cell[BoxData[
    \(J[x, a] \[Equal] \[Sum]\+\(i\  = \ 1\)\%n\( A\_i\) \(J\_i\)\&\((0)\)[x] 
      \[Equal] \[Sum]\+\(i\  = \ 1\)\%n\( B\_i\) 
          \(J\_i\)\&\((\[Infinity])\)[x]\)], "NumberedEquation1",
  CellTags->"Equation102"],

Cell["with", "Text"],

Cell[BoxData[
    \(\(\(J\_i\)\&\((0)\)[x] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ 
                \[Infinity]\)\(\[Pi]\/Sin[\[Pi] \((z - \[Rho]\_i)\)]\) 
            \[ScriptCapitalG][z] \(x\^\(-z\)\) \[DifferentialD]z\), \)\)], 
  "NumberedEquation1"],

Cell[BoxData[
    \(\(J\_i\)\&\((\[Infinity])\)[x] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)\[Pi]\/Sin[
                \[Pi] \((z - \[Sigma]\_i)\)]\ \[ScriptCapitalH][z] 
            \(x\^\(-z\)\) \(\[DifferentialD]z.\)\)\)], "NumberedEquation1"],

Cell[TextData[{
  "Because of the mentioned properties of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\)]],
  " within the above mentioned half planes one gets very simple expansions \
for the ",
  Cell[BoxData[
      \(\(J\_i\)\&\((0)\)[x]\)]],
  " in the neighbourhood of ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] 0\)]],
  " and for the ",
  Cell[BoxData[
      \(\(J\_i\)\&\((\[Infinity])\)[x]\)]],
  " in the neighbourhood of ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Equal] \[Infinity]\)]],
  ", namely results"
}], "Text"],

Cell[BoxData[
    \(\(\(J\_i\)\&\((0)\)[x] \[Equal] 
      \(x\^\(-\[Rho]\_i\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity] \[ScriptCapitalG][
              \[Rho]\_i - \[Nu]] \((\(-x\))\)\^\[Nu]\ \ \ \ \ \ \ \ \ \ for\ 
            \((\(|x | \))\)\) < 1, \)\)], "NumberedEquation1",
  CellTags->"Equation105"],

Cell[BoxData[
    \(\[Nu] \[Equal] 1, 2, \(\[CenterDot]\[CenterDot]\[CenterDot]\), n, \)], 
  "Equation",
  TextAlignment->Right],

Cell[BoxData[
    \(\(J\_i\)\&\((\[Infinity])\)[x] \[Equal] 
      \(\((1\/x)\)\^\(\[Sigma]\_i + 1\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity]\ 
          \[ScriptCapitalH][\[Sigma]\_i + 1 + \[Nu]] 
            \((\(-\(1\/x\)\))\)\^\[Nu]\ \ \ \ \ \ \ \ \ \ for\ 
            \((\(|x | \))\)\) > 1.\)], "NumberedEquation1",
  CellTags->"Equation106"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Pi]\/Sin[\[Pi] \((z - \[Rho]\_i)\)] == 
        Gamma[z - \[Rho]\_i] Gamma[1 - \((z - \[Rho]\_i)\)] // FullSimplify
      \)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Plus@@
        \((\(Residue[
                \(\[Pi]\/Sin[\[Pi] \((z - \[Rho]\[Rho]1)\)]\) 
                  \(\[Product]\+\(k\  = \ 1\)\%1
                      \( Gamma[1 + \[Sigma]\[Sigma]1 - z]\/Gamma[
                            1 + \[Rho]\[Rho]1 - z]\) x\^\(-z\)\), {z, 
                  \[Rho]\[Rho]1 - #}]&\)/@Range[0, 4])\) /. {
        \[Rho]\[Rho]1 \[Rule] \[Rho]\_1, 
        \[Sigma]\[Sigma]1 \[Rule] \[Sigma]\_1}\), 
    \(\(% == 
            \(x\^\(-\[Rho]\_i\)\) 
              \(\[Sum]\+\(\[Nu]\  = \ 0\)\%4
                   \[ScriptCapitalG][\[Rho]\_i - \[Nu]] 
                  \((\(-x\))\)\^\[Nu]\) /. {
            \[ScriptCapitalG][z_] \[RuleDelayed] 
              \[Product]\+\(k\  = \ 1\)\%n
                   \[CapitalGamma][1 + \[Sigma]\_k - z]\/\[CapitalGamma][
                    1 + \[Rho]\_k - z]}\) /. {\[CapitalGamma] \[Rule] Gamma, 
          n \[Rule] 1, \[Rho]\_i \[Rule] \[Rho]\_1} // Simplify\)}], "Input"],

Cell[BoxData[
    \(x\^\(-\[Rho]\_1\)\ Gamma[1 - \[Rho]\_1 + \[Sigma]\_1] - 
      x\^\(1 - \[Rho]\_1\)\ Gamma[2 - \[Rho]\_1 + \[Sigma]\_1] + 
      1\/2\ x\^\(2 - \[Rho]\_1\)\ Gamma[3 - \[Rho]\_1 + \[Sigma]\_1] - 
      1\/6\ x\^\(3 - \[Rho]\_1\)\ Gamma[4 - \[Rho]\_1 + \[Sigma]\_1] + 
      1\/24\ x\^\(4 - \[Rho]\_1\)\ Gamma[5 - \[Rho]\_1 + \[Sigma]\_1]\)], 
  "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Plus@@
        \((\(\(-Residue[
                  \(\[Pi]\/Sin[\[Pi] \((z - \[Sigma]\[Sigma]1)\)]\) 
                    \(\[Product]\+\(k\  = \ 1\)\%1
                         Gamma[z - \[Rho]\[Rho]1]\/Gamma[
                            z - \[Sigma]\[Sigma]1]\ x\^\(-z\)\), {z, 
                    \[Sigma]\[Sigma]1 + 1 + #}]\)&\)/@Range[0, 4])\) /. {
        \[Rho]\[Rho]1 \[Rule] \[Rho]\_1, 
        \[Sigma]\[Sigma]1 \[Rule] \[Sigma]\_1}\), 
    \(\(\(% == 
              \(\((1\/x)\)\^\(\[Sigma]\_i + 1\)\) 
                \(\[Sum]\+\(\[Nu]\  = \ 0\)\%4\ 
                  \[ScriptCapitalH][\[Sigma]\_i + 1 + \[Nu]] 
                    \((\(-\(1\/x\)\))\)\^\[Nu]\) /. {
              \[ScriptCapitalH][z_] \[RuleDelayed] 
                \[Product]\+\(k\  = \ 1\)\%n
                     \[CapitalGamma][z - \[Rho]\_k]\/\[CapitalGamma][
                      z - \[Sigma]\_k]}\) /. {\[CapitalGamma] \[Rule] Gamma, 
            n \[Rule] 1, \[Sigma]\_i \[Rule] \[Sigma]\_1} // PowerExpand\) // 
      Simplify\)}], "Input"],

Cell[BoxData[
    \(x\^\(\(-1\) - \[Sigma]\_1\)\ Gamma[1 - \[Rho]\_1 + \[Sigma]\_1] - 
      x\^\(\(-2\) - \[Sigma]\_1\)\ Gamma[2 - \[Rho]\_1 + \[Sigma]\_1] + 
      1\/2\ x\^\(\(-3\) - \[Sigma]\_1\)\ Gamma[3 - \[Rho]\_1 + \[Sigma]\_1] - 
      1\/6\ x\^\(\(-4\) - \[Sigma]\_1\)\ Gamma[4 - \[Rho]\_1 + \[Sigma]\_1] + 
      1\/24\ x\^\(\(-5\) - \[Sigma]\_1\)\ 
        Gamma[5 - \[Rho]\_1 + \[Sigma]\_1]\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The complete expressions of the coefficients are due to equations (",
  CounterBox["NumberedEquation", "Equation100"],
  "):"
}], "Text"],

Cell[BoxData[
    \(\(\[ScriptCapitalG][\[Rho]\_i - \[Nu]] \[Equal] 
      \((\[Product]\+\(k = 1\)\%n
             \[CapitalGamma][1 + \[Sigma]\_k - \[Rho]\_i + \[Nu]]
              \/\[CapitalGamma][1 + \[Rho]\_k - \[Rho]\_i + \[Nu]])\), \)\)], 
  "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Product]\+\(k = 1\)\%n
             \[CapitalGamma][1 + \[Sigma]\_k - \[Rho]\_i + \[Nu]]
              \/\[CapitalGamma][1 + \[Rho]\_k - \[Rho]\_i + \[Nu]] == 
        \((\[Product]\+\(k\  = \ 1\)\%n
               \[CapitalGamma][1 + \[Sigma]\_k - z]\/\[CapitalGamma][
                1 + \[Rho]\_k - z])\) /. {z \[Rule] \[Rho]\_i - \[Nu]}\)], 
  "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\[ScriptCapitalH][\[Sigma]\_i + 1 + \[Nu]] \[Equal] 
      \(\((\[Product]\+\(k = 1\)\%n
               \[CapitalGamma][1 + \[Sigma]\_i - \[Rho]\_k + \[Nu]]
                \/\[CapitalGamma][1 + \[Sigma]\_i - \[Sigma]\_k + \[Nu]])\).
        \)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Product]\+\(k = 1\)\%n
             \[CapitalGamma][1 + \[Sigma]\_i - \[Rho]\_k + \[Nu]]
              \/\[CapitalGamma][1 + \[Sigma]\_i - \[Sigma]\_k + \[Nu]] == 
        \((\[Product]\+\(k\  = \ 1\)\%n
               \[CapitalGamma][z - \[Rho]\_k]\/\[CapitalGamma][
                z - \[Sigma]\_k])\) /. {z \[Rule] \[Sigma]\_i + 1 + \[Nu]}\)],
   "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now if we ask for the ",
  StyleBox["transforming substitutions",
    FontSlant->"Italic"],
  ", that lead from the fundamental system (",
  CounterBox["NumberedEquation", "Equation105"],
  ") to the fundamental system (",
  CounterBox["NumberedEquation", "Equation106"],
  ") and vice versa, then they result from identity (",
  CounterBox["NumberedEquation", "Equation102"],
  "). With ",
  Cell[BoxData[
      \(TraditionalForm\`A\_k \[Equal] 1\)]],
  " and all remaining ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " being equal to zero, equation (",
  CounterBox["NumberedEquation", "Equation102"],
  ") gets the form"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(J\_k\)\&\((0)\)[x] \[Equal] 
      \[Sum]\+\(i\  = \ 1\)\%n\( B\_i\%\((k)\)\) 
          \(J\_i\)\&\((\[Infinity])\)[x]\ \ \ \ \ \ \ \ \ \ k \[Equal] 1, 2, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\), \(n.\)\)], "NumberedEquation1",
  CellTags->"Equation109"],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`B\_k \[Equal] 1\)]],
  " and all remaining ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " being equal to zero, yields"
}], "Text"],

Cell[BoxData[
    \(\(J\_k\)\&\((\[Infinity])\)[x] \[Equal] 
      \[Sum]\+\(i\  = \ 1\)\%n\( A\_i\%\((k)\)\) 
          \(J\_i\)\&\((0)\)[x]\ \ \ \ \ \ \ \ \ \ k \[Equal] 1, 2, 
    \(\[CenterDot]\[CenterDot]\[CenterDot]\), \(n.\)\)], "NumberedEquation1",
  CellTags->"Equation110"],

Cell[TextData[{
  "The constants ",
  Cell[BoxData[
      \(TraditionalForm\`B\_i\%\((k)\)\)]],
  " result from identity (",
  CounterBox["NumberedEquation", "Equation97"],
  ") by setting ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Equal] \[Sigma]\_1, 
      \(\[CenterDot]\[CenterDot]\[CenterDot]\), \[Sigma]\_n\)]],
  ", while all ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " except for ",
  Cell[BoxData[
      \(TraditionalForm\`A\_k \[Equal] 1\)]],
  " are set to zero; and in corresponding manner the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_i\%\((k)\)\)]],
  " are calculated. By this is found"
}], "Text"],

Cell[BoxData[
    \(\(\(B\_i\%\((k)\)\) 
        \(\(\[Product]\^\((i)\)\)\+\(\[Nu]\  = \ 1\)\%n Sin[
            \[Pi] \((\[Sigma]\_i - \[Sigma]\_\[Nu])\)]\) \[Equal] 
      \(\[Product]\^\((k)\)\)\+\(\[Nu]\  = \ 1\)\%n Sin[
          \[Pi] \((\[Sigma]\_i - \[Rho]\_\[Nu])\)], \)\)], "NumberedEquation1"],

Cell[BoxData[
    \(i \[Equal] 1, 2, \(\[CenterDot]\[CenterDot]\[CenterDot]\), n, \)], 
  "Equation",
  TextAlignment->Right],

Cell[BoxData[
    \(\(\(A\_i\%\((k)\)\) 
        \(\(\[Product]\^\((i)\)\)\+\(\[Nu]\  = \ 1\)\%n Sin[
            \[Pi] \((\[Rho]\_i - \[Rho]\_\[Nu])\)]\) \[Equal] 
      \(\[Product]\^\((k)\)\)\+\(\[Nu]\  = \ 1\)\%n Sin[
          \[Pi] \((\[Rho]\_i - \[Sigma]\_\[Nu])\)], \)\)], "NumberedEquation1"],

Cell[TextData[{
  "where by ",
  Cell[BoxData[
      \(TraditionalForm\`\((k)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((i)\)\)]],
  " is shown, that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  " does not get the value ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", respectively."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(substitutionrule
       = {B\_\(i_, k_\) \[RuleDelayed] 
          \(\((\[Product]\+\(\[Nu]\  = \ 1\)\%\(k - 1\)Sin[
                    \[Pi]\ \((\[Sigma]\_i - \[Rho]\_\[Nu])\)])\)\ 
              \(\[Product]\+\(\[Nu]\  = \ k + 1\)\%n Sin[
                  \[Pi]\ \((\[Sigma]\_i - \[Rho]\_\[Nu])\)]\)\)\/\(\((
                \[Product]\+\(\[Nu]\  = \ 1\)\%\(i - 1\)Sin[
                    \[Pi]\ \((\[Sigma]\_i - \[Sigma]\_\[Nu])\)])\)\ 
              \(\[Product]\+\(\[Nu]\  = \ i + 1\)\%n Sin[
                  \[Pi]\ \((\[Sigma]\_i - \[Sigma]\_\[Nu])\)]\)\), 
        A\_\(i_, k_\) \[RuleDelayed] 
          \(\((\[Product]\+\(\[Nu]\  = \ 1\)\%\(k - 1\)Sin[
                    \[Pi]\ \((\[Rho]\_i - \[Sigma]\_\[Nu])\)])\)\ 
              \(\[Product]\+\(\[Nu]\  = \ k + 1\)\%n Sin[
                  \[Pi]\ \((\[Rho]\_i - \[Sigma]\_\[Nu])\)]\)\)\/\(\((
                \[Product]\+\(\[Nu]\  = \ 1\)\%\(i - 1\)Sin[
                    \[Pi]\ \((\[Rho]\_i - \[Rho]\_\[Nu])\)])\)\ 
              \(\[Product]\+\(\[Nu]\  = \ i + 1\)\%n Sin[
                  \[Pi]\ \((\[Rho]\_i - \[Rho]\_\[Nu])\)]\)\)}\)], "Input"],

Cell[BoxData[
    \({B\_\(i_, k_\) \[RuleDelayed] 
        \(\((\[Product]\+\(\[Nu] = 1\)\%\(k - 1\)Sin[
                  \[Pi]\ \((\[Sigma]\_i - \[Rho]\_\[Nu])\)])\)\ 
            \(\[Product]\+\(\[Nu] = k + 1\)\%n Sin[
                \[Pi]\ \((\[Sigma]\_i - \[Rho]\_\[Nu])\)]\)\)\/\(\((
              \[Product]\+\(\[Nu] = 1\)\%\(i - 1\)Sin[
                  \[Pi]\ \((\[Sigma]\_i - \[Sigma]\_\[Nu])\)])\)\ 
            \(\[Product]\+\(\[Nu] = i + 1\)\%n Sin[
                \[Pi]\ \((\[Sigma]\_i - \[Sigma]\_\[Nu])\)]\)\), 
      A\_\(i_, k_\) \[RuleDelayed] 
        \(\((\[Product]\+\(\[Nu] = 1\)\%\(k - 1\)Sin[
                  \[Pi]\ \((\[Rho]\_i - \[Sigma]\_\[Nu])\)])\)\ 
            \(\[Product]\+\(\[Nu] = k + 1\)\%n Sin[
                \[Pi]\ \((\[Rho]\_i - \[Sigma]\_\[Nu])\)]\)\)\/\(\((
              \[Product]\+\(\[Nu] = 1\)\%\(i - 1\)Sin[
                  \[Pi]\ \((\[Rho]\_i - \[Rho]\_\[Nu])\)])\)\ 
            \(\[Product]\+\(\[Nu] = i + 1\)\%n Sin[
                \[Pi]\ \((\[Rho]\_i - \[Rho]\_\[Nu])\)]\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[ScriptCapitalG][z] 
                \(\[Sum]\+\(i\  = \ 1\)\%n
                    \( \[Pi]\ A\_i\)\/Sin[\[Pi] \((z - \[Rho]\_i)\)]\) == \ 
              \[ScriptCapitalH][z] 
                \(\[Sum]\+\(i\  = \ 1\)\%n
                    \( \[Pi]\ B\_i\)\/Sin[\[Pi] \((z - \[Sigma]\_i)\)]\) /. {
              \[ScriptCapitalG][z] \[Rule] 
                \[Product]\+\(k\  = \ 1\)\%n
                     \[CapitalGamma][1 + \[Sigma]\_k - z]\/\[CapitalGamma][
                      1 + \[Rho]\_k - z], 
              \[ScriptCapitalH][z] \[Rule] 
                \[Product]\+\(k\  = \ 1\)\%n
                     \[CapitalGamma][z - \[Rho]\_k]\/\[CapitalGamma][
                      z - \[Sigma]\_k]}\) /. 
          \ {\[CapitalGamma] \[Rule] Gamma, n \[Rule] 2}\) /. {
          A\_1 \[Rule] 1, A\_2 \[Rule] 0, B\_i_ \[RuleDelayed] B\_\(i, 1\)}
           // ExpandAll\), 
    \(\(% /. substitutionrule\) /. {n \[Rule] 2} // FullSimplify\)}], "Input"],

Cell[BoxData[
    \(\(\[Pi]\ Csc[\[Pi]\ z - \[Pi]\ \[Rho]\_1]\ Gamma[1 - z + \[Sigma]\_1]\ 
          Gamma[1 - z + \[Sigma]\_2]\)\/\(Gamma[1 - z + \[Rho]\_1]\ 
          Gamma[1 - z + \[Rho]\_2]\) == 
      \(\[Pi]\ Csc[\[Pi]\ z - \[Pi]\ \[Sigma]\_1]\ Gamma[z - \[Rho]\_1]\ 
            Gamma[z - \[Rho]\_2]\ B\_\(1, 1\)\)\/\(Gamma[z - \[Sigma]\_1]\ 
            Gamma[z - \[Sigma]\_2]\) + 
        \(\[Pi]\ Csc[\[Pi]\ z - \[Pi]\ \[Sigma]\_2]\ Gamma[z - \[Rho]\_1]\ 
            Gamma[z - \[Rho]\_2]\ B\_\(2, 1\)\)\/\(Gamma[z - \[Sigma]\_1]\ 
            Gamma[z - \[Sigma]\_2]\)\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[ScriptCapitalG][z] 
                \(\[Sum]\+\(i\  = \ 1\)\%n
                    \( \[Pi]\ A\_i\)\/Sin[\[Pi] \((z - \[Rho]\_i)\)]\) == \ 
              \[ScriptCapitalH][z] 
                \(\[Sum]\+\(i\  = \ 1\)\%n
                    \( \[Pi]\ B\_i\)\/Sin[\[Pi] \((z - \[Sigma]\_i)\)]\) /. {
              \[ScriptCapitalG][z] \[Rule] 
                \[Product]\+\(k\  = \ 1\)\%n
                     \[CapitalGamma][1 + \[Sigma]\_k - z]\/\[CapitalGamma][
                      1 + \[Rho]\_k - z], 
              \[ScriptCapitalH][z] \[Rule] 
                \[Product]\+\(k\  = \ 1\)\%n
                     \[CapitalGamma][z - \[Rho]\_k]\/\[CapitalGamma][
                      z - \[Sigma]\_k]}\) /. 
          \ {\[CapitalGamma] \[Rule] Gamma, n \[Rule] 2}\) /. {
          B\_2 \[Rule] 1, B\_1 \[Rule] 0, A\_i_ \[RuleDelayed] A\_\(i, 2\)}
           // ExpandAll\), 
    \(\(% /. substitutionrule\) /. {n \[Rule] 2} // FullSimplify\)}], "Input"],

Cell[BoxData[
    \(\(\[Pi]\ Csc[\[Pi]\ z - \[Pi]\ \[Rho]\_1]\ Gamma[1 - z + \[Sigma]\_1]\ 
            Gamma[1 - z + \[Sigma]\_2]\ 
            A\_\(1, 2\)\)\/\(Gamma[1 - z + \[Rho]\_1]\ 
            Gamma[1 - z + \[Rho]\_2]\) + 
        \(\[Pi]\ Csc[\[Pi]\ z - \[Pi]\ \[Rho]\_2]\ 
            Gamma[1 - z + \[Sigma]\_1]\ Gamma[1 - z + \[Sigma]\_2]\ 
            A\_\(2, 2\)\)\/\(Gamma[1 - z + \[Rho]\_1]\ 
            Gamma[1 - z + \[Rho]\_2]\) == 
      \(\[Pi]\ Csc[\[Pi]\ z - \[Pi]\ \[Sigma]\_2]\ Gamma[z - \[Rho]\_1]\ 
          Gamma[z - \[Rho]\_2]\)\/\(Gamma[z - \[Sigma]\_1]\ 
          Gamma[z - \[Sigma]\_2]\)\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
The treatise of other questions concerning the integration of hypergeometric \
differential equations must be omitted at this occasion.\
\>", "Text",
  ParagraphIndent->30]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". ",
  "The Ordinary Hypergeometric Differential Equation"
}], "Section"],

Cell["For the equation of second order", "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(\((a\_0 + \(b\_0\) x)\) y + 
        \((a\_1 + \(b\_1\) x)\) x \[DifferentialD]y\/\[DifferentialD]x + 
        \((1 + x)\) \(x\^2\) \[DifferentialD]\^2 y\/\[DifferentialD]x\^2 
      \[Equal] 0, \)\)], "NumberedEquation1"],

Cell["which by the assumptions", "Text"],

Cell[BoxData[
    \(x \[Equal] \(-t\), \ \ \ \ \ a\_0 \[Equal] 0, \ \ \ \ \ 
    a\_1 \[Equal] \[Gamma], \ \ \ \ \ b\_0 \[Equal] \[Alpha]\ \[Beta], 
    \ \ \ \ \ b\_1 \[Equal] \[Alpha] + \[Beta] + 1, \n\[Rho]\_1 \[Equal] 0, 
    \ \ \ \ \ \[Rho]\_2 \[Equal] \[Gamma] - 1, \ \ \ \ \ 
    \[Sigma]\_1 \[Equal] \[Alpha] - 1, \ \ \ \ \ 
    \[Sigma]\_2 \[Equal] \[Beta] - 1\)], "NumberedEquation1",
  CellTags->"Equation114"],

Cell["changes to the usual Gauss Kummer equation", "Text"],

Cell[BoxData[
    \(\(\((1 - t)\) t \[DifferentialD]\^2 y\/\[DifferentialD]t\^2 + 
        \((\[Gamma] - \((\[Alpha] + \[Beta] + 1)\) t)\) 
          \[DifferentialD]y\/\[DifferentialD]t - \[Alpha]\ \[Beta]\ y 
      \[Equal] 0, \)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      a\_0 - \(a\_1\) z + \(a\_2\) z \((z + 1)\) == 0 /. {a\_0 \[Rule] 0, 
          a\_1 \[Rule] \[Gamma], a\_2 \[Rule] 1}, z]\)], "Input"],

Cell[BoxData[
    \({{z \[Rule] 0}, {z \[Rule] \(-1\) + \[Gamma]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      b\_0 - \(b\_1\) \((z + 1)\) + \(b\_2\) \((z + 1)\) \((z + 2)\) == 0 /. {
          b\_0 \[Rule] \[Alpha]\ \[Beta], 
          b\_1 \[Rule] \[Alpha] + \[Beta] + 1, b\_2 \[Rule] 1}, z]\)], "Input"],

Cell[BoxData[
    \({{z \[Rule] \(-1\) + \[Alpha]}, {z \[Rule] \(-1\) + \[Beta]}}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(#\/t&\)/@\((a\_0 + \(b\_0\) x)\) y[x] + 
            \((a\_1 + \(b\_1\) x)\) x\ \(y'\)[x] + 
            \((1 + x)\) \(x\^2\) \(\(y'\)'\)[x] == 0 /. {
          y \[Rule] Function[{t}, y[\(-t\)]], x \[Rule] \(-t\), 
          a\_0 \[Rule] 0, a\_1 \[Rule] \[Gamma], 
          b\_0 \[Rule] \[Alpha]\ \[Beta], b\_1 \[Rule] \[Alpha] + \[Beta] + 1}
           // Simplify\), 
    \(\(\(DSolve[
              \((a\_0 + \(b\_0\) x)\) y[x] + 
                  \((a\_1 + \(b\_1\) x)\) x\ \(y'\)[x] + 
                  \((1 + x)\) \(x\^2\) \(\(y'\)'\)[x] == 0, y[x], x] /. {
              x \[Rule] \(-t\), a\_0 \[Rule] 0, a\_1 \[Rule] \[Gamma], 
              b\_0 \[Rule] \[Alpha]\ \[Beta], 
              b\_1 \[Rule] \[Alpha] + \[Beta] + 1, 
              C[1] \[Rule] C[1] \((\(-1\))\)\^\(\[Gamma] - 1\)} // Simplify
          \) // PowerExpand\) // ExpandAll\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(-\[Alpha]\)\ \[Beta]\ y[t]\), "+", 
        RowBox[{
        "t", " ", \((\(-t\)\ \((1 + \[Alpha] + \[Beta])\) + \[Gamma])\), " ", 
          
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "-", 
        RowBox[{\((\(-1\) + t)\), " ", \(t\^2\), " ", 
          RowBox[{
            SuperscriptBox["y", "\[DoublePrime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], "==", "0"}]], 
  "Output"],

Cell[BoxData[
    \({{y[\(-t\)] \[Rule] 
          C[2]\ Hypergeometric2F1[\[Beta], \[Alpha], \[Gamma], t] + 
            t\^\(1 - \[Gamma]\)\ C[1]\ 
              Hypergeometric2F1[1 + \[Beta] - \[Gamma], 
                1 + \[Alpha] - \[Gamma], 2 - \[Gamma], t]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "the formulae (",
  CounterBox["NumberedEquation", "Equation105"],
  ") and (",
  CounterBox["NumberedEquation", "Equation106"],
  ") get the following shape:"
}], "Text"],

Cell[BoxData[
    \(\(\(J\_i\)\&\((0)\)[x] \[Equal] 
      \(x\^\(-\[Rho]\_i\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ 0
              \)\%\[Infinity]\(\( \[CapitalGamma][
                    1 + \[Sigma]\_1 - \[Rho]\_i + \[Nu]] 
                  \[CapitalGamma][1 + \[Sigma]\_2 - \[Rho]\_i + \[Nu]]
                    \)\/\(\[CapitalGamma][1 + \[Rho]\_1 - \[Rho]\_i + \[Nu]] 
                  \[CapitalGamma][1 + \[Rho]\_2 - \[Rho]\_i + \[Nu]]\)\) 
            \((\(-x\))\)\^\[Nu]\), \)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        \(\(x\^\(-\[Rho]\_i\)\) 
                \(\[Sum]\+\(\[Nu]\  = \ 0
                      \)\%\[Infinity]\(\( Gamma[
                            1 + \[Sigma]\_1 - \[Rho]\_i + \[Nu]] 
                          Gamma[1 + \[Sigma]\_2 - \[Rho]\_i + \[Nu]]
                            \)\/\(Gamma[1 + \[Rho]\_1 - \[Rho]\_i + \[Nu]] 
                          Gamma[1 + \[Rho]\_2 - \[Rho]\_i + \[Nu]]\)\) 
                    \((\(-x\))\)\^\[Nu]\) /. {\[Rho]\_1 \[Rule] 0, 
                \[Rho]\_2 \[Rule] \[Gamma] - 1, 
                \[Sigma]\_1 \[Rule] \[Alpha] - 1, 
                \[Sigma]\_2 \[Rule] \[Beta] - 1} // FullSimplify\) // 
          FunctionExpand, {i, 2}] // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
           
             {\(\(Gamma[\[Alpha]]\ Gamma[\[Beta]]\ 
                    Hypergeometric2F1[\[Alpha], \[Beta], \[Gamma], \(-x\)]
                      \)\/Gamma[\[Gamma]]\)},
           
             {\(\(x\^\(1 - \[Gamma]\)\ Gamma[1 + \[Alpha] - \[Gamma]]\ 
                    Gamma[1 + \[Beta] - \[Gamma]]\ 
                    Hypergeometric2F1[1 + \[Alpha] - \[Gamma], 
                      1 + \[Beta] - \[Gamma], 2 - \[Gamma], \(-x\)]\)\/Gamma[
                    2 - \[Gamma]]\)}
            }], ")"}],
      MatrixForm[ {
        Times[ 
          Gamma[ \[Alpha]], 
          Gamma[ \[Beta]], 
          Power[ 
            Gamma[ \[Gamma]], -1], 
          Hypergeometric2F1[ \[Alpha], \[Beta], \[Gamma], 
            Times[ -1, x]]], 
        Times[ 
          Power[ x, 
            Plus[ 1, 
              Times[ -1, \[Gamma]]]], 
          Power[ 
            Gamma[ 
              Plus[ 2, 
                Times[ -1, \[Gamma]]]], -1], 
          Gamma[ 
            Plus[ 1, \[Alpha], 
              Times[ -1, \[Gamma]]]], 
          Gamma[ 
            Plus[ 1, \[Beta], 
              Times[ -1, \[Gamma]]]], 
          Hypergeometric2F1[ 
            Plus[ 1, \[Alpha], 
              Times[ -1, \[Gamma]]], 
            Plus[ 1, \[Beta], 
              Times[ -1, \[Gamma]]], 
            Plus[ 2, 
              Times[ -1, \[Gamma]]], 
            Times[ -1, x]]]}]]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(i \[Equal] 1, 2\)], "Equation",
  TextAlignment->Right],

Cell[BoxData[
    \(\(\(J\_i\)\&\((\[Infinity])\)[x] \[Equal] 
      \(\((1\/x)\)\^\(\[Sigma]\_i + 1\)\) 
        \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity]\ 
          \(\(\[CapitalGamma][1 + \[Sigma]\_i - \[Rho]\_1 + \[Nu]] 
                  \[CapitalGamma][1 + \[Sigma]\_i - \[Rho]\_2 + \[Nu]]
                    \)\/\(\[CapitalGamma][
                    1 + \[Sigma]\_i - \[Sigma]\_1 + \[Nu]] 
                  \[CapitalGamma][1 + \[Sigma]\_i - \[Sigma]\_2 + \[Nu]]\)\) 
            \((\(-\(1\/x\)\))\)\^\[Nu]\), \)\)], "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        \(\(\((1\/x)\)\^\(\[Sigma]\_i + 1\)\) 
                \(\[Sum]\+\(\[Nu]\  = \ 0\)\%\[Infinity]\ 
                  \(\(Gamma[1 + \[Sigma]\_i - \[Rho]\_1 + \[Nu]] 
                          Gamma[1 + \[Sigma]\_i - \[Rho]\_2 + \[Nu]]
                            \)\/\(Gamma[1 + \[Sigma]\_i - \[Sigma]\_1 + \[Nu]]
                             Gamma[1 + \[Sigma]\_i - \[Sigma]\_2 + \[Nu]]\)\) 
                    \((\(-\(1\/x\)\))\)\^\[Nu]\) /. {\[Rho]\_1 \[Rule] 0, 
                \[Rho]\_2 \[Rule] \[Gamma] - 1, 
                \[Sigma]\_1 \[Rule] \[Alpha] - 1, 
                \[Sigma]\_2 \[Rule] \[Beta] - 1} // FullSimplify\) // 
          FunctionExpand, {i, 2}] // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
           
             {\(\(\((1\/x)\)\^\[Alpha]\ Gamma[\[Alpha]]\ 
                    Gamma[1 + \[Alpha] - \[Gamma]]\ 
                    Hypergeometric2F1[\[Alpha], 1 + \[Alpha] - \[Gamma], 
                      1 + \[Alpha] - \[Beta], \(-\(1\/x\)\)]\)\/Gamma[
                    1 + \[Alpha] - \[Beta]]\)},
           
             {\(\(\((1\/x)\)\^\[Beta]\ Gamma[\[Beta]]\ 
                    Gamma[1 + \[Beta] - \[Gamma]]\ 
                    Hypergeometric2F1[\[Beta], 1 + \[Beta] - \[Gamma], 
                      1 - \[Alpha] + \[Beta], \(-\(1\/x\)\)]\)\/Gamma[
                    1 - \[Alpha] + \[Beta]]\)}
            }], ")"}],
      MatrixForm[ {
        Times[ 
          Power[ 
            Power[ x, -1], \[Alpha]], 
          Gamma[ \[Alpha]], 
          Power[ 
            Gamma[ 
              Plus[ 1, \[Alpha], 
                Times[ -1, \[Beta]]]], -1], 
          Gamma[ 
            Plus[ 1, \[Alpha], 
              Times[ -1, \[Gamma]]]], 
          Hypergeometric2F1[ \[Alpha], 
            Plus[ 1, \[Alpha], 
              Times[ -1, \[Gamma]]], 
            Plus[ 1, \[Alpha], 
              Times[ -1, \[Beta]]], 
            Times[ -1, 
              Power[ x, -1]]]], 
        Times[ 
          Power[ 
            Power[ x, -1], \[Beta]], 
          Gamma[ \[Beta]], 
          Power[ 
            Gamma[ 
              Plus[ 1, 
                Times[ -1, \[Alpha]], \[Beta]]], -1], 
          Gamma[ 
            Plus[ 1, \[Beta], 
              Times[ -1, \[Gamma]]]], 
          Hypergeometric2F1[ \[Beta], 
            Plus[ 1, \[Beta], 
              Times[ -1, \[Gamma]]], 
            Plus[ 1, 
              Times[ -1, \[Alpha]], \[Beta]], 
            Times[ -1, 
              Power[ x, -1]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "while the transforming substitutions (",
  CounterBox["NumberedEquation", "Equation109"],
  ") and (",
  CounterBox["NumberedEquation", "Equation110"],
  ") get the form:"
}], "Text"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\(J\_1\)\&\((0)\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Sigma]\_1 - \[Rho]\_2)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_1 - \[Sigma]\_2)\)]\) 
                  \(J\_1\)\&\((\[Infinity])\)[x] + 
                \(Sin[\[Pi] \((\[Sigma]\_2 - \[Rho]\_2)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_2 - \[Sigma]\_1)\)]\) 
                  \(J\_2\)\&\((\[Infinity])\)[x], \)},
          {
            \(\(J\_2\)\&\((0)\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Sigma]\_1 - \[Rho]\_1)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_1 - \[Sigma]\_2)\)]\) 
                  \(J\_1\)\&\((\[Infinity])\)[x] + 
                \(Sin[\[Pi] \((\[Sigma]\_2 - \[Rho]\_2)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_2 - \[Sigma]\_1)\)]\) 
                  \(J\_2\)\&\((\[Infinity])\)[x], \)}
          }]}]], "NumberedEquation1"],

Cell["Correction of printing mistake:", "Text",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\(J\_1\)\&\((0)\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Sigma]\_1 - \[Rho]\_2)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_1 - \[Sigma]\_2)\)]\) 
                  \(J\_1\)\&\((\[Infinity])\)[x] + 
                \(Sin[\[Pi] \((\[Sigma]\_2 - \[Rho]\_2)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_2 - \[Sigma]\_1)\)]\) 
                  \(J\_2\)\&\((\[Infinity])\)[x], \)},
          {
            \(\(J\_2\)\&\((0)\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Sigma]\_1 - \[Rho]\_1)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_1 - \[Sigma]\_2)\)]\) 
                  \(J\_1\)\&\((\[Infinity])\)[x] + 
                \(Sin[\[Pi] \((\[Sigma]\_2 - \[Rho]\_1)\)]\/Sin[
                        \[Pi] \((\[Sigma]\_2 - \[Sigma]\_1)\)]\) 
                  \(J\_2\)\&\((\[Infinity])\)[x], \)}
          }]}]], "Equation",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(\(\(J\_k\)\&\((0)\)[x] == 
                    \[Sum]\+\(i\  = \ 1\)\%n\( B\_\(i, k\)\) 
                        \(J\_i\)\&\((\[Infinity])\)[x] /. substitutionrule
                  \) /. {n \[Rule] 2, k \[Rule] #}&\)/@Range[2])\) /. {
          Csc[z_] \[RuleDelayed] 1\/"\<Sin\>"[z]} // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{\(\(J\_1\)\&0[x]\), "==", 
                RowBox[{
                  FractionBox[
                    RowBox[{
                    \(Sin[\[Pi]\ \((\(-\[Rho]\_2\) + \[Sigma]\_1)\)]\), " ", 
                      RowBox[{
                        OverscriptBox[\(J\_1\), 
                          InterpretationBox["\[Infinity]",
                            DirectedInfinity[ 1]]], "[", "x", "]"}]}], 
                    \("Sin"[\[Pi]\ \((\[Sigma]\_1 - \[Sigma]\_2)\)]\)], "+", 
                  FractionBox[
                    RowBox[{
                    \(Sin[\[Pi]\ \((\(-\[Rho]\_2\) + \[Sigma]\_2)\)]\), " ", 
                      RowBox[{
                        OverscriptBox[\(J\_2\), 
                          InterpretationBox["\[Infinity]",
                            DirectedInfinity[ 1]]], "[", "x", "]"}]}], 
                    \("Sin"[\[Pi]\ \((\(-\[Sigma]\_1\) + \[Sigma]\_2)\)]
                      \)]}]}]},
            {
              RowBox[{\(\(J\_2\)\&0[x]\), "==", 
                RowBox[{
                  FractionBox[
                    RowBox[{
                    \(Sin[\[Pi]\ \((\(-\[Rho]\_1\) + \[Sigma]\_1)\)]\), " ", 
                      RowBox[{
                        OverscriptBox[\(J\_1\), 
                          InterpretationBox["\[Infinity]",
                            DirectedInfinity[ 1]]], "[", "x", "]"}]}], 
                    \("Sin"[\[Pi]\ \((\[Sigma]\_1 - \[Sigma]\_2)\)]\)], "+", 
                  FractionBox[
                    RowBox[{
                    \(Sin[\[Pi]\ \((\(-\[Rho]\_1\) + \[Sigma]\_2)\)]\), " ", 
                      RowBox[{
                        OverscriptBox[\(J\_2\), 
                          InterpretationBox["\[Infinity]",
                            DirectedInfinity[ 1]]], "[", "x", "]"}]}], 
                    \("Sin"[\[Pi]\ \((\(-\[Sigma]\_1\) + \[Sigma]\_2)\)]
                      \)]}]}]}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Overscript[ 
            Subscript[ J, 1], 0][ x], 
          Plus[ 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Subscript[ \[Sigma], 1], 
                      Times[ -1, 
                        Subscript[ \[Sigma], 2]]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Times[ -1, 
                      Subscript[ \[Rho], 2]], 
                    Subscript[ \[Sigma], 1]]]], 
              Overscript[ 
                Subscript[ J, 1], 
                DirectedInfinity[ 1]][ x]], 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Times[ -1, 
                        Subscript[ \[Sigma], 1]], 
                      Subscript[ \[Sigma], 2]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Times[ -1, 
                      Subscript[ \[Rho], 2]], 
                    Subscript[ \[Sigma], 2]]]], 
              Overscript[ 
                Subscript[ J, 2], 
                DirectedInfinity[ 1]][ x]]]], 
        Equal[ 
          Overscript[ 
            Subscript[ J, 2], 0][ x], 
          Plus[ 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Subscript[ \[Sigma], 1], 
                      Times[ -1, 
                        Subscript[ \[Sigma], 2]]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Times[ -1, 
                      Subscript[ \[Rho], 1]], 
                    Subscript[ \[Sigma], 1]]]], 
              Overscript[ 
                Subscript[ J, 1], 
                DirectedInfinity[ 1]][ x]], 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Times[ -1, 
                        Subscript[ \[Sigma], 1]], 
                      Subscript[ \[Sigma], 2]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Times[ -1, 
                      Subscript[ \[Rho], 1]], 
                    Subscript[ \[Sigma], 2]]]], 
              Overscript[ 
                Subscript[ J, 2], 
                DirectedInfinity[ 1]][ x]]]]}]]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\(J\_1\)\&\((\[Infinity])\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Rho]\_1 - \[Sigma]\_2)\)]\/Sin[
                        \[Pi] \((\[Rho]\_1 - \[Rho]\_2)\)]\) 
                  \(J\_1\)\&\((0)\)[x] + 
                \(Sin[\[Pi] \((\[Rho]\_2 - \[Sigma]\_2)\)]\/Sin[
                        \[Pi] \((\[Rho]\_2 - \[Rho]\_1)\)]\) 
                  \(J\_2\)\&\((0)\)[x], \)},
          {
            \(\(J\_1\)\&\((\[Infinity])\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Rho]\_1 - \[Sigma]\_1)\)]\/Sin[
                        \[Pi] \((\[Rho]\_1 - \[Rho]\_2)\)]\) 
                  \(J\_1\)\&\((0)\)[x] + 
                \(Sin[\[Pi] \((\[Rho]\_2 - \[Sigma]\_1)\)]\/Sin[
                        \[Pi] \((\[Rho]\_2 - \[Rho]\_1)\)]\) 
                  \(\(J\_2\)\&\((0)\)[x].\)\)}
          }]}]], "NumberedEquation1"],

Cell["Correction of misprint:", "Text",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[BoxData[
    RowBox[{"{", GridBox[{
          {
            \(\(J\_1\)\&\((\[Infinity])\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Rho]\_1 - \[Sigma]\_2)\)]\/Sin[
                        \[Pi] \((\[Rho]\_1 - \[Rho]\_2)\)]\) 
                  \(J\_1\)\&\((0)\)[x] + 
                \(Sin[\[Pi] \((\[Rho]\_2 - \[Sigma]\_2)\)]\/Sin[
                        \[Pi] \((\[Rho]\_2 - \[Rho]\_1)\)]\) 
                  \(J\_2\)\&\((0)\)[x], \)},
          {
            \(\(J\_2\)\&\((\[Infinity])\)[x] \[Equal] 
              \(Sin[\[Pi] \((\[Rho]\_1 - \[Sigma]\_1)\)]\/Sin[
                        \[Pi] \((\[Rho]\_1 - \[Rho]\_2)\)]\) 
                  \(J\_1\)\&\((0)\)[x] + 
                \(Sin[\[Pi] \((\[Rho]\_2 - \[Sigma]\_1)\)]\/Sin[
                        \[Pi] \((\[Rho]\_2 - \[Rho]\_1)\)]\) 
                  \(\(J\_2\)\&\((0)\)[x].\)\)}
          }]}]], "Equation",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(\(\(J\_k\)\&\((\[Infinity])\)[x] == 
                    \[Sum]\+\(i\  = \ 1\)\%n\( A\_\(i, k\)\) 
                        \(J\_i\)\&\((0)\)[x] /. substitutionrule\) /. {
                  n \[Rule] 2, k \[Rule] #}&\)/@Range[2])\) /. {
          Csc[z_] \[RuleDelayed] 1\/"\<Sin\>"[z]} // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{
                RowBox[{
                  OverscriptBox[\(J\_1\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], "[", "x", "]"}], "==", 
                \(\(Sin[\[Pi]\ \((\[Rho]\_1 - \[Sigma]\_2)\)]\ 
                      \(J\_1\)\&0[x]\)\/"Sin"[
                      \[Pi]\ \((\[Rho]\_1 - \[Rho]\_2)\)] + 
                  \(Sin[\[Pi]\ \((\[Rho]\_2 - \[Sigma]\_2)\)]\ 
                      \(J\_2\)\&0[x]\)\/"Sin"[
                      \[Pi]\ \((\(-\[Rho]\_1\) + \[Rho]\_2)\)]\)}]},
            {
              RowBox[{
                RowBox[{
                  OverscriptBox[\(J\_2\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], "[", "x", "]"}], "==", 
                \(\(Sin[\[Pi]\ \((\[Rho]\_1 - \[Sigma]\_1)\)]\ 
                      \(J\_1\)\&0[x]\)\/"Sin"[
                      \[Pi]\ \((\[Rho]\_1 - \[Rho]\_2)\)] + 
                  \(Sin[\[Pi]\ \((\[Rho]\_2 - \[Sigma]\_1)\)]\ 
                      \(J\_2\)\&0[x]\)\/"Sin"[
                      \[Pi]\ \((\(-\[Rho]\_1\) + \[Rho]\_2)\)]\)}]}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Overscript[ 
            Subscript[ J, 1], 
            DirectedInfinity[ 1]][ x], 
          Plus[ 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Subscript[ \[Rho], 1], 
                      Times[ -1, 
                        Subscript[ \[Rho], 2]]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Subscript[ \[Rho], 1], 
                    Times[ -1, 
                      Subscript[ \[Sigma], 2]]]]], 
              Overscript[ 
                Subscript[ J, 1], 0][ x]], 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Times[ -1, 
                        Subscript[ \[Rho], 1]], 
                      Subscript[ \[Rho], 2]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Subscript[ \[Rho], 2], 
                    Times[ -1, 
                      Subscript[ \[Sigma], 2]]]]], 
              Overscript[ 
                Subscript[ J, 2], 0][ x]]]], 
        Equal[ 
          Overscript[ 
            Subscript[ J, 2], 
            DirectedInfinity[ 1]][ x], 
          Plus[ 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Subscript[ \[Rho], 1], 
                      Times[ -1, 
                        Subscript[ \[Rho], 2]]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Subscript[ \[Rho], 1], 
                    Times[ -1, 
                      Subscript[ \[Sigma], 1]]]]], 
              Overscript[ 
                Subscript[ J, 1], 0][ x]], 
            Times[ 
              Power[ 
                "Sin"[ 
                  Times[ Pi, 
                    Plus[ 
                      Times[ -1, 
                        Subscript[ \[Rho], 1]], 
                      Subscript[ \[Rho], 2]]]], -1], 
              Sin[ 
                Times[ Pi, 
                  Plus[ 
                    Subscript[ \[Rho], 2], 
                    Times[ -1, 
                      Subscript[ \[Sigma], 1]]]]], 
              Overscript[ 
                Subscript[ J, 2], 0][ x]]]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The assumptions (",
  CounterBox["NumberedEquation", "Equation114"],
  ") yield the usual formulae, however the symmetry won above is rather lost \
by this."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\[Section] ",
  CounterBox["Section"],
  ". ",
  "Final Remarks"
}], "Section"],

Cell[TextData[{
  "Stirling's formula always has been important concerning the theory of the \
gamma functions. In a ",
  ButtonBox["former elaboration*)",
    ButtonData:>"Footnote1Section14",
    ButtonStyle->"Hyperlink"],
  " I have given a derivation of the same, which totally differs from the \
usual derivations and the one of ",
  StyleBox[ButtonBox["Stieltjes",
    ButtonData:>"Footnote2Section14",
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  ButtonBox["**)",
    ButtonData:>"Footnote2Section14",
    ButtonStyle->"Hyperlink"],
  ", and which is also uniformly connected to the theory of the reciprocal \
functions being developed in ",
  ButtonBox["\[Section]",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ". That formula indeed is contained within the formula"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(Log[\[CapitalGamma][x + 1]] \[Equal] 
      \(-C\)\ x - 
        \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
          \(\[Integral]\_\(3\/2 - \[ImaginaryI]\ \[Infinity]\)\%\(3\/2 + 
                \[ImaginaryI]\ \[Infinity]\)\(\[Pi]\/Sin[\[Pi]\ z]\) 
              \[Zeta][z] \(x\^z\/z\) \[DifferentialD]z\), \)\)], 
  "NumberedEquation1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gammalogseries[1] = Series[Log[Gamma[x + 1]], {x, 0, 5}] // Simplify\)],
   "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \(-\(EulerGamma\ x\)\), "+", \(\(\[Pi]\^2\ x\^2\)\/12\), "+", 
        \(1\/6\ PolyGamma[2, 1]\ x\^3\), "+", \(\(\[Pi]\^4\ x\^4\)\/360\), 
        "+", \(1\/120\ PolyGamma[4, 1]\ x\^5\), "+", 
        InterpretationBox[\(O[x]\^6\),
          SeriesData[ x, 0, {}, 1, 6, 1]]}],
      SeriesData[ x, 0, {
        Times[ -1, EulerGamma], 
        Times[ 
          Rational[ 1, 12], 
          Power[ Pi, 2]], 
        Times[ 
          Rational[ 1, 6], 
          PolyGamma[ 2, 1]], 
        Times[ 
          Rational[ 1, 360], 
          Power[ Pi, 4]], 
        Times[ 
          Rational[ 1, 120], 
          PolyGamma[ 4, 1]]}, 1, 6, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gammalogseries[2] = 
      \(-EulerGamma\)\ x - 
        Plus@@\((
            \(\(-Residue[\(\[Pi]\/Sin[\[Pi]\ z]\) Zeta[z] x\^z\/z, {z, 2 + #}]
                    \)&\)/@Range[0, 3])\)\)], "Input"],

Cell[BoxData[
    \(\(-EulerGamma\)\ x + \(\[Pi]\^2\ x\^2\)\/12 + \(\[Pi]\^4\ x\^4\)\/360 - 
      1\/3\ x\^3\ Zeta[3] - 1\/5\ x\^5\ Zeta[5]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gammalogseries[1] == gammalogseries[2] // Normal\) // FullSimplify\)],
   "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PolyGamma[#, 1] + Gamma[# + 1] Zeta[# + 1]&\)/@Range[7] // 
      FullSimplify\)], "Input"],

Cell[BoxData[
    \({\[Pi]\^2\/3, 0, \(2\ \[Pi]\^4\)\/15, 0, \(16\ \[Pi]\^6\)\/63, 0, 
      \(16\ \[Pi]\^8\)\/15}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Zeta\)\)], "Input"],

Cell[BoxData[
    \("Zeta[s] gives the Riemann zeta function. Zeta[s, a] gives the \
generalized Riemann zeta function."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PolyGamma\)\)], "Input"],

Cell[BoxData[
    \("PolyGamma[z] gives the digamma function psi(z). PolyGamma[n, z] gives \
the nth derivative of the digamma function."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Gamma'\)[z]\/Gamma[z]\)], "Input"],

Cell[BoxData[
    \(PolyGamma[0, z]\)], "Output"]
}, Open  ]],

Cell["\<\
which I present here without proof. From this formula, which expresses a \
remarkable connection between the gamma and Riemann's zeta function, arises \
Stirling's formula by shifting of the integration path into negative \
direction.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(-EulerGamma\)\ x - 
      Plus@@\((\(Residue[
                \(\[Pi]\/Sin[\[Pi]\ z]\) Zeta[z] x\^z\/z, {z, 1 - #}]&\)/@
            Range[0, 5])\)\), 
    \(\(\[ExponentialE]\^% // Simplify\) // ExpandAll\)}], "Input"],

Cell[BoxData[
    \(\(-\(1\/\(360\ x\^3\)\)\) + 1\/\(12\ x\) - EulerGamma\ x + 
      x\ \((\(-1\) + EulerGamma + Log[x])\) + 
      1\/2\ \((Log[2\ \[Pi]] + Log[x])\)\)], "Output"],

Cell[BoxData[
    \(E\^\(\(-\(1\/\(360\ x\^3\)\)\) + 1\/\(12\ x\) - x\)\ \@\(2\ \[Pi]\)\ 
      x\^\(1\/2 + x\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Log[Gamma[1\/x + 1]], {x, 0, 4}]\)], "Input"],

Cell[BoxData[
    RowBox[{
    \(Series::"esss"\), \( : \ \), 
      "\<\"Essential singularity encountered in \
\\!\\(Gamma[\\(\\*InterpretationBox[\\(1\\/x + 1 + \
\\*InterpretationBox[\\(\\(O[x]\\)\\^5\\), SeriesData[x, 0, List[], -1, 5, \
1]]\\), SeriesData[x, 0, List[1, 1], -1, 5, 1]]\\)]\\).\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{"Log", "[", 
      RowBox[{"Gamma", "[", 
        InterpretationBox[
          RowBox[{\(1\/x\), "+", "1", "+", 
            InterpretationBox[\(O[x]\^5\),
              SeriesData[ x, 0, {}, -1, 5, 1]]}],
          SeriesData[ x, 0, {1, 1}, -1, 5, 1]], "]"}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From the position of our uniform theory of the gamma and the \
hypergeometric functions the integral formulae within the conventional theory \
of the gamma function give a very small part of the relations, that can be \
developed on the whole. We must dispense with a more detailed presentation of \
this topic on this occasion. What interesting relations hereby can be found, \
this shows an ",
  ButtonBox["elaboration",
    ButtonData:>"Footnote3Section14",
    ButtonStyle->"Hyperlink"],
  ButtonBox["\[Dagger]",
    ButtonData:>"Footnote3Section14",
    ButtonStyle->"Hyperlink"],
  ButtonBox[")",
    ButtonData:>"Footnote3Section14",
    ButtonStyle->"Hyperlink"],
  " of Mr. ",
  StyleBox["Voronoi",
    FontWeight->"Bold"],
  ", who did his work without knowledge of my theory of the reciprocal \
functions, which is ten years older. However one conclusion of the \
reciprocity law (",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ") shall be emphasized here and elucidated at an example."
}], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi][x]\)]],
  " be a function of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalPhi])\)\)]],
  " due to ",
  ButtonBox["\[Section] 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ". ",
  StyleBox["Then ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)],
    FontSlant->"Italic"],
  " can be presented in manyfold manners as a definite integral on the \
following type:"
}], "Text",
  ParagraphIndent->30,
  FontSlant->"Italic"],

Cell[BoxData[
    \(\(\[CapitalPhi][x] \[Equal] 
      \[Integral]\_0\%\[Infinity] \[CapitalPhi]\_1[x\/t] \[CapitalPhi]\_2[t] 
          \[DifferentialD]t\/t, \)\)], "NumberedEquation1",
  CellTags->"Equation121"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_2\)]],
  " also standing for certain functions of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalPhi])\)\)]],
  "."
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  "This is proved in the following way. If ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " stands for the reciprocal function corresponding  to the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`F[z]\)]],
  " within the formula"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\[CapitalPhi][x] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)F[z] \(x\^\(-z\)\) 
            \[DifferentialD]z\)\)], "NumberedEquation1",
  CellTags->"Equation122"],

Cell[TextData[{
  "can be presented in manyfold manners as a product of two functions ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  " of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((F)\)\)]],
  ". I presuppose, that ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  " as well as ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " behave regularly in the neighbourhood of each finite location within and \
at the border of the stripe ",
  Cell[BoxData[
      \(TraditionalForm\`a < Re[z] < \[Beta]\)]],
  " and there are characterized with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(|z |  \[Equal] \) | s + \[ImaginaryI]\ t | \)]],
  " by the formulae"
}], "Text"],

Cell[BoxData[
    \(\(|\((F\_1[z])\) | 
       \[Equal] 
        \(\[ExponentialE]\^\(\(-\[CurlyTheta]\_1\)\  | t | \)\) f\_1[s, t]\), 
    \ \ \ \ \ \ \ \ \ \ 
    \(|\((F\_2[z])\) | 
       \[Equal] 
        \(\[ExponentialE]\^\(\(-\[CurlyTheta]\_2\)\  | t | \)\) f\_2[s, t]\), 
    \n\(|F[z] | 
       \[Equal] 
        \(\[ExponentialE]\^\(\(-\[CurlyTheta]\)\  | t | \)\) f[s, t]\), 
    \ \ \ \ \ \ \ \ \ \ 
    \[CurlyTheta]\_1 + \[CurlyTheta]\_2 \[Equal] \[CurlyTheta], \)], 
  "Equation"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyTheta]\)]],
  " and the ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " have got the meanings given in ",
  ButtonBox["\[Section]",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ButtonBox[" 8",
    ButtonData:>"Section8",
    ButtonStyle->"Hyperlink"],
  ". Now if ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_2\)]],
  " respectively stand for the reciprocal functions of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  ", then results"
}], "Text"],

Cell[BoxData[
    \(\[CapitalPhi]\_1 \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)F\_1[z] \(x\^\(-z\)\) 
            \[DifferentialD]z\), \ \ \ \ \ \ \ \ \ \ 
    F\_2[z] \[Equal] 
      \[Integral]\_0\%\[Infinity] \[CapitalPhi]\_2[t] \(t\^\(z - 1\)\) 
          \[DifferentialD]t, \n
    \(-\[CurlyTheta]\_1\) < Arg[x] < \(+\[CurlyTheta]\_1\), 
    \ \ \ \ \ \ \ \ \ \ \[Alpha] < a < \[Beta], \ \ \ \ \ \ \ \ \ \ 
    \[Alpha] < Re[z] < \(\[Beta].\)\)], "Equation"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`F[z] \[Equal] F\_1[z] F\_2[z]\)]],
  " is replaced in equation (",
  CounterBox["NumberedEquation", "Equation122"],
  ") and for ",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  " the last expression, then follows equation (",
  CounterBox["NumberedEquation", "Equation121"],
  ") by inversion of the integration order."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
      \(\[Integral]\_0
          \%\[Infinity]\((
            \[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                  \[ImaginaryI]\ \[Infinity]\)F\_1[z] \[CapitalPhi]\_2[t] 
                t\^z\ \(x\^\(-z\)\) \[DifferentialD]z)\) 
          \[DifferentialD]t\/t\)\), 
    \(% /. {
        \[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
                \[ImaginaryI]\ \[Infinity]\)F\_1[z] \[CapitalPhi]\_2[t] t\^z\ 
              \(x\^\(-z\)\) \[DifferentialD]z \[Rule] 
          \[CapitalPhi]\_1[x\/t] \[CapitalPhi]\_2[t]}\)}], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{"I", " ", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], 
            RowBox[{
              FractionBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SubsuperscriptBox["\[Integral]", 
                        InterpretationBox[\(\(-I\)\ \[Infinity]\),
                          DirectedInfinity[ 
                            Complex[ 0, -1]]], 
                        InterpretationBox[\(I\ \[Infinity]\),
                          DirectedInfinity[ 
                            Complex[ 0, 1]]]], 
                      \(\(t\^z\ x\^\(-z\)\ F\_1[z]\) \[DifferentialD]z\)}], 
                    ")"}], " ", \(\[CapitalPhi]\_2[t]\)}], "t"], 
              \(\[DifferentialD]t\)}]}]}], \(2\ \[Pi]\)]}]], "Output"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{"I", " ", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], 
            \(\(\(\[CapitalPhi]\_1[x\/t]\ \[CapitalPhi]\_2[t]\)\/t\) 
              \[DifferentialD]t\)}]}], \(2\ \[Pi]\)]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A simple example for this yields the formula being found by use of \
equation (",
  CounterBox["NumberedEquation", "Equation40"],
  ")"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)\(\[CapitalGamma]\^2\)[z] 
            \(x\^\(-z\)\) \[DifferentialD]z\) \[Equal] 
      \[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(\(-x\)\/t\)\) 
          \(\[ExponentialE]\^\(-t\)\) \[DifferentialD]t\/t, 
    \ \ \ \ \ \ \ \ \ \ a > 0.\)], "Equation"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(\(-x\)\/t\)\) 
          \(\[ExponentialE]\^\(-t\)\) \[DifferentialD]t\/t /. {
        If[a_, b_, __] \[RuleDelayed] \((Print[a]; b)\)}\), 
    \(\[Integral]\_0\%\[Infinity] % \( x\^\(z - 1\)\) \[DifferentialD]x /. {
        If[a_, b_, __] \[RuleDelayed] \((Print[a]; b)\)}\), 
    \(% == Gamma[z]\^2\)}], "Input"],

Cell[BoxData[
    \(Re[x] > 0\)], "Print"],

Cell[BoxData[
    \(2\ BesselK[0, 2\ \@x]\)], "Output"],

Cell[BoxData[
    \(Gamma[z]\^2\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In an analogous way results, that also each function of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((F)\)\)]],
  " in manyfold manners can be presented as a definite integral of the \
following type:"
}], "Text",
  ParagraphIndent->30],

Cell[BoxData[
    \(\(F[s] \[Equal] 
      \(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
        \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
              \[ImaginaryI]\ \[Infinity]\)F\_1[s - z] F\_2[z] 
            \[DifferentialD]z\), \)\)], "NumberedEquation1"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_2\)]],
  " also being functions of the class ",
  Cell[BoxData[
      \(TraditionalForm\`\((F)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
  \(\(1\/\(2  \[Pi]\ \[ImaginaryI]\)\) 
      \(\[Integral]\_\(a - \[ImaginaryI]\ \[Infinity]\)\%\(a + 
            \[ImaginaryI]\ \[Infinity]\)\((
            \[Integral]\_0\%\[Infinity]\( x\^\(-z\)\) \[CapitalPhi]\_1[x] 
                F\_2[z] \(x\^\(s - 1\)\) \[DifferentialD]x)\) 
          \[DifferentialD]z\)\), 
    RowBox[{"%", "/.", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], 
            \(x\^\(\(-1\) + s - z\)\ \[CapitalPhi]\_1[x] F\_2[z] 
              \[DifferentialD]x\)}], "\[Rule]", \(F\_1[s - z] F\_2[z]\)}], 
        "}"}]}]}], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{"I", " ", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", 
              InterpretationBox[\(\(-I\)\ \[Infinity]\),
                DirectedInfinity[ 
                  Complex[ 0, -1]]], 
              InterpretationBox[\(I\ \[Infinity]\),
                DirectedInfinity[ 
                  Complex[ 0, 1]]]], 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    SubsuperscriptBox["\[Integral]", "0", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    \(\(x\^\(\(-1\) + s - z\)\ \[CapitalPhi]\_1[x]\) 
                      \[DifferentialD]x\)}], ")"}], " ", \(F\_2[z]\)}], 
              \(\[DifferentialD]z\)}]}]}], \(2\ \[Pi]\)]}]], "Output"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{"I", " ", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", 
              InterpretationBox[\(\(-I\)\ \[Infinity]\),
                DirectedInfinity[ 
                  Complex[ 0, -1]]], 
              InterpretationBox[\(I\ \[Infinity]\),
                DirectedInfinity[ 
                  Complex[ 0, 1]]]], 
            \(\(F\_1[s - z]\ F\_2[z]\) \[DifferentialD]z\)}]}], 
        \(2\ \[Pi]\)]}]], "Output"]
}, Open  ]],

Cell[TextData[ButtonBox[
"For gamma and hypergeometric functions of several variables a theory can be \
developed, that is totally analogeous to the one dealed with in this \
elaboration.",
  ButtonData:>"Footnote4Section14",
  ButtonStyle->"Hyperlink"],
ButtonBox["\[Dagger]\[Dagger]",
  ButtonData:>"Footnote4Section14",
  ButtonStyle->"Hyperlink"],
ButtonBox[")",
  ButtonData:>"Footnote4Section14",
  ButtonStyle->"Hyperlink"]], "Text",
  ParagraphIndent->30],

Cell[TextData[{
  StyleBox["Helsingfors",
    FontWeight->"Bold"],
  ", ",
  StyleBox["June 1909",
    FontWeight->"Plain"],
  "."
}], "Text",
  ParagraphIndent->30],

Cell["\<\
*) Eine Formel f\[UDoubleDot]r den Logarithmus transzendenter Funktionen von \
endlichem Geschlecht. (A formula of the logarithm of transcendental functions \
of finite classification order) Acta Math. vol. 25.\
\>", "Text",
  ParagraphIndent->40,
  CellTags->"Footnote1Section14"],

Cell[TextData[
"**) Sur le d\[EAcute]veloppement de log \[CapitalGamma](a). Journal de Math. \
(4) vol. 5"], "Text",
  ParagraphIndent->30,
  CellTags->"Footnote2Section14"],

Cell[TextData[
"\[Dagger]) Sur une fonction transcendante et ses applications \[AGrave] la \
sommation de quelques s\[EAcute]ries. Annales de l'\[CapitalEAcute]cole \
Norm., 3. S\[EAcute]rie, T. 21. 1904."], "Text",
  ParagraphIndent->40,
  CellTags->"Footnote3Section14"],

Cell[TextData[
"\[Dagger]\[Dagger]) Look at: Zur Theorie zweier allgemeiner Klassen \
bestimmter Integrale. (On the theory of two general classes of definite \
integrals), Acta Soc. Sc. Fennicae. T. 22. 1896."], "Text",
  ParagraphIndent->30,
  CellTags->"Footnote4Section14"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Protocol", "Section"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version has been:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({$Version, $ReleaseNumber, $LicenseID}\)], "Input"],

Cell[BoxData[
    \({"Microsoft Windows 3.0 (October 6, 1996)", 0, "L4526-3546"}\)], 
  "Output"]
}, Open  ]],

Cell["The calculation time was (in seconds):", "Text"],

Cell[BoxData[
    \(TimeUsed[\ ]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowSize->{640, 393},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "\[Copyright] Norbert S\[UDoubleDot]dland"], "Header"], 
      Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ "\[Copyright] Norbert S\[UDoubleDot]dland"], "Header"], 
      Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0.8, 0.300008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.500008, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.500008, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellFrame->True,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
            FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Center,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Condensed"],
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Presentation"],
    FontSize->16,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Condensed"],
    FontSize->11,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "[Mel1910]"->{
    Cell[2726, 81, 332, 12, 93, "Text",
      CellTags->"[Mel1910]"]},
  "FootnoteAbstract"->{
    Cell[4778, 135, 313, 8, 93, "Text",
      CellTags->"FootnoteAbstract"]},
  "Equation3"->{
    Cell[6472, 196, 125, 3, 35, "NumberedEquation1",
      CellTags->"Equation3"]},
  "Equation4"->{
    Cell[8662, 272, 140, 3, 58, "NumberedEquation1",
      CellTags->"Equation4"]},
  "Equation5"->{
    Cell[9054, 285, 316, 6, 75, "NumberedEquation1",
      CellTags->"Equation5"]},
  "Equation6"->{
    Cell[9890, 314, 132, 3, 35, "NumberedEquation1",
      CellTags->"Equation6"]},
  "Equation7"->{
    Cell[10299, 334, 159, 3, 56, "NumberedEquation1",
      CellTags->"Equation7"]},
  "Equation8"->{
    Cell[12170, 395, 226, 5, 77, "NumberedEquation1",
      CellTags->"Equation8"]},
  "Equation9"->{
    Cell[13389, 437, 347, 8, 56, "NumberedEquation1",
      CellTags->"Equation9"]},
  "Equation10"->{
    Cell[14802, 480, 168, 3, 55, "NumberedEquation1",
      CellTags->"Equation10"]},
  "FootnoteSection1"->{
    Cell[16282, 535, 190, 5, 69, "Text",
      CellTags->"FootnoteSection1"]},
  "Section2"->{
    Cell[16509, 545, 285, 10, 76, "Section",
      CellTags->"Section2"]},
  "Equation11"->{
    Cell[17378, 576, 319, 6, 56, "NumberedEquation1",
      CellTags->"Equation11"]},
  "Equation12"->{
    Cell[18132, 604, 550, 10, 132, "NumberedEquation1",
      CellTags->"Equation12"]},
  "Equation13"->{
    Cell[26607, 856, 257, 6, 57, "NumberedEquation1",
      CellTags->"Equation13"]},
  "Equation14"->{
    Cell[27456, 883, 279, 6, 56, "NumberedEquation1",
      CellTags->"Equation14"]},
  "Footnote1Section2"->{
    Cell[29535, 947, 178, 4, 45, "Text",
      CellTags->"Footnote1Section2"]},
  "Footnote2Section2"->{
    Cell[29716, 953, 728, 23, 133, "Text",
      CellTags->"Footnote2Section2"]},
  "Footnote3Section2"->{
    Cell[30447, 978, 235, 6, 69, "Text",
      CellTags->"Footnote3Section2"]},
  "Footnote4Section2"->{
    Cell[30685, 986, 167, 4, 45, "Text",
      CellTags->"Footnote4Section2"]},
  "Section3"->{
    Cell[30889, 995, 136, 5, 76, "Section",
      CellTags->"Section3"]},
  "Equation15"->{
    Cell[31144, 1007, 123, 3, 35, "NumberedEquation1",
      CellTags->"Equation15"]},
  "Equation16"->{
    Cell[31401, 1019, 310, 6, 57, "NumberedEquation1",
      CellTags->"Equation16"],
    Cell[54257, 1741, 811, 16, 270, "Input",
      CellTags->"Equation16"]},
  "Equation17"->{
    Cell[31759, 1029, 349, 7, 35, "NumberedEquation1",
      CellTags->"Equation17"],
    Cell[48619, 1570, 848, 14, 208, "Input",
      CellTags->"Equation17"],
    Cell[49545, 1592, 878, 14, 226, "Input",
      CellTags->"Equation17"],
    Cell[50501, 1614, 1150, 19, 320, "Input",
      CellTags->"Equation17"]},
  "Equation21"->{
    Cell[40378, 1300, 528, 10, 114, "NumberedEquation1",
      CellTags->"Equation21"],
    Cell[45468, 1469, 355, 7, 63, "NumberedEquation1",
      CellTags->"Equation21"]},
  "Section4"->{
    Cell[45008, 1451, 298, 10, 104, "Section",
      CellTags->"Section4"]},
  "Equation23"->{
    Cell[46176, 1488, 194, 4, 49, "NumberedEquation1",
      CellTags->"Equation23"]},
  "Equation24"->{
    Cell[46373, 1494, 194, 4, 49, "NumberedEquation1",
      CellTags->"Equation24"]},
  "Equation25"->{
    Cell[46570, 1500, 312, 7, 49, "NumberedEquation1",
      CellTags->"Equation25"]},
  "Section5"->{
    Cell[51741, 1642, 298, 10, 104, "Section",
      CellTags->"Section5"]},
  "Equation27"->{
    Cell[52200, 1661, 190, 5, 35, "NumberedEquation1",
      CellTags->"Equation27"]},
  "Equation28"->{
    Cell[52425, 1670, 235, 6, 56, "NumberedEquation1",
      CellTags->"Equation28"]},
  "Equation30"->{
    Cell[57335, 1836, 322, 5, 54, "NumberedEquation1",
      CellTags->"Equation30"]},
  "Equation31"->{
    Cell[57682, 1845, 361, 7, 81, "NumberedEquation1",
      CellTags->"Equation31"]},
  "Section6"->{
    Cell[66345, 2146, 164, 5, 104, "Section",
      CellTags->"Section6"]},
  "Equation34"->{
    Cell[68196, 2201, 592, 11, 58, "NumberedEquation1",
      CellTags->"Equation34"]},
  "Equation35"->{
    Cell[70293, 2266, 706, 13, 86, "NumberedEquation1",
      CellTags->"Equation35"]},
  "Equation36"->{
    Cell[71412, 2294, 408, 7, 57, "NumberedEquation1",
      CellTags->"Equation36"]},
  "Equation37"->{
    Cell[72462, 2320, 491, 9, 58, "NumberedEquation1",
      CellTags->"Equation37"]},
  "Equation38"->{
    Cell[73017, 2333, 309, 6, 58, "NumberedEquation1",
      CellTags->"Equation38"]},
  "Equation39"->{
    Cell[74823, 2394, 194, 4, 73, "NumberedEquation1",
      CellTags->"Equation39"]},
  "Equation40"->{
    Cell[81820, 2609, 689, 14, 80, "NumberedEquation1",
      CellTags->"Equation40"]},
  "FootnoteSection6"->{
    Cell[83539, 2659, 397, 11, 117, "Text",
      CellTags->"FootnoteSection6"]},
  "Equation41"->{
    Cell[85905, 2736, 196, 4, 38, "NumberedEquation1",
      CellTags->"Equation41"]},
  "Equation42"->{
    Cell[87853, 2800, 188, 4, 56, "NumberedEquation1",
      CellTags->"Equation42"]},
  "Equation43"->{
    Cell[88044, 2806, 304, 6, 58, "NumberedEquation1",
      CellTags->"Equation43"]},
  "Section8"->{
    Cell[89859, 2863, 157, 5, 104, "Section",
      CellTags->"Section8"]},
  "Equation44"->{
    Cell[91286, 2913, 162, 3, 35, "NumberedEquation1",
      CellTags->"Equation44"]},
  "Equation45"->{
    Cell[91707, 2928, 175, 4, 37, "NumberedEquation1",
      CellTags->"Equation45"]},
  "Equation46"->{
    Cell[92275, 2948, 361, 7, 58, "NumberedEquation1",
      CellTags->"Equation46"]},
  "Equation47"->{
    Cell[92888, 2967, 297, 6, 53, "NumberedEquation1",
      CellTags->"Equation47"]},
  "Equation48"->{
    Cell[93275, 2978, 133, 3, 35, "NumberedEquation1",
      CellTags->"Equation48"]},
  "Equation49"->{
    Cell[95513, 3059, 373, 6, 70, "NumberedEquation1",
      CellTags->"Equation49"]},
  "Equation52"->{
    Cell[100409, 3220, 635, 12, 124, "NumberedEquation1",
      CellTags->"Equation52"]},
  "Equation54"->{
    Cell[107119, 3406, 571, 11, 57, "NumberedEquation1",
      CellTags->"Equation54"]},
  "Equation55"->{
    Cell[108566, 3450, 150, 3, 35, "NumberedEquation1",
      CellTags->"Equation55"]},
  "Equation58"->{
    Cell[110172, 3504, 178, 5, 37, "NumberedEquation1",
      CellTags->"Equation58"]},
  "Equation61"->{
    Cell[118391, 3742, 656, 11, 58, "NumberedEquation1",
      CellTags->"Equation61"]},
  "Equation62"->{
    Cell[122220, 3847, 701, 15, 80, "NumberedEquation1",
      CellTags->"Equation62"]},
  "Equation63"->{
    Cell[123964, 3895, 620, 12, 57, "NumberedEquation1",
      CellTags->"Equation63"]},
  "Footnote1Section8"->{
    Cell[128320, 4024, 268, 6, 93, "Text",
      CellTags->"Footnote1Section8"]},
  "Footnote2Section8"->{
    Cell[128591, 4032, 248, 6, 93, "Text",
      CellTags->"Footnote2Section8"]},
  "Equation68"->{
    Cell[143368, 4496, 277, 6, 69, "NumberedEquation1",
      CellTags->"Equation68"]},
  "Equation69"->{
    Cell[144945, 4548, 410, 9, 73, "NumberedEquation1",
      CellTags->"Equation69"]},
  "Equation70"->{
    Cell[147222, 4618, 150, 3, 35, "NumberedEquation1",
      CellTags->"Equation70"]},
  "Section10"->{
    Cell[147932, 4641, 142, 6, 76, "Section",
      CellTags->"Section10"]},
  "Equation71"->{
    Cell[148497, 4665, 449, 13, 37, "NumberedEquation1",
      CellTags->"Equation71"]},
  "Equation72"->{
    Cell[149172, 4690, 197, 5, 57, "NumberedEquation1",
      CellTags->"Equation72"]},
  "Equation75"->{
    Cell[156929, 4953, 214, 5, 57, "NumberedEquation1",
      CellTags->"Equation75"]},
  "Equation76"->{
    Cell[157403, 4968, 96, 2, 35, "NumberedEquation1",
      CellTags->"Equation76"]},
  "Equation80"->{
    Cell[163611, 5151, 848, 23, 63, "NumberedEquation1",
      CellTags->"Equation80"]},
  "Equation81"->{
    Cell[167345, 5252, 134, 3, 58, "NumberedEquation1",
      CellTags->"Equation81"]},
  "Footnote1Section10"->{
    Cell[170350, 5342, 133, 2, 45, "Text",
      CellTags->"Footnote1Section10"]},
  "Footnote2Section10"->{
    Cell[170486, 5346, 418, 7, 117, "Text",
      CellTags->"Footnote2Section10"]},
  "Section11"->{
    Cell[170941, 5358, 202, 6, 104, "Section",
      CellTags->"Section11"]},
  "Equation82"->{
    Cell[172264, 5403, 448, 13, 37, "NumberedEquation1",
      CellTags->"Equation82"]},
  "Section12"->{
    Cell[184154, 5741, 241, 8, 104, "Section",
      CellTags->"Section12"]},
  "Equation90"->{
    Cell[188973, 5886, 306, 6, 58, "NumberedEquation1",
      CellTags->"Equation90"]},
  "Equation91"->{
    Cell[189710, 5913, 194, 4, 35, "NumberedEquation1",
      CellTags->"Equation91"]},
  "Equation95"->{
    Cell[193046, 6018, 256, 4, 35, "NumberedEquation1",
      CellTags->"Equation95"]},
  "Equation96"->{
    Cell[199241, 6201, 192, 4, 38, "NumberedEquation1",
      CellTags->"Equation96"]},
  "Equation97"->{
    Cell[200618, 6250, 584, 12, 138, "NumberedEquation1",
      CellTags->"Equation97"]},
  "Equation99"->{
    Cell[202305, 6304, 370, 9, 70, "NumberedEquation1",
      CellTags->"Equation99"]},
  "Equation100"->{
    Cell[202702, 6317, 444, 9, 70, "NumberedEquation1",
      CellTags->"Equation100"]},
  "Equation102"->{
    Cell[205547, 6405, 235, 4, 70, "NumberedEquation1",
      CellTags->"Equation102"]},
  "Equation105"->{
    Cell[207183, 6453, 317, 6, 69, "NumberedEquation1",
      CellTags->"Equation105"]},
  "Equation106"->{
    Cell[207635, 6466, 359, 7, 69, "NumberedEquation1",
      CellTags->"Equation106"]},
  "Equation109"->{
    Cell[213535, 6629, 283, 5, 70, "NumberedEquation1",
      CellTags->"Equation109"]},
  "Equation110"->{
    Cell[214030, 6646, 283, 5, 70, "NumberedEquation1",
      CellTags->"Equation110"]},
  "Equation114"->{
    Cell[222396, 6860, 422, 7, 60, "NumberedEquation1",
      CellTags->"Equation114"]},
  "Equation121"->{
    Cell[251977, 7705, 213, 4, 57, "NumberedEquation1",
      CellTags->"Equation121"]},
  "Equation122"->{
    Cell[252893, 7739, 300, 6, 58, "NumberedEquation1",
      CellTags->"Equation122"]},
  "Footnote1Section14"->{
    Cell[263040, 8051, 291, 6, 93, "Text",
      CellTags->"Footnote1Section14"]},
  "Footnote2Section14"->{
    Cell[263334, 8059, 173, 4, 45, "Text",
      CellTags->"Footnote2Section14"]},
  "Footnote3Section14"->{
    Cell[263510, 8065, 272, 5, 69, "Text",
      CellTags->"Footnote3Section14"]},
  "Footnote4Section14"->{
    Cell[263785, 8072, 276, 5, 93, "Text",
      CellTags->"Footnote4Section14"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"[Mel1910]", 305385, 9563},
  {"FootnoteAbstract", 305480, 9566},
  {"Equation3", 305575, 9569},
  {"Equation4", 305676, 9572},
  {"Equation5", 305777, 9575},
  {"Equation6", 305878, 9578},
  {"Equation7", 305979, 9581},
  {"Equation8", 306081, 9584},
  {"Equation9", 306183, 9587},
  {"Equation10", 306286, 9590},
  {"FootnoteSection1", 306396, 9593},
  {"Section2", 306491, 9596},
  {"Equation11", 306584, 9599},
  {"Equation12", 306688, 9602},
  {"Equation13", 306794, 9605},
  {"Equation14", 306898, 9608},
  {"Footnote1Section2", 307009, 9611},
  {"Footnote2Section2", 307114, 9614},
  {"Footnote3Section2", 307221, 9617},
  {"Footnote4Section2", 307326, 9620},
  {"Section3", 307422, 9623},
  {"Equation15", 307514, 9626},
  {"Equation16", 307619, 9629},
  {"Equation17", 307800, 9634},
  {"Equation21", 308134, 9643},
  {"Section4", 308325, 9648},
  {"Equation23", 308420, 9651},
  {"Equation24", 308525, 9654},
  {"Equation25", 308630, 9657},
  {"Section5", 308733, 9660},
  {"Equation27", 308828, 9663},
  {"Equation28", 308933, 9666},
  {"Equation30", 309038, 9669},
  {"Equation31", 309143, 9672},
  {"Section6", 309246, 9675},
  {"Equation34", 309340, 9678},
  {"Equation35", 309446, 9681},
  {"Equation36", 309552, 9684},
  {"Equation37", 309657, 9687},
  {"Equation38", 309762, 9690},
  {"Equation39", 309867, 9693},
  {"Equation40", 309972, 9696},
  {"FootnoteSection6", 310084, 9699},
  {"Equation41", 310184, 9702},
  {"Equation42", 310289, 9705},
  {"Equation43", 310394, 9708},
  {"Section8", 310497, 9711},
  {"Equation44", 310591, 9714},
  {"Equation45", 310696, 9717},
  {"Equation46", 310801, 9720},
  {"Equation47", 310906, 9723},
  {"Equation48", 311011, 9726},
  {"Equation49", 311116, 9729},
  {"Equation52", 311221, 9732},
  {"Equation54", 311329, 9735},
  {"Equation55", 311436, 9738},
  {"Equation58", 311542, 9741},
  {"Equation61", 311648, 9744},
  {"Equation62", 311755, 9747},
  {"Equation63", 311862, 9750},
  {"Footnote1Section8", 311976, 9753},
  {"Footnote2Section8", 312083, 9756},
  {"Equation68", 312183, 9759},
  {"Equation69", 312289, 9762},
  {"Equation70", 312395, 9765},
  {"Section10", 312500, 9768},
  {"Equation71", 312595, 9771},
  {"Equation72", 312702, 9774},
  {"Equation75", 312808, 9777},
  {"Equation76", 312914, 9780},
  {"Equation80", 313019, 9783},
  {"Equation81", 313126, 9786},
  {"Footnote1Section10", 313240, 9789},
  {"Footnote2Section10", 313349, 9792},
  {"Section11", 313450, 9795},
  {"Equation82", 313546, 9798},
  {"Section12", 313652, 9801},
  {"Equation90", 313748, 9804},
  {"Equation91", 313854, 9807},
  {"Equation95", 313960, 9810},
  {"Equation96", 314066, 9813},
  {"Equation97", 314172, 9816},
  {"Equation99", 314280, 9819},
  {"Equation100", 314387, 9822},
  {"Equation102", 314495, 9825},
  {"Equation105", 314603, 9828},
  {"Equation106", 314711, 9831},
  {"Equation109", 314819, 9834},
  {"Equation110", 314927, 9837},
  {"Equation114", 315035, 9840},
  {"Equation121", 315143, 9843},
  {"Equation122", 315251, 9846},
  {"Footnote1Section14", 315366, 9849},
  {"Footnote2Section14", 315475, 9852},
  {"Footnote3Section14", 315584, 9855},
  {"Footnote4Section14", 315693, 9858}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 261, 3, 154, "Title",
  CounterAssignments->{{"Title", 0}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],
Cell[1995, 56, 487, 11, 245, "Subsubtitle"],
Cell[2485, 69, 124, 5, 45, "Text"],
Cell[2612, 76, 51, 1, 41, "Input"],
Cell[2666, 79, 57, 0, 45, "Text"],
Cell[2726, 81, 332, 12, 93, "Text",
  CellTags->"[Mel1910]"],

Cell[CellGroupData[{
Cell[3083, 97, 118, 3, 123, "Subtitle"],
Cell[3204, 102, 92, 4, 95, "Subsubtitle"],
Cell[3299, 108, 1476, 25, 405, "Text"],
Cell[4778, 135, 313, 8, 93, "Text",
  CellTags->"FootnoteAbstract"],

Cell[CellGroupData[{
Cell[5116, 147, 119, 5, 76, "Section"],
Cell[5238, 154, 53, 1, 45, "Text"],
Cell[5294, 157, 440, 8, 69, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[5759, 169, 166, 4, 77, "Input"],
Cell[5928, 175, 38, 1, 41, "Output"]
}, Open  ]],
Cell[5981, 179, 198, 4, 93, "Text"],
Cell[6182, 185, 160, 3, 69, "NumberedEquation1"],
Cell[6345, 190, 124, 4, 45, "Text"],
Cell[6472, 196, 125, 3, 35, "NumberedEquation1",
  CellTags->"Equation3"],
Cell[6600, 201, 294, 8, 69, "Text"],
Cell[6897, 211, 729, 13, 120, "Equation"],

Cell[CellGroupData[{
Cell[7651, 228, 155, 3, 69, "Input"],
Cell[7809, 233, 38, 1, 41, "Output"]
}, Open  ]],
Cell[7862, 237, 32, 0, 45, "Text"],
Cell[7897, 239, 185, 4, 54, "Equation"],

Cell[CellGroupData[{
Cell[8107, 247, 100, 2, 76, "Input"],
Cell[8210, 251, 44, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8291, 257, 48, 1, 41, "Input"],
Cell[8342, 260, 128, 2, 60, "Print"]
}, Open  ]],
Cell[8485, 265, 174, 5, 69, "Text"],
Cell[8662, 272, 140, 3, 58, "NumberedEquation1",
  CellTags->"Equation4"],
Cell[8805, 277, 246, 6, 69, "Text"],
Cell[9054, 285, 316, 6, 75, "NumberedEquation1",
  CellTags->"Equation5"],

Cell[CellGroupData[{
Cell[9395, 295, 256, 5, 121, "Input"],
Cell[9654, 302, 38, 1, 41, "Output"]
}, Open  ]],
Cell[9707, 306, 180, 6, 45, "Text"],
Cell[9890, 314, 132, 3, 35, "NumberedEquation1",
  CellTags->"Equation6"],

Cell[CellGroupData[{
Cell[10047, 321, 76, 1, 41, "Input"],
Cell[10126, 324, 38, 1, 41, "Output"]
}, Open  ]],
Cell[10179, 328, 117, 4, 45, "Text"],
Cell[10299, 334, 159, 3, 56, "NumberedEquation1",
  CellTags->"Equation7"],

Cell[CellGroupData[{
Cell[10483, 341, 98, 2, 65, "Input"],
Cell[10584, 345, 38, 1, 41, "Output"]
}, Open  ]],
Cell[10637, 349, 137, 6, 45, "Text"],
Cell[10777, 357, 636, 11, 170, "Equation"],

Cell[CellGroupData[{
Cell[11438, 372, 278, 4, 154, "Input"],
Cell[11719, 378, 38, 1, 41, "Output"]
}, Open  ]],
Cell[11772, 382, 395, 11, 109, "Text"],
Cell[12170, 395, 226, 5, 77, "NumberedEquation1",
  CellTags->"Equation8"],

Cell[CellGroupData[{
Cell[12421, 404, 593, 11, 193, "Input"],
Cell[13017, 417, 38, 1, 41, "Output"]
}, Open  ]],
Cell[13070, 421, 148, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[13243, 430, 93, 1, 95, "Input"],
Cell[13339, 433, 35, 1, 41, "Output"]
}, Open  ]],
Cell[13389, 437, 347, 8, 56, "NumberedEquation1",
  CellTags->"Equation9"],

Cell[CellGroupData[{
Cell[13761, 449, 250, 4, 187, "Input"],
Cell[14014, 455, 131, 2, 64, "Output"],
Cell[14148, 459, 35, 1, 41, "Output"]
}, Open  ]],
Cell[14198, 463, 147, 4, 45, "Text"],
Cell[14348, 469, 419, 7, 57, "Equation"],
Cell[14770, 478, 29, 0, 45, "Text"],
Cell[14802, 480, 168, 3, 55, "NumberedEquation1",
  CellTags->"Equation10"],

Cell[CellGroupData[{
Cell[14995, 487, 121, 2, 70, "Input"],
Cell[15119, 491, 38, 1, 41, "Output"]
}, Open  ]],
Cell[15172, 495, 498, 15, 69, "Text"],

Cell[CellGroupData[{
Cell[15695, 514, 275, 5, 105, "Input"],
Cell[15973, 521, 38, 1, 41, "Output"]
}, Open  ]],
Cell[16026, 525, 253, 8, 69, "Text"],
Cell[16282, 535, 190, 5, 69, "Text",
  CellTags->"FootnoteSection1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16509, 545, 285, 10, 76, "Section",
  CellTags->"Section2"],
Cell[16797, 557, 179, 4, 69, "Text"],
Cell[16979, 563, 396, 11, 93, "Text"],
Cell[17378, 576, 319, 6, 56, "NumberedEquation1",
  CellTags->"Equation11"],
Cell[17700, 584, 232, 9, 45, "Text"],
Cell[17935, 595, 194, 7, 45, "Text"],
Cell[18132, 604, 550, 10, 132, "NumberedEquation1",
  CellTags->"Equation12"],

Cell[CellGroupData[{
Cell[18707, 618, 249, 5, 69, "Input"],
Cell[18959, 625, 38, 1, 41, "Output"]
}, Open  ]],
Cell[19012, 629, 504, 14, 69, "Text"],
Cell[19519, 645, 265, 5, 79, "Equation"],

Cell[CellGroupData[{
Cell[19809, 654, 316, 6, 98, "Input"],
Cell[20128, 662, 38, 1, 41, "Output"]
}, Open  ]],
Cell[20181, 666, 24, 0, 45, "Text"],
Cell[20208, 668, 517, 9, 153, "Equation"],

Cell[CellGroupData[{
Cell[20750, 681, 568, 10, 219, "Input"],
Cell[21321, 693, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21396, 699, 859, 15, 223, "Input"],
Cell[22258, 716, 38, 1, 41, "Output"]
}, Open  ]],
Cell[22311, 720, 33, 0, 45, "Text"],
Cell[22347, 722, 497, 9, 135, "Equation"],

Cell[CellGroupData[{
Cell[22869, 735, 628, 12, 230, "Input"],
Cell[23500, 749, 80, 1, 59, "Message"],
Cell[23583, 752, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23658, 758, 243, 5, 120, "Input"],
Cell[23904, 765, 83, 1, 62, "Output"]
}, Open  ]],
Cell[24002, 769, 790, 26, 117, "Text"],
Cell[24795, 797, 82, 1, 53, "Equation"],
Cell[24880, 800, 629, 24, 93, "Text"],
Cell[25512, 826, 638, 11, 135, "Equation"],

Cell[CellGroupData[{
Cell[26175, 841, 233, 3, 135, "Input"],
Cell[26411, 846, 97, 2, 62, "Output"],
Cell[26511, 850, 38, 1, 41, "Output"]
}, Open  ]],
Cell[26564, 854, 40, 0, 45, "Text"],
Cell[26607, 856, 257, 6, 57, "NumberedEquation1",
  CellTags->"Equation13"],
Cell[26867, 864, 586, 17, 93, "Text"],
Cell[27456, 883, 279, 6, 56, "NumberedEquation1",
  CellTags->"Equation14"],

Cell[CellGroupData[{
Cell[27760, 893, 180, 4, 127, "Input"],
Cell[27943, 899, 38, 1, 41, "Output"],
Cell[27984, 902, 61, 1, 52, "Output"]
}, Open  ]],
Cell[28060, 906, 1472, 39, 261, "Text"],
Cell[29535, 947, 178, 4, 45, "Text",
  CellTags->"Footnote1Section2"],
Cell[29716, 953, 728, 23, 133, "Text",
  CellTags->"Footnote2Section2"],
Cell[30447, 978, 235, 6, 69, "Text",
  CellTags->"Footnote3Section2"],
Cell[30685, 986, 167, 4, 45, "Text",
  CellTags->"Footnote4Section2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30889, 995, 136, 5, 76, "Section",
  CellTags->"Section3"],
Cell[31028, 1002, 113, 3, 45, "Text"],
Cell[31144, 1007, 123, 3, 35, "NumberedEquation1",
  CellTags->"Equation15"],
Cell[31270, 1012, 128, 5, 45, "Text"],
Cell[31401, 1019, 310, 6, 57, "NumberedEquation1",
  CellTags->"Equation16"],
Cell[31714, 1027, 42, 0, 45, "Text"],
Cell[31759, 1029, 349, 7, 35, "NumberedEquation1",
  CellTags->"Equation17"],
Cell[32111, 1038, 60, 0, 45, "Text"],
Cell[32174, 1040, 101, 2, 35, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[32300, 1046, 451, 9, 173, "Input"],
Cell[32754, 1057, 38, 1, 41, "Output"]
}, Open  ]],
Cell[32807, 1061, 248, 5, 93, "Text"],
Cell[33058, 1068, 324, 6, 58, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[33407, 1078, 392, 8, 158, "Input"],
Cell[33802, 1088, 38, 1, 41, "Output"]
}, Open  ]],
Cell[33855, 1092, 118, 4, 45, "Text"],
Cell[33976, 1098, 217, 4, 35, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[34218, 1106, 554, 11, 180, "Input"],
Cell[34775, 1119, 38, 1, 41, "Output"]
}, Open  ]],
Cell[34828, 1123, 904, 24, 165, "Text"],
Cell[35735, 1149, 321, 10, 69, "Text"],
Cell[36059, 1161, 475, 15, 93, "Text"],
Cell[36537, 1178, 458, 14, 69, "Text"],
Cell[36998, 1194, 633, 18, 118, "Text"],
Cell[37634, 1214, 168, 3, 38, "Equation"],
Cell[37805, 1219, 299, 8, 69, "Text"],
Cell[38107, 1229, 304, 5, 60, "Equation"],
Cell[38414, 1236, 632, 16, 117, "Text"],
Cell[39049, 1254, 248, 6, 57, "Equation"],
Cell[39300, 1262, 900, 27, 117, "Text"],
Cell[40203, 1291, 172, 7, 45, "Text"],
Cell[40378, 1300, 528, 10, 114, "NumberedEquation1",
  CellTags->"Equation21"],
Cell[40909, 1312, 162, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[41096, 1320, 765, 16, 291, "Input"],
Cell[41864, 1338, 38, 1, 41, "Output"]
}, Open  ]],
Cell[41917, 1342, 1469, 48, 189, "Text"],
Cell[43389, 1392, 448, 16, 69, "Text"],
Cell[43840, 1410, 142, 3, 57, "Equation"],
Cell[43985, 1415, 386, 10, 117, "Text"],
Cell[44374, 1427, 421, 13, 69, "Text"],
Cell[44798, 1442, 173, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45008, 1451, 298, 10, 104, "Section",
  CellTags->"Section4"],
Cell[45309, 1463, 156, 4, 69, "Text"],
Cell[45468, 1469, 355, 7, 63, "NumberedEquation1",
  CellTags->"Equation21"],
Cell[45826, 1478, 347, 8, 93, "Text"],
Cell[46176, 1488, 194, 4, 49, "NumberedEquation1",
  CellTags->"Equation23"],
Cell[46373, 1494, 194, 4, 49, "NumberedEquation1",
  CellTags->"Equation24"],
Cell[46570, 1500, 312, 7, 49, "NumberedEquation1",
  CellTags->"Equation25"],
Cell[46885, 1509, 113, 5, 45, "Text"],
Cell[47001, 1516, 363, 8, 56, "NumberedEquation1"],
Cell[47367, 1526, 84, 2, 46, "Text"],
Cell[47454, 1530, 399, 10, 86, "Equation"],
Cell[47856, 1542, 738, 24, 117, "Text"],

Cell[CellGroupData[{
Cell[48619, 1570, 848, 14, 208, "Input",
  CellTags->"Equation17"],
Cell[49470, 1586, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49545, 1592, 878, 14, 226, "Input",
  CellTags->"Equation17"],
Cell[50426, 1608, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50501, 1614, 1150, 19, 320, "Input",
  CellTags->"Equation17"],
Cell[51654, 1635, 38, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51741, 1642, 298, 10, 104, "Section",
  CellTags->"Section5"],
Cell[52042, 1654, 155, 5, 45, "Text"],
Cell[52200, 1661, 190, 5, 35, "NumberedEquation1",
  CellTags->"Equation27"],
Cell[52393, 1668, 29, 0, 45, "Text"],
Cell[52425, 1670, 235, 6, 56, "NumberedEquation1",
  CellTags->"Equation28"],

Cell[CellGroupData[{
Cell[52685, 1680, 222, 5, 116, "Input"],
Cell[52910, 1687, 129, 3, 62, "Output"]
}, Open  ]],
Cell[53054, 1693, 227, 8, 45, "Text"],
Cell[53284, 1703, 60, 1, 45, "Text"],
Cell[53347, 1706, 247, 6, 35, "NumberedEquation1"],
Cell[53597, 1714, 84, 2, 46, "Text"],
Cell[53684, 1718, 283, 8, 36, "Equation"],
Cell[53970, 1728, 110, 4, 45, "Text"],
Cell[54083, 1734, 149, 3, 53, "Equation"],

Cell[CellGroupData[{
Cell[54257, 1741, 811, 16, 270, "Input",
  CellTags->"Equation16"],
Cell[55071, 1759, 38, 1, 41, "Output"]
}, Open  ]],
Cell[55124, 1763, 26, 0, 45, "Text"],
Cell[55153, 1765, 128, 2, 53, "Equation"],

Cell[CellGroupData[{
Cell[55306, 1771, 235, 3, 181, "Input"],
Cell[55544, 1776, 38, 1, 41, "Output"]
}, Open  ]],
Cell[55597, 1780, 29, 0, 45, "Text"],
Cell[55629, 1782, 159, 3, 53, "Equation"],
Cell[55791, 1787, 600, 21, 93, "Text"],
Cell[56394, 1810, 387, 6, 102, "Equation"],

Cell[CellGroupData[{
Cell[56806, 1820, 436, 8, 184, "Input"],
Cell[57245, 1830, 38, 1, 41, "Output"]
}, Open  ]],
Cell[57298, 1834, 34, 0, 45, "Text"],
Cell[57335, 1836, 322, 5, 54, "NumberedEquation1",
  CellTags->"Equation30"],
Cell[57660, 1843, 19, 0, 45, "Text"],
Cell[57682, 1845, 361, 7, 81, "NumberedEquation1",
  CellTags->"Equation31"],
Cell[58046, 1854, 20, 0, 45, "Text"],
Cell[58069, 1856, 179, 3, 73, "Equation"],
Cell[58251, 1861, 171, 3, 73, "Equation"],

Cell[CellGroupData[{
Cell[58447, 1868, 419, 7, 177, "Input"],
Cell[58869, 1877, 38, 1, 41, "Output"]
}, Open  ]],
Cell[58922, 1881, 1198, 38, 192, "Text"],
Cell[60123, 1921, 263, 5, 38, "Equation"],
Cell[60389, 1928, 1102, 36, 141, "Text"],
Cell[61494, 1966, 391, 9, 93, "Text"],
Cell[61888, 1977, 276, 10, 69, "Text"],
Cell[62167, 1989, 231, 4, 37, "Equation"],
Cell[62401, 1995, 159, 6, 45, "Text"],
Cell[62563, 2003, 234, 4, 61, "NumberedEquation1"],
Cell[62800, 2009, 315, 12, 69, "Text"],
Cell[63118, 2023, 243, 4, 57, "NumberedEquation1"],
Cell[63364, 2029, 126, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[63515, 2039, 90, 1, 69, "Input"],
Cell[63608, 2042, 138, 2, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63783, 2049, 191, 4, 99, "Input"],
Cell[63977, 2055, 330, 7, 59, "Output"],
Cell[64310, 2064, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64382, 2070, 146, 3, 87, "Input"],
Cell[64531, 2075, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64603, 2081, 137, 2, 95, "Input"],
Cell[64743, 2085, 287, 7, 43, "Output"],
Cell[65033, 2094, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65105, 2100, 159, 3, 95, "Input"],
Cell[65267, 2105, 130, 3, 41, "Output"],
Cell[65400, 2110, 35, 1, 41, "Output"]
}, Open  ]],
Cell[65450, 2114, 296, 10, 69, "Text"],

Cell[CellGroupData[{
Cell[65771, 2128, 279, 6, 91, "Input"],
Cell[66053, 2136, 243, 4, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66345, 2146, 164, 5, 104, "Section",
  CellTags->"Section6"],
Cell[66512, 2153, 629, 18, 93, "Text"],
Cell[67144, 2173, 223, 4, 56, "Equation"],
Cell[67370, 2179, 823, 20, 189, "Text"],
Cell[68196, 2201, 592, 11, 58, "NumberedEquation1",
  CellTags->"Equation34"],
Cell[68791, 2214, 297, 8, 69, "Text"],
Cell[69091, 2224, 296, 6, 58, "Equation"],

Cell[CellGroupData[{
Cell[69412, 2234, 89, 1, 63, "Input"],
Cell[69504, 2237, 138, 3, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69679, 2245, 102, 2, 62, "Input"],
Cell[69784, 2249, 343, 8, 63, "Output"]
}, Open  ]],
Cell[70142, 2260, 148, 4, 45, "Text"],
Cell[70293, 2266, 706, 13, 86, "NumberedEquation1",
  CellTags->"Equation35"],
Cell[71002, 2281, 407, 11, 93, "Text"],
Cell[71412, 2294, 408, 7, 57, "NumberedEquation1",
  CellTags->"Equation36"],
Cell[71823, 2303, 636, 15, 141, "Text"],
Cell[72462, 2320, 491, 9, 58, "NumberedEquation1",
  CellTags->"Equation37"],
Cell[72956, 2331, 58, 0, 45, "Text"],
Cell[73017, 2333, 309, 6, 58, "NumberedEquation1",
  CellTags->"Equation38"],
Cell[73329, 2341, 487, 15, 93, "Text"],

Cell[CellGroupData[{
Cell[73841, 2360, 330, 6, 81, "Input"],
Cell[74174, 2368, 151, 2, 54, "Output"],
Cell[74328, 2372, 35, 1, 41, "Output"]
}, Open  ]],
Cell[74378, 2376, 442, 16, 101, "Text"],
Cell[74823, 2394, 194, 4, 73, "NumberedEquation1",
  CellTags->"Equation39"],
Cell[75020, 2400, 444, 14, 69, "Text"],
Cell[75467, 2416, 404, 7, 58, "Equation"],

Cell[CellGroupData[{
Cell[75896, 2427, 64, 1, 41, "Input"],
Cell[75963, 2430, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76035, 2436, 91, 1, 41, "Input"],
Cell[76129, 2439, 141, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76307, 2446, 224, 4, 99, "Input"],
Cell[76534, 2452, 130, 2, 67, "Output"],
Cell[76667, 2456, 50, 1, 64, "Output"]
}, Open  ]],
Cell[76732, 2460, 151, 5, 53, "Text"],
Cell[76886, 2467, 489, 10, 81, "Equation"],
Cell[77378, 2479, 34, 0, 45, "Text"],
Cell[77415, 2481, 357, 7, 81, "Equation"],
Cell[77775, 2490, 398, 13, 69, "Text"],

Cell[CellGroupData[{
Cell[78198, 2507, 240, 4, 130, "Input"],
Cell[78441, 2513, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78516, 2519, 1489, 30, 390, "Input"],
Cell[80008, 2551, 540, 12, 104, "Output"],
Cell[80551, 2565, 526, 12, 94, "Output"],
Cell[81080, 2579, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81152, 2585, 142, 2, 75, "Input"],
Cell[81297, 2589, 38, 1, 41, "Output"]
}, Open  ]],
Cell[81350, 2593, 467, 14, 93, "Text"],
Cell[81820, 2609, 689, 14, 80, "NumberedEquation1",
  CellTags->"Equation40"],
Cell[82512, 2625, 474, 16, 77, "Text"],
Cell[82989, 2643, 547, 14, 117, "Text"],
Cell[83539, 2659, 397, 11, 117, "Text",
  CellTags->"FootnoteSection6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83973, 2675, 145, 4, 104, "Section"],
Cell[84121, 2681, 885, 22, 165, "Text"],
Cell[85009, 2705, 238, 5, 56, "Equation"],
Cell[85250, 2712, 389, 11, 93, "Text"],
Cell[85642, 2725, 260, 9, 45, "Text"],
Cell[85905, 2736, 196, 4, 38, "NumberedEquation1",
  CellTags->"Equation41"],
Cell[86104, 2742, 556, 18, 101, "Text"],
Cell[86663, 2762, 105, 2, 37, "Equation"],
Cell[86771, 2766, 648, 19, 141, "Text"],
Cell[87422, 2787, 428, 11, 93, "Text"],
Cell[87853, 2800, 188, 4, 56, "NumberedEquation1",
  CellTags->"Equation42"],
Cell[88044, 2806, 304, 6, 58, "NumberedEquation1",
  CellTags->"Equation43"],
Cell[88351, 2814, 247, 6, 93, "Text"],
Cell[88601, 2822, 746, 22, 119, "Text"],
Cell[89350, 2846, 472, 12, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89859, 2863, 157, 5, 104, "Section",
  CellTags->"Section8"],
Cell[90019, 2870, 736, 22, 117, "Text"],
Cell[90758, 2894, 525, 17, 93, "Text"],
Cell[91286, 2913, 162, 3, 35, "NumberedEquation1",
  CellTags->"Equation44"],
Cell[91451, 2918, 253, 8, 69, "Text"],
Cell[91707, 2928, 175, 4, 37, "NumberedEquation1",
  CellTags->"Equation45"],
Cell[91885, 2934, 387, 12, 69, "Text"],
Cell[92275, 2948, 361, 7, 58, "NumberedEquation1",
  CellTags->"Equation46"],
Cell[92639, 2957, 246, 8, 45, "Text"],
Cell[92888, 2967, 297, 6, 53, "NumberedEquation1",
  CellTags->"Equation47"],
Cell[93188, 2975, 84, 1, 45, "Text"],
Cell[93275, 2978, 133, 3, 35, "NumberedEquation1",
  CellTags->"Equation48"],
Cell[93411, 2983, 424, 17, 69, "Text"],
Cell[93838, 3002, 323, 10, 69, "Text"],
Cell[94164, 3014, 189, 4, 37, "Equation"],

Cell[CellGroupData[{
Cell[94378, 3022, 524, 11, 123, "Input"],
Cell[94905, 3035, 187, 3, 44, "Output"],
Cell[95095, 3040, 170, 3, 43, "Output"],
Cell[95268, 3045, 38, 1, 41, "Output"]
}, Open  ]],
Cell[95321, 3049, 189, 8, 45, "Text"],
Cell[95513, 3059, 373, 6, 70, "NumberedEquation1",
  CellTags->"Equation49"],
Cell[95889, 3067, 88, 2, 45, "Text"],
Cell[95980, 3071, 607, 11, 70, "Equation"],
Cell[96590, 3084, 371, 11, 93, "Text"],
Cell[96964, 3097, 675, 21, 93, "Text"],
Cell[97642, 3120, 632, 22, 69, "Text"],
Cell[98277, 3144, 415, 14, 69, "Text"],
Cell[98695, 3160, 678, 22, 93, "Text"],
Cell[99376, 3184, 162, 2, 35, "NumberedEquation1"],
Cell[99541, 3188, 208, 7, 45, "Text"],
Cell[99752, 3197, 133, 2, 56, "NumberedEquation1"],
Cell[99888, 3201, 399, 12, 93, "Text"],
Cell[100290, 3215, 116, 3, 45, "Text"],
Cell[100409, 3220, 635, 12, 124, "NumberedEquation1",
  CellTags->"Equation52"],
Cell[101047, 3234, 571, 13, 117, "Text"],
Cell[101621, 3249, 138, 2, 53, "Equation"],

Cell[CellGroupData[{
Cell[101784, 3255, 526, 10, 210, "Input"],
Cell[102313, 3267, 226, 3, 68, "Output"],
Cell[102542, 3272, 203, 3, 64, "Output"],
Cell[102748, 3277, 129, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102914, 3284, 142, 2, 67, "Input"],
Cell[103059, 3288, 38, 1, 41, "Output"]
}, Open  ]],
Cell[103112, 3292, 311, 11, 45, "Text"],
Cell[103426, 3305, 388, 7, 58, "Equation"],
Cell[103817, 3314, 379, 6, 60, "Equation"],
Cell[104199, 3322, 110, 3, 69, "Text"],
Cell[104312, 3327, 1086, 20, 215, "Equation"],
Cell[105401, 3349, 229, 6, 69, "Text"],
Cell[105633, 3357, 170, 3, 55, "Equation"],
Cell[105806, 3362, 108, 5, 45, "Text"],
Cell[105917, 3369, 266, 10, 45, "Text"],
Cell[106186, 3381, 701, 14, 80, "NumberedEquation1"],
Cell[106890, 3397, 226, 7, 69, "Text"],
Cell[107119, 3406, 571, 11, 57, "NumberedEquation1",
  CellTags->"Equation54"],
Cell[107693, 3419, 521, 15, 93, "Text"],
Cell[108217, 3436, 346, 12, 69, "Text"],
Cell[108566, 3450, 150, 3, 35, "NumberedEquation1",
  CellTags->"Equation55"],
Cell[108719, 3455, 863, 27, 117, "Text"],
Cell[109585, 3484, 156, 3, 56, "NumberedEquation1"],
Cell[109744, 3489, 74, 1, 45, "Text"],
Cell[109821, 3492, 126, 2, 35, "NumberedEquation1"],
Cell[109950, 3496, 219, 6, 69, "Text"],
Cell[110172, 3504, 178, 5, 37, "NumberedEquation1",
  CellTags->"Equation58"],
Cell[110353, 3511, 223, 9, 45, "Text"],
Cell[110579, 3522, 560, 17, 69, "Text"],
Cell[111142, 3541, 114, 2, 55, "Equation"],
Cell[111259, 3545, 692, 21, 93, "Text"],
Cell[111954, 3568, 746, 14, 40, "Equation"],
Cell[112703, 3584, 29, 0, 45, "Text"],
Cell[112735, 3586, 513, 10, 61, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[113273, 3600, 1110, 21, 163, "Input"],
Cell[114386, 3623, 243, 4, 43, "Output"],
Cell[114632, 3629, 215, 4, 43, "Output"],
Cell[114850, 3635, 38, 1, 41, "Output"]
}, Open  ]],
Cell[114903, 3639, 461, 14, 93, "Text"],

Cell[CellGroupData[{
Cell[115389, 3657, 695, 14, 125, "Input"],
Cell[116087, 3673, 487, 11, 63, "Output"],
Cell[116577, 3686, 35, 1, 41, "Output"]
}, Open  ]],
Cell[116627, 3690, 195, 7, 45, "Text"],
Cell[116825, 3699, 379, 7, 47, "NumberedEquation1"],
Cell[117207, 3708, 402, 13, 69, "Text"],
Cell[117612, 3723, 75, 1, 45, "Text"],
Cell[117690, 3726, 358, 6, 58, "Equation"],
Cell[118051, 3734, 311, 4, 54, "Equation"],
Cell[118365, 3740, 23, 0, 45, "Text"],
Cell[118391, 3742, 656, 11, 58, "NumberedEquation1",
  CellTags->"Equation61"],

Cell[CellGroupData[{
Cell[119072, 3757, 715, 12, 177, "Input"],
Cell[119790, 3771, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119865, 3777, 617, 10, 201, "Input"],
Cell[120485, 3789, 38, 1, 41, "Output"]
}, Open  ]],
Cell[120538, 3793, 1409, 40, 181, "Text"],
Cell[121950, 3835, 267, 10, 45, "Text"],
Cell[122220, 3847, 701, 15, 80, "NumberedEquation1",
  CellTags->"Equation62"],
Cell[122924, 3864, 84, 2, 46, "Text"],
Cell[123011, 3868, 711, 16, 82, "Equation"],
Cell[123725, 3886, 236, 7, 69, "Text"],
Cell[123964, 3895, 620, 12, 57, "NumberedEquation1",
  CellTags->"Equation63"],
Cell[124587, 3909, 2331, 71, 309, "Text"],
Cell[126921, 3982, 195, 4, 69, "Text"],
Cell[127119, 3988, 178, 5, 69, "Text"],
Cell[127300, 3995, 822, 21, 165, "Text"],
Cell[128125, 4018, 192, 4, 69, "Text"],
Cell[128320, 4024, 268, 6, 93, "Text",
  CellTags->"Footnote1Section8"],
Cell[128591, 4032, 248, 6, 93, "Text",
  CellTags->"Footnote2Section8"]
}, Open  ]],

Cell[CellGroupData[{
Cell[128876, 4043, 117, 5, 76, "Section"],
Cell[128996, 4050, 141, 4, 69, "Text"],
Cell[129140, 4056, 240, 8, 69, "Text"],
Cell[129383, 4066, 478, 10, 57, "Equation"],
Cell[129864, 4078, 219, 9, 45, "Text"],
Cell[130086, 4089, 237, 5, 73, "Equation"],

Cell[CellGroupData[{
Cell[130348, 4098, 134, 3, 66, "Input"],
Cell[130485, 4103, 149, 2, 106, "Output"]
}, Open  ]],
Cell[130649, 4108, 1031, 33, 165, "Text"],
Cell[131683, 4143, 801, 16, 108, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[132509, 4163, 135, 2, 69, "Input"],
Cell[132647, 4167, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132722, 4173, 333, 7, 161, "Input"],
Cell[133058, 4182, 141, 2, 68, "Output"],
Cell[133202, 4186, 342, 7, 110, "Message"],
Cell[133547, 4195, 342, 7, 110, "Message"],
Cell[133892, 4204, 386, 9, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134315, 4218, 246, 5, 103, "Input"],
Cell[134564, 4225, 59, 1, 35, "Print"],
Cell[134626, 4228, 38, 1, 41, "Output"]
}, Open  ]],
Cell[134679, 4232, 157, 4, 69, "Text"],
Cell[134839, 4238, 238, 8, 69, "Text"],
Cell[135080, 4248, 506, 10, 57, "NumberedEquation1"],
Cell[135589, 4260, 194, 5, 69, "Text"],
Cell[135786, 4267, 518, 11, 69, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[136329, 4282, 194, 4, 116, "Input"],
Cell[136526, 4288, 332, 6, 112, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136895, 4299, 194, 4, 116, "Input"],
Cell[137092, 4305, 337, 6, 112, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137466, 4316, 626, 12, 245, "Input"],
Cell[138095, 4330, 352, 6, 97, "Output"],
Cell[138450, 4338, 129, 2, 54, "Output"],
Cell[138582, 4342, 54, 1, 35, "Print"],
Cell[138639, 4345, 38, 1, 41, "Output"]
}, Open  ]],
Cell[138692, 4349, 1038, 28, 189, "Text"],
Cell[139733, 4379, 77, 1, 37, "Equation"],
Cell[139813, 4382, 375, 11, 69, "Text"],
Cell[140191, 4395, 231, 9, 45, "Text"],
Cell[140425, 4406, 605, 11, 70, "Equation"],

Cell[CellGroupData[{
Cell[141055, 4421, 126, 3, 46, "Input"],
Cell[141184, 4426, 303, 5, 183, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141524, 4436, 476, 9, 213, "Input"],
Cell[142003, 4447, 75, 1, 41, "Output"],
Cell[142081, 4450, 84, 1, 46, "Output"],
Cell[142168, 4453, 55, 1, 46, "Output"],
Cell[142226, 4456, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142301, 4462, 216, 4, 89, "Input"],
Cell[142520, 4468, 38, 1, 41, "Output"]
}, Open  ]],
Cell[142573, 4472, 126, 5, 45, "Text"],
Cell[142702, 4479, 452, 8, 62, "NumberedEquation1"],
Cell[143157, 4489, 208, 5, 69, "Text"],
Cell[143368, 4496, 277, 6, 69, "NumberedEquation1",
  CellTags->"Equation68"],

Cell[CellGroupData[{
Cell[143670, 4506, 185, 4, 133, "Input"],
Cell[143858, 4512, 315, 5, 126, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144210, 4522, 378, 6, 165, "Input"],
Cell[144591, 4530, 122, 2, 64, "Output"],
Cell[144716, 4534, 42, 1, 35, "Print"],
Cell[144761, 4537, 38, 1, 41, "Output"]
}, Open  ]],
Cell[144814, 4541, 128, 5, 45, "Text"],
Cell[144945, 4548, 410, 9, 73, "NumberedEquation1",
  CellTags->"Equation69"],

Cell[CellGroupData[{
Cell[145380, 4561, 216, 5, 162, "Input"],
Cell[145599, 4568, 492, 8, 178, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146128, 4581, 243, 5, 75, "Input"],
Cell[146374, 4588, 80, 1, 59, "Message"],
Cell[146457, 4591, 227, 4, 75, "Output"]
}, Open  ]],
Cell[146699, 4598, 204, 8, 45, "Text"],
Cell[146906, 4608, 133, 2, 49, "Equation"],
Cell[147042, 4612, 177, 4, 69, "Text"],
Cell[147222, 4618, 150, 3, 35, "NumberedEquation1",
  CellTags->"Equation70"],
Cell[147375, 4623, 520, 13, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147932, 4641, 142, 6, 76, "Section",
  CellTags->"Section10"],
Cell[148077, 4649, 417, 14, 69, "Text"],
Cell[148497, 4665, 449, 13, 37, "NumberedEquation1",
  CellTags->"Equation71"],
Cell[148949, 4680, 147, 5, 45, "Text"],
Cell[149099, 4687, 70, 1, 45, "Text"],
Cell[149172, 4690, 197, 5, 57, "NumberedEquation1",
  CellTags->"Equation72"],
Cell[149372, 4697, 409, 14, 69, "Text"],
Cell[149784, 4713, 537, 15, 93, "Text"],
Cell[150324, 4730, 266, 9, 69, "Text"],
Cell[150593, 4741, 162, 4, 37, "Equation"],
Cell[150758, 4747, 739, 22, 117, "Text"],
Cell[151500, 4771, 276, 7, 69, "Text"],
Cell[151779, 4780, 804, 20, 82, "NumberedEquation1"],
Cell[152586, 4802, 131, 5, 45, "Text"],
Cell[152720, 4809, 940, 24, 82, "NumberedEquation1"],
Cell[153663, 4835, 596, 20, 93, "Text"],
Cell[154262, 4857, 294, 10, 45, "Text"],
Cell[154559, 4869, 611, 20, 101, "Text"],
Cell[155173, 4891, 694, 21, 101, "Text"],
Cell[155870, 4914, 242, 9, 69, "Text"],
Cell[156115, 4925, 638, 19, 93, "Text"],
Cell[156756, 4946, 170, 5, 45, "Text"],
Cell[156929, 4953, 214, 5, 57, "NumberedEquation1",
  CellTags->"Equation75"],
Cell[157146, 4960, 254, 6, 69, "Text"],
Cell[157403, 4968, 96, 2, 35, "NumberedEquation1",
  CellTags->"Equation76"],
Cell[157502, 4972, 468, 17, 69, "Text"],
Cell[157973, 4991, 65, 1, 45, "Text"],
Cell[158041, 4994, 276, 5, 35, "NumberedEquation1"],
Cell[158320, 5001, 288, 5, 35, "NumberedEquation1"],
Cell[158611, 5008, 240, 8, 45, "Text"],
Cell[158854, 5018, 493, 12, 57, "Equation"],
Cell[159350, 5032, 708, 16, 86, "Equation"],

Cell[CellGroupData[{
Cell[160083, 5052, 1114, 26, 225, "Input"],
Cell[161200, 5080, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161275, 5086, 1889, 43, 290, "Input"],
Cell[163167, 5131, 38, 1, 41, "Output"]
}, Open  ]],
Cell[163220, 5135, 152, 5, 45, "Text"],
Cell[163375, 5142, 87, 1, 35, "NumberedEquation1"],
Cell[163465, 5145, 143, 4, 45, "Text"],
Cell[163611, 5151, 848, 23, 63, "NumberedEquation1",
  CellTags->"Equation80"],

Cell[CellGroupData[{
Cell[164484, 5178, 2692, 63, 348, "Input"],
Cell[167179, 5243, 38, 1, 41, "Output"]
}, Open  ]],
Cell[167232, 5247, 110, 3, 45, "Text"],
Cell[167345, 5252, 134, 3, 58, "NumberedEquation1",
  CellTags->"Equation81"],
Cell[167482, 5257, 415, 14, 69, "Text"],

Cell[CellGroupData[{
Cell[167922, 5275, 154, 3, 91, "Input"],
Cell[168079, 5280, 716, 12, 322, "Output"]
}, Open  ]],
Cell[168810, 5295, 550, 17, 117, "Text"],
Cell[169363, 5314, 984, 26, 189, "Text"],
Cell[170350, 5342, 133, 2, 45, "Text",
  CellTags->"Footnote1Section10"],
Cell[170486, 5346, 418, 7, 117, "Text",
  CellTags->"Footnote2Section10"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170941, 5358, 202, 6, 104, "Section",
  CellTags->"Section11"],
Cell[171146, 5366, 813, 23, 141, "Text"],
Cell[171962, 5391, 249, 7, 69, "Text"],
Cell[172214, 5400, 47, 1, 45, "Text"],
Cell[172264, 5403, 448, 13, 37, "NumberedEquation1",
  CellTags->"Equation82"],
Cell[172715, 5418, 518, 17, 93, "Text"],

Cell[CellGroupData[{
Cell[173258, 5439, 647, 16, 149, "Input"],
Cell[173908, 5457, 1008, 27, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174953, 5489, 73, 1, 41, "Input"],
Cell[175029, 5492, 74, 1, 64, "Output"]
}, Open  ]],
Cell[175118, 5496, 276, 5, 35, "NumberedEquation1"],
Cell[175397, 5503, 84, 2, 46, "Text"],
Cell[175484, 5507, 312, 7, 36, "Equation"],
Cell[175799, 5516, 288, 5, 35, "NumberedEquation1"],
Cell[176090, 5523, 29, 0, 45, "Text"],
Cell[176122, 5525, 208, 4, 35, "NumberedEquation1"],
Cell[176333, 5531, 214, 4, 35, "NumberedEquation1"],
Cell[176550, 5537, 329, 6, 35, "NumberedEquation1"],
Cell[176882, 5545, 269, 6, 70, "NumberedEquation1"],
Cell[177154, 5553, 278, 9, 69, "Text"],
Cell[177435, 5564, 225, 8, 45, "Text"],
Cell[177663, 5574, 199, 4, 57, "NumberedEquation1"],
Cell[177865, 5580, 554, 19, 69, "Text"],

Cell[CellGroupData[{
Cell[178444, 5603, 1792, 38, 454, "Input"],
Cell[180239, 5643, 510, 9, 206, "Output"],
Cell[180752, 5654, 459, 7, 206, "Output"],
Cell[181214, 5663, 835, 13, 318, "Output"],
Cell[182052, 5678, 265, 5, 111, "Output"],
Cell[182320, 5685, 312, 6, 111, "Output"],
Cell[182635, 5693, 290, 5, 136, "Output"],
Cell[182928, 5700, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[183003, 5706, 147, 3, 66, "Input"],
Cell[183153, 5711, 38, 1, 41, "Output"]
}, Open  ]],
Cell[183206, 5715, 399, 7, 141, "Text"],
Cell[183608, 5724, 509, 12, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184154, 5741, 241, 8, 104, "Section",
  CellTags->"Section12"],
Cell[184398, 5751, 455, 15, 69, "Text"],

Cell[CellGroupData[{
Cell[184878, 5770, 653, 16, 93, "Input"],
Cell[185534, 5788, 3330, 91, 93, "Output"]
}, Open  ]],
Cell[188879, 5882, 91, 2, 45, "Text"],
Cell[188973, 5886, 306, 6, 58, "NumberedEquation1",
  CellTags->"Equation90"],
Cell[189282, 5894, 189, 6, 45, "Text"],
Cell[189474, 5902, 233, 9, 45, "Text"],
Cell[189710, 5913, 194, 4, 35, "NumberedEquation1",
  CellTags->"Equation91"],
Cell[189907, 5919, 620, 18, 93, "Text"],
Cell[190530, 5939, 217, 3, 53, "NumberedEquation1"],
Cell[190750, 5944, 148, 5, 45, "Text"],
Cell[190901, 5951, 1010, 32, 141, "Text"],
Cell[191914, 5985, 190, 3, 35, "NumberedEquation1"],
Cell[192107, 5990, 129, 3, 35, "Equation"],
Cell[192239, 5995, 200, 3, 35, "NumberedEquation1"],
Cell[192442, 6000, 601, 16, 93, "Text"],
Cell[193046, 6018, 256, 4, 35, "NumberedEquation1",
  CellTags->"Equation95"],
Cell[193305, 6024, 453, 10, 117, "Text"],
Cell[193761, 6036, 1668, 45, 261, "Text"],
Cell[195432, 6083, 166, 3, 57, "Equation"],
Cell[195601, 6088, 867, 24, 117, "Text"],
Cell[196471, 6114, 642, 14, 141, "Text"],
Cell[197116, 6130, 462, 14, 117, "Text"],
Cell[197581, 6146, 98, 2, 58, "Equation"],
Cell[197682, 6150, 115, 2, 58, "Equation"],
Cell[197800, 6154, 410, 13, 93, "Text"],
Cell[198213, 6169, 148, 2, 50, "Equation"],
Cell[198364, 6173, 143, 2, 50, "Equation"],
Cell[198510, 6177, 578, 15, 117, "Text"],
Cell[199091, 6194, 147, 5, 45, "Text"],
Cell[199241, 6201, 192, 4, 38, "NumberedEquation1",
  CellTags->"Equation96"],
Cell[199436, 6207, 472, 15, 69, "Text"],
Cell[199911, 6224, 704, 24, 93, "Text"],
Cell[200618, 6250, 584, 12, 138, "NumberedEquation1",
  CellTags->"Equation97"],
Cell[201205, 6264, 623, 22, 69, "Text"],
Cell[201831, 6288, 74, 1, 45, "Text"],
Cell[201908, 6291, 261, 5, 70, "NumberedEquation1"],
Cell[202172, 6298, 130, 4, 45, "Text"],
Cell[202305, 6304, 370, 9, 70, "NumberedEquation1",
  CellTags->"Equation99"],
Cell[202678, 6315, 21, 0, 45, "Text"],
Cell[202702, 6317, 444, 9, 70, "NumberedEquation1",
  CellTags->"Equation100"],

Cell[CellGroupData[{
Cell[203171, 6330, 787, 16, 197, "Input"],
Cell[203961, 6348, 253, 4, 115, "Output"],
Cell[204217, 6354, 38, 1, 41, "Output"]
}, Open  ]],
Cell[204270, 6358, 474, 16, 69, "Text"],
Cell[204747, 6376, 309, 10, 69, "Text"],
Cell[205059, 6388, 337, 8, 70, "NumberedEquation1"],
Cell[205399, 6398, 145, 5, 45, "Text"],
Cell[205547, 6405, 235, 4, 70, "NumberedEquation1",
  CellTags->"Equation102"],
Cell[205785, 6411, 20, 0, 45, "Text"],
Cell[205808, 6413, 361, 7, 62, "NumberedEquation1"],
Cell[206172, 6422, 366, 6, 62, "NumberedEquation1"],
Cell[206541, 6430, 639, 21, 111, "Text"],
Cell[207183, 6453, 317, 6, 69, "NumberedEquation1",
  CellTags->"Equation105"],
Cell[207503, 6461, 129, 3, 35, "Equation"],
Cell[207635, 6466, 359, 7, 69, "NumberedEquation1",
  CellTags->"Equation106"],

Cell[CellGroupData[{
Cell[208019, 6477, 157, 3, 94, "Input"],
Cell[208179, 6482, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208254, 6488, 972, 19, 297, "Input"],
Cell[209229, 6509, 373, 6, 134, "Output"],
Cell[209605, 6517, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[209680, 6523, 1052, 20, 393, "Input"],
Cell[210735, 6545, 417, 6, 134, "Output"],
Cell[211155, 6553, 38, 1, 41, "Output"]
}, Open  ]],
Cell[211208, 6557, 156, 4, 45, "Text"],
Cell[211367, 6563, 270, 5, 70, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[211662, 6572, 378, 7, 76, "Input"],
Cell[212043, 6581, 38, 1, 41, "Output"]
}, Open  ]],
Cell[212096, 6585, 289, 5, 70, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[212410, 6594, 380, 7, 76, "Input"],
Cell[212793, 6603, 38, 1, 41, "Output"]
}, Open  ]],
Cell[212846, 6607, 686, 20, 117, "Text"],
Cell[213535, 6629, 283, 5, 70, "NumberedEquation1",
  CellTags->"Equation109"],
Cell[213821, 6636, 206, 8, 45, "Text"],
Cell[214030, 6646, 283, 5, 70, "NumberedEquation1",
  CellTags->"Equation110"],
Cell[214316, 6653, 634, 20, 95, "Text"],
Cell[214953, 6675, 305, 5, 71, "NumberedEquation1"],
Cell[215261, 6682, 125, 3, 35, "Equation"],
Cell[215389, 6687, 301, 5, 71, "NumberedEquation1"],
Cell[215693, 6694, 391, 17, 45, "Text"],

Cell[CellGroupData[{
Cell[216109, 6715, 1142, 19, 182, "Input"],
Cell[217254, 6736, 1051, 18, 136, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218342, 6759, 983, 18, 225, "Input"],
Cell[219328, 6779, 594, 9, 171, "Output"],
Cell[219925, 6790, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220000, 6796, 983, 18, 225, "Input"],
Cell[220986, 6816, 634, 11, 170, "Output"],
Cell[221623, 6829, 38, 1, 41, "Output"]
}, Open  ]],
Cell[221676, 6833, 182, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[221895, 6842, 134, 5, 104, "Section"],
Cell[222032, 6849, 71, 1, 45, "Text"],
Cell[222106, 6852, 244, 4, 58, "NumberedEquation1"],
Cell[222353, 6858, 40, 0, 45, "Text"],
Cell[222396, 6860, 422, 7, 60, "NumberedEquation1",
  CellTags->"Equation114"],
Cell[222821, 6869, 58, 0, 45, "Text"],
Cell[222882, 6871, 256, 4, 58, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[223163, 6879, 167, 3, 41, "Input"],
Cell[223333, 6884, 80, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223450, 6890, 228, 4, 91, "Input"],
Cell[223681, 6896, 98, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223816, 6903, 894, 16, 259, "Input"],
Cell[224713, 6921, 527, 13, 43, "Output"],
Cell[225243, 6936, 280, 5, 67, "Output"]
}, Open  ]],
Cell[225538, 6944, 189, 6, 45, "Text"],
Cell[225730, 6952, 510, 9, 69, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[226265, 6965, 733, 13, 206, "Input"],
Cell[227001, 6980, 1479, 43, 102, "Output"]
}, Open  ]],
Cell[228495, 7026, 75, 2, 35, "Equation"],
Cell[228573, 7030, 546, 9, 69, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[229144, 7043, 732, 12, 270, "Input"],
Cell[229879, 7057, 1830, 52, 120, "Output"]
}, Open  ]],
Cell[231724, 7112, 202, 6, 45, "Text"],
Cell[231929, 7120, 925, 18, 109, "NumberedEquation1"],
Cell[232857, 7140, 92, 2, 46, "Text"],
Cell[232952, 7144, 961, 20, 113, "Equation"],

Cell[CellGroupData[{
Cell[233938, 7168, 337, 5, 228, "Input"],
Cell[234278, 7175, 4540, 120, 123, "Output"]
}, Open  ]],
Cell[238833, 7298, 892, 18, 109, "NumberedEquation1"],
Cell[239728, 7318, 84, 2, 46, "Text"],
Cell[239815, 7322, 928, 20, 113, "Equation"],

Cell[CellGroupData[{
Cell[240768, 7346, 337, 5, 228, "Input"],
Cell[241108, 7353, 3666, 102, 151, "Output"]
}, Open  ]],
Cell[244789, 7458, 188, 5, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[245014, 7468, 98, 5, 76, "Section"],
Cell[245115, 7475, 916, 25, 117, "Text"],
Cell[246034, 7502, 355, 7, 71, "NumberedEquation1"],

Cell[CellGroupData[{
Cell[246414, 7513, 104, 2, 41, "Input"],
Cell[246521, 7517, 710, 21, 112, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247268, 7543, 220, 5, 100, "Input"],
Cell[247491, 7550, 154, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247682, 7557, 104, 2, 41, "Input"],
Cell[247789, 7561, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247864, 7567, 113, 2, 41, "Input"],
Cell[247980, 7571, 128, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248145, 7578, 42, 1, 41, "Input"],
Cell[248190, 7581, 133, 2, 60, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248360, 7588, 47, 1, 41, "Input"],
Cell[248410, 7591, 150, 2, 60, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248597, 7598, 56, 1, 69, "Input"],
Cell[248656, 7601, 49, 1, 41, "Output"]
}, Open  ]],
Cell[248720, 7605, 258, 5, 93, "Text"],

Cell[CellGroupData[{
Cell[249003, 7614, 242, 5, 130, "Input"],
Cell[249248, 7621, 181, 3, 106, "Output"],
Cell[249432, 7626, 125, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[249594, 7633, 72, 1, 66, "Input"],
Cell[249669, 7636, 318, 6, 110, "Message"],
Cell[249990, 7644, 304, 7, 59, "Output"]
}, Open  ]],
Cell[250309, 7654, 1096, 27, 237, "Text"],
Cell[251408, 7683, 566, 20, 69, "Text"],
Cell[251977, 7705, 213, 4, 57, "NumberedEquation1",
  CellTags->"Equation121"],
Cell[252193, 7711, 326, 12, 45, "Text"],
Cell[252522, 7725, 368, 12, 69, "Text"],
Cell[252893, 7739, 300, 6, 58, "NumberedEquation1",
  CellTags->"Equation122"],
Cell[253196, 7747, 833, 27, 141, "Text"],
Cell[254032, 7776, 496, 13, 63, "Equation"],
Cell[254531, 7791, 722, 27, 93, "Text"],
Cell[255256, 7820, 581, 11, 86, "Equation"],
Cell[255840, 7833, 405, 12, 69, "Text"],

Cell[CellGroupData[{
Cell[256270, 7849, 623, 12, 131, "Input"],
Cell[256896, 7863, 954, 22, 82, "Output"],
Cell[257853, 7887, 372, 9, 81, "Output"]
}, Open  ]],
Cell[258240, 7899, 189, 6, 69, "Text"],
Cell[258432, 7907, 424, 7, 58, "Equation"],

Cell[CellGroupData[{
Cell[258881, 7918, 384, 6, 147, "Input"],
Cell[259268, 7926, 42, 1, 35, "Print"],
Cell[259313, 7929, 55, 1, 46, "Output"],
Cell[259371, 7932, 45, 1, 43, "Output"],
Cell[259419, 7935, 38, 1, 41, "Output"]
}, Open  ]],
Cell[259472, 7939, 266, 7, 69, "Text"],
Cell[259741, 7948, 268, 5, 58, "NumberedEquation1"],
Cell[260012, 7955, 252, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[260289, 7970, 723, 16, 120, "Input"],
Cell[261015, 7988, 875, 21, 70, "Output"],
Cell[261893, 8011, 498, 13, 68, "Output"]
}, Open  ]],
Cell[262406, 8027, 463, 12, 93, "Text"],
Cell[262872, 8041, 165, 8, 45, "Text"],
Cell[263040, 8051, 291, 6, 93, "Text",
  CellTags->"Footnote1Section14"],
Cell[263334, 8059, 173, 4, 45, "Text",
  CellTags->"Footnote2Section14"],
Cell[263510, 8065, 272, 5, 69, "Text",
  CellTags->"Footnote3Section14"],
Cell[263785, 8072, 276, 5, 93, "Text",
  CellTags->"Footnote4Section14"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264098, 8082, 27, 0, 76, "Section"],
Cell[264128, 8084, 112, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[264265, 8093, 71, 1, 41, "Input"],
Cell[264339, 8096, 97, 2, 41, "Output"]
}, Open  ]],
Cell[264451, 8101, 54, 0, 45, "Text"],
Cell[264508, 8103, 45, 1, 41, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

